# covid19-cli
---
[![Gem Version](http://badge.fury.io/rb/covid19-cli.svg)](http://badge.fury.io/rb/covid19-cli)
[![Build Status](https://travis-ci.org/TecnoSigma/covid19-cli.svg?branch=master)](https://travis-ci.org/github/TecnoSigma/covid19-cli)
[![Coverage Status](https://coveralls.io/repos/github/TecnoSigma/covid19-cli/badge.svg?branch=master)](https://coveralls.io/github/TecnoSigma/covid19-cli?branch=master)
[![Code Climate](https://codeclimate.com/github/TecnoSigma/covid19-cli/badges/gpa.svg)](https://codeclimate.com/github/TecnoSigma/covid19-cli)
[![GitHub license](https://img.shields.io/apm/l/vim-mode.svg)](LICENSE)

Welcome to your new gem! In this directory, you'll find the files you need to be able to package up your Ruby library into a gem. Put your Ruby code in the file `lib/covid19/cli`. To experiment with that code, run `bin/console` for an interactive prompt.

Gem that collect COVID-19 global stats through [disease.sh](https://corona.lmao.ninja/).

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'covid19-cli'
```

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install covid19-cli

## Usage

In terminal:

### Commands List

---

**Show available commands**
```shell
covid19-cli
```
**Output**
```shell
covid19-cli all countries             # List all countries data
covid19-cli all_continents            # List all continents data
covid19-cli continent CONTINENT_NAME  # List continent data
covid19-cli country COUNTRY_NAME      # List country data
covid19-cli help [COMMAND]            # Describe available commands or one specific command
```
---
**Show available options**
```shell
covid19-cli -h <command_name>
```
**Output**
```shell
Usage:
  covid19-cli <command_name>

Options:
  -t, [--table=TABLE]
  -c, [--chart=CHART]
      [--colored=COLORED] <only charts>

<Command description>

```
---

**Get specific continent data in hash format**
```shell
covid19-cli continent africa
```
**Output**
```shell
{"updated"=>1594779763763, "cases"=>628885, "todayCases"=>0, "deaths"=>13803, "todayDeaths"=>0, "recovered"=>316780, "todayRecovered"=>0, "active"=>298302, "critical"=>982, "casesPerOneMillion"=>468.8, "deathsPerOneMillion"=>10.29, "tests"=>6052901, "testsPerOneMillion"=>4512.07, "population"=>1341491868, "continent"=>"Africa", "activePerOneMillion"=>222.37, "recoveredPerOneMillion"=>236.14, "criticalPerOneMillion"=>0.73, "continentInfo"=>{"lat"=>1.7383867, "long"=>-16.3094636}, "countries"=>["Algeria", "Angola", "Benin", "Botswana", "Burkina Faso", "Burundi", "Cabo Verde", "Cameroon", "Central African Republic", "Chad", "Comoros", "Congo", "Côte d'Ivoire", "DRC", "Djibouti", "Egypt", "Equatorial Guinea", "Eritrea", "Ethiopia", "Gabon", "Gambia", "Ghana", "Guinea", "Guinea-Bissau", "Kenya", "Lesotho", "Liberia", "Libyan Arab Jamahiriya", "Madagascar", "Malawi", "Mali", "Mauritania", "Mauritius", "Mayotte", "Morocco", "Mozambique", "Namibia", "Niger", "Nigeria", "Rwanda", "Réunion", "Sao Tome and Principe", "Senegal", "Seychelles", "Sierra Leone", "Somalia", "South Africa", "South Sudan", "Sudan", "Swaziland", "Tanzania", "Togo", "Tunisia", "Uganda", "Western Sahara", "Zambia", "Zimbabwe"]}
```

---

**Get specific continent data in table format**
```shell
covid19-cli continent africa --table
```
**Output**
```shell
+---------+------------+--------+-------------+-----------+----------------+---------+----------+-----------+--------------------+
|  cases  | todayCases | deaths | todayDeaths | recovered | todayRecovered | active  | critical |   tests   | testsPerOneMillion |
+---------+------------+--------+-------------+-----------+----------------+---------+----------+-----------+--------------------+
| 628 885 |          0 | 13 803 |           0 |   316 780 |              0 | 298 302 |      982 | 6 052 901 |           4 512.07 |
+---------+------------+--------+-------------+-----------+----------------+---------+----------+-----------+--------------------+
```

---

**Render specific continent data chart**
```shell
covid19-cli continent africa --chart
```
**Output**
```shell
                       @@@@@@@***xxxxx
                   @@@@@@@@@@@**xxxxxxxxxx
               @@@@@@@@@@@@@@@**xxxxxxxxxxxxxx
            @@@@@@@@@@@@@@@@@@**xxxxxxxxxxxxxxxxx
          @@@@@@@@@@@@@@@@@@@@**xxxxxxxxxxxxxxxxxxx
        @@@@@@@@@@@@@@@@@@@@@@**xxxxxxxxxxxxxxxxxxxxx
      @@@@@@@@@@@@@@@@@@@@@@@@**xxxxxxxxxxxxxxxxxxxxxxx
     @@@@@@@@@@@@@@@@@@@@@@@@@**xxxxxxxxxxxxxxxxxxxxxxxx
   @@@@@@@@@@@@@@@@@@@@@@@@@@@*xxxxxxxxxxxxxxxxxxxxxxxxxxx
   @@@@@@@@@@@@@@@@@@@@@@@@@@@*xxxxxxxxxxxxxxxxxxxxxxxxxxx
  @@@@@@@@@@@@@@@@@@@@@@@@@@@@*xxxxxxxxxxxxxxxxxxxxxxxxxxxx
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@*xxxxxxxxxxxxxxxxxxxxxxxxxxxxx
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@*xxxxxxxxxxxxxxxxxxxxxxxxxxxxx
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@*xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx    * deaths 2.16%
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@*xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx    x recovered 52.04%
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx    @ active 45.80%
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
  @@@@@@@@@@@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
   @@@@@@@@@@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxxxxxxxxxx
   @@@@@@@@@@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxxxxxxxxxx
     @@@@@@@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxxxxxxxxx
      @@@@@@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxxxxxxxx
        @@@@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxxxxxx
          @@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxxxx
            @@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxxx
               @@@@@@@@@@@@xxxxxxxxxxxxxxxxxxx
                   @@@@@@@@xxxxxxxxxxxxxxx
                       @@@xxxxxxxxxxxx
                       @@@@@@@********
                   @@@@@@@@@@@************
               @@@@@@@@@@@@@@@****************
            @@@@@@@@@@@@@@@@@@*******************
          @@@@@@@@@@@@@@@@@@@@*********************
        @@@@@@@@@@@@@@@@@@@@@@***********************
      @@@@@@@@@@@@@@@@@@@@@@@@*************************
     @@@@@@@@@@@@@@@@@@@@@@@@@**************************
   @@@@@@@@@@@@@@@@@@@@@@@@@@@****************************
   @@@@@@@@@@@@@@@@@@@@@@@@@@@****************************
  @@@@@@@@@@@@@@@@@@@@@@@@@@@@*****************************
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@******************************
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@******************************
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@*******************************    * todayCases 51.77%
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@*******************************
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@*******************************    x todayDeaths 0.55%
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@*******************************
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@*******************************    @ todayRecovered 47.68%
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@******************************
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@******************************
  @@@@@@@@@@@@@@@@@@@@@@@@@@@@*****************************
   @@@@@@@@@@@@@@@@@@@@@@@@@@@****************************
   @@@@@@@@@@@@@@@@@@@@@@@@@@x****************************
     @@@@@@@@@@@@@@@@@@@@@@@@x**************************
      @@@@@@@@@@@@@@@@@@@@@@@**************************
        @@@@@@@@@@@@@@@@@@@@@************************
          @@@@@@@@@@@@@@@@@@@**********************
            @@@@@@@@@@@@@@@@@********************
               @@@@@@@@@@@@@@*****************
                   @@@@@@@@@x*************
                       @@@@@x*********

```

---

**Get specific country data in hash format**
```shell
covid19-cli country canada
```
**Output**
```ruby
{"updated"=>1594779763526, "country"=>"Canada", "countryInfo"=>{"_id"=>124, "iso2"=>"CA", "iso3"=>"CAN", "lat"=>60, "long"=>-95, "flag"=>"https://disease.sh/assets/img/flags/ca.png"}, "cases"=>108486, "todayCases"=>0, "deaths"=>8798, "todayDeaths"=>0, "recovered"=>72170, "todayRecovered"=>0, "active"=>27518, "critical"=>2170, "casesPerOneMillion"=>2873, "deathsPerOneMillion"=>233, "tests"=>3302483, "testsPerOneMillion"=>87473, "population"=>37754249, "continent"=>"North America", "oneCasePerPeople"=>348, "oneDeathPerPeople"=>4291, "oneTestPerPeople"=>11, "activePerOneMillion"=>728.87, "recoveredPerOneMillion"=>1911.57, "criticalPerOneMillion"=>57.48}
```

---

**Get specific country data in table format**
```shell
covid19-cli country canada --table
```
**Output**
```shell
+---------+------------+--------+-------------+-----------+----------------+--------+----------+-----------+--------------------+
|  cases  | todayCases | deaths | todayDeaths | recovered | todayRecovered | active | critical |   tests   | testsPerOneMillion |
+---------+------------+--------+-------------+-----------+----------------+--------+----------+-----------+--------------------+
| 108 486 |          0 |  8 798 |           0 |    72 170 |              0 | 27 518 |    2 170 | 3 302 483 |             87 473 |
+---------+------------+--------+-------------+-----------+----------------+--------+----------+-----------+--------------------+
```

---

**Render specific country data chart**
```shell
covid19-cli country canada --chart
```
**Output**
```shell
                       @@@@@@@********
                   @@@@@@@@@@@********xxxx
               @@@@@@@@@@@@@@@********xxxxxxxx
            @@@@@@@@@@@@@@@@@@*******xxxxxxxxxxxx
          @@@@@@@@@@@@@@@@@@@@*******xxxxxxxxxxxxxx
        @@@@@@@@@@@@@@@@@@@@@@******xxxxxxxxxxxxxxxxx
      @@@@@@@@@@@@@@@@@@@@@@@@******xxxxxxxxxxxxxxxxxxx
     @@@@@@@@@@@@@@@@@@@@@@@@@*****xxxxxxxxxxxxxxxxxxxxx
   @@@@@@@@@@@@@@@@@@@@@@@@@@@****xxxxxxxxxxxxxxxxxxxxxxxx
   @@@@@@@@@@@@@@@@@@@@@@@@@@@****xxxxxxxxxxxxxxxxxxxxxxxx
  @@@@@@@@@@@@@@@@@@@@@@@@@@@@***xxxxxxxxxxxxxxxxxxxxxxxxxx
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@***xxxxxxxxxxxxxxxxxxxxxxxxxxx
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@**xxxxxxxxxxxxxxxxxxxxxxxxxxxx
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@**xxxxxxxxxxxxxxxxxxxxxxxxxxxxx    * deaths 8.09%
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@*xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx    x recovered 66.72%
xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx    @ active 25.19%
 xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
 xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
  xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
   xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
   xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
     xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
      xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
        xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
          xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
            xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
               xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
                   xxxxxxxxxxxxxxxxxxxxxxx
                       xxxxxxxxxxxxxxx
                       @@@@@@@********
                   @@@@@@@@@@@************
               @@@@@@@@@@@@@@@****************
            @@@@@@@@@@@@@@@@@@*******************
          @@@@@@@@@@@@@@@@@@@@*********************
        @@@@@@@@@@@@@@@@@@@@@@***********************
      @@@@@@@@@@@@@@@@@@@@@@@@*************************
     @@@@@@@@@@@@@@@@@@@@@@@@@**************************
   @@@@@@@@@@@@@@@@@@@@@@@@@@@****************************
   @@@@@@@@@@@@@@@@@@@@@@@@@@@****************************
  @@@@@@@@@@@@@@@@@@@@@@@@@@@@*****************************
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@******************************
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@******************************
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@*******************************    * todayCases 44.58%
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@*******************************
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@******************************    x todayDeaths 2.66%
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@******************************
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@******************************    @ todayRecovered 52.75%
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@x****************************
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@x****************************
  @@@@@@@@@@@@@@@@@@@@@@@@@@@@@x***************************
   @@@@@@@@@@@@@@@@@@@@@@@@@@@@@x*************************
   @@@@@@@@@@@@@@@@@@@@@@@@@@@@@x*************************
     @@@@@@@@@@@@@@@@@@@@@@@@@@@x***********************
      @@@@@@@@@@@@@@@@@@@@@@@@@@xx*********************
        @@@@@@@@@@@@@@@@@@@@@@@@xx*******************
          @@@@@@@@@@@@@@@@@@@@@@xx*****************
            @@@@@@@@@@@@@@@@@@@@@xx**************
               @@@@@@@@@@@@@@@@@@xx***********
                   @@@@@@@@@@@@@@xx*******
                       @@@@@@@@@@xxx**
```

---

**Get continent general data in hash format**
```shell
covid19-cli all_continents
```
**Output**
```shell
{"updated"=>1594779763760, "cases"=>4152507, "todayCases"=>7057, "deaths"=>188977, "todayDeaths"=>837, "recovered"=>1939661, "todayRecovered"=>4932, "active"=>2023869, "critical"=>19737, "casesPerOneMillion"=>7046.81, "deathsPerOneMillion"=>320.69, "tests"=>49174748, "testsPerOneMillion"=>83449.65, "population"=>589274482, "continent"=>"North America", "activePerOneMillion"=>3434.51, "recoveredPerOneMillion"=>3291.61, "criticalPerOneMillion"=>33.49, "continentInfo"=>{"lat"=>31.6768272, "long"=>-146.4707474}, "countries"x'=>["Anguilla", "Antigua and Barbuda", "Aruba", "Bahamas", "Barbados", "Belize", "Bermuda", "British Virgin Islands", "Canada", "Caribbean Netherlands", "Cayman Islands", "Costa Rica", "Cuba", "Curaçao", "Dominica", "Dominican Republic", "El Salvador", "Greenland", "Grenada", "Guadeloupe", "Guatemala", "Haiti", "Honduras", "Jamaica", "Martinique", "Mexico", "Montserrat", "Nicaragua", "Panama", "Saint Kitts and Nevis", "Saint Lucia", "Saint Martin", "Saint Pierre Miquelon", "Saint Vincent and the Grenadines", "Sint Maarten", "St. Barth", "Trinidad and Tobago", "Turks and Caicos Islands", "USA"]}
{"updated"=>1594779763761, "cases"=>2993241, "todayCases"=>1617, "deaths"=>108399, "todayDeaths"=>32, "recovered"=>1895637, "todayRecovered"=>525, "active"=>989205, "critical"=>13640, "casesPerOneMillion"=>6946.69, "deathsPerOneMillion"=>251.57, "tests"=>11303001, "testsPerOneMillion"=>26231.92, "population"=>430887254, "continent"=>"South America", "activePerOneMillion"=>2295.74, "recoveredPerOneMillion"=>4399.38, "criticalPerOneMillion"=>31.66, "continentInfo"=>{"lat"=>-15.6551563, "long"=>-100.7484231}, "countries"=>["Argentina", "Bolivia", "Brazil", "Chile", "Colombia", "Ecuador", "Falkland Islands (Malvinas)", "French Guiana", "Guyana", "Paraguay", "Peru", "Suriname", "Uruguay", "Venezuela"]}
{"updated"=>1594779763762, "cases"=>3070885, "todayCases"=>45, "deaths"=>72618, "todayDeaths"=>0, "recovered"=>2154879, "todayRecovered"=>85, "active"=>843388, "critical"=>19858, "casesPerOneMillion"=>666.01, "deathsPerOneMillion"=>15.75, "tests"=>134948085, "testsPerOneMillion"=>29267.4, "population"=>4610867206, "continent"=>"Asia", "activePerOneMillion"=>182.91, "recoveredPerOneMillion"=>467.35, "criticalPerOneMillion"=>4.31, "continentInfo"=>{"lat"=>23.7027273, "long"=>62.3750637}, "countries"=>["Afghanistan", "Armenia", "Azerbaijan", "Bahrain", "Bangladesh", "Bhutan", "Brunei", "Cambodia", "China", "Cyprus", "Georgia", "Hong Kong", "India", "Indonesia", "Iran", "Iraq", "Israel", "Japan", "Jordan", "Kazakhstan", "Kuwait", "Kyrgyzstan", "Lao People's Democratic Republic", "Lebanon", "Macao", "Malaysia", "Maldives", "Mongolia", "Myanmar", "Nepal", "Oman", "Pakistan", "Palestine", "Philippines", "Qatar", "S. Korea", "Saudi Arabia", "Singapore", "Sri Lanka", "Syrian Arab Republic", "Taiwan", "Tajikistan", "Thailand", "Timor-Leste", "Turkey", "UAE", "Uzbekistan", "Vietnam", "Yemen"]}
{"updated"=>1594779763762, "cases"=>2599065, "todayCases"=>0, "deaths"=>197276, "todayDeaths"=>0, "recovered"=>1530085, "todayRecovered"=>0, "active"=>871704, "critical"=>5330, "casesPerOneMillion"=>3476.32, "deathsPerOneMillion"=>263.86, "tests"=>73467226, "testsPerOneMillion"=>98264.29, "population"=>747649305, "continent"=>"Europe", "activePerOneMillion"=>1165.93, "recoveredPerOneMillion"=>2046.53, "criticalPerOneMillion"=>7.13, "continentInfo"=>{"lat"=>25.771324, "long"=>-35.6012256}, "countries"=>["Albania", "Andorra", "Austria", "Belarus", "Belgium", "Bosnia", "Bulgaria", "Channel Islands", "Croatia", "Czechia", "Denmark", "Estonia", "Faroe Islands", "Finland", "France", "Germany", "Gibraltar", "Greece", "Holy See (Vatican City State)", "Hungary", "Iceland", "Ireland", "Isle of Man", "Italy", "Latvia", "Liechtenstein", "Lithuania", "Luxembourg", "Macedonia", "Malta", "Moldova", "Monaco", "Montenegro", "Netherlands", "Norway", "Poland", "Portugal", "Romania", "Russia", "San Marino", "Serbia", "Slovakia", "Slovenia", "Spain", "Sweden", "Switzerland", "UK", "Ukraine"]}
{"updated"=>1594779763763, "cases"=>628885, "todayCases"=>0, "deaths"=>13803, "todayDeaths"=>0, "recovered"=>316780, "todayRecovered"=>0, "active"=>298302, "critical"=>982, "casesPerOneMillion"=>468.8, "deathsPerOneMillion"=>10.29, "tests"=>6052901, "testsPerOneMillion"=>4512.07, "population"=>1341491868, "continent"=>"Africa", "activePerOneMillion"=>222.37, "recoveredPerOneMillion"=>236.14, "criticalPerOneMillion"=>0.73, "continentInfo"=>{"lat"=>1.7383867, "long"=>-16.3094636}, "countries"=>["Algeria", "Angola", "Benin", "Botswana", "Burkina Faso", "Burundi", "Cabo Verde", "Cameroon", "Central African Republic", "Chad", "Comoros", "Congo", "Côte d'Ivoire", "DRC", "Djibouti", "Egypt", "Equatorial Guinea", "Eritrea", "Ethiopia", "Gabon", "Gambia", "Ghana", "Guinea", "Guinea-Bissau", "Kenya", "Lesotho", "Liberia", "Libyan Arab Jamahiriya", "Madagascar", "Malawi", "Mali", "Mauritania", "Mauritius", "Mayotte", "Morocco", "Mozambique", "Namibia", "Niger", "Nigeria", "Rwanda", "Réunion", "Sao Tome and Principe", "Senegal", "Seychelles", "Sierra Leone", "Somalia", "South Africa", "South Sudan", "Sudan", "Swaziland", "Tanzania", "Togo", "Tunisia", "Uganda", "Western Sahara", "Zambia", "Zimbabwe"]}
{"updated"=>1594779763764, "cases"=>12154, "todayCases"=>239, "deaths"=>133, "todayDeaths"=>3, "recovered"=>9533, "todayRecovered"=>93, "active"=>2488, "critical"=>28, "casesPerOneMillion"=>296.96, "deathsPerOneMillion"=>3.25, "tests"=>3672053, "testsPerOneMillion"=>89719.88, "population"=>40927974, "continent"=>"Australia/Oceania", "activePerOneMillion"=>60.79, "recoveredPerOneMillion"=>232.92, "criticalPerOneMillion"=>0.68, "continentInfo"=>{"lat"=>-8.6599161, "long"=>91.1469847}, "countries"=>["Australia", "Fiji", "French Polynesia", "New Caledonia", "New Zealand", "Papua New Guinea"]}
```

---

**Get continent general data in table format**
```shell
covid19-cli all_continents
```
**Output**
```shell
+-------------------+-----------+------------+---------+-------------+-----------+----------------+-----------+----------+-------------+--------------------+
|     continent     |   cases   | todayCases | deaths  | todayDeaths | recovered | todayRecovered |  active   | critical |    tests    | testsPerOneMillion |
+-------------------+-----------+------------+---------+-------------+-----------+----------------+-----------+----------+-------------+--------------------+
|     North America | 4 152 507 |      7 057 | 188 977 |         837 | 1 939 661 |          4 932 | 2 023 869 |   19 737 |  49 174 748 |          83 449.65 |
|     South America | 2 993 241 |      1 617 | 108 399 |          32 | 1 895 637 |            525 |   989 205 |   13 640 |  11 303 001 |          26 231.92 |
|              Asia | 3 070 885 |         45 |  72 618 |           0 | 2 154 879 |             85 |   843 388 |   19 858 | 134 948 085 |           29 267.4 |
|            Europe | 2 599 065 |          0 | 197 276 |           0 | 1 530 085 |              0 |   871 704 |    5 330 |  73 467 226 |          98 264.29 |
|            Africa |   628 885 |          0 |  13 803 |           0 |   316 780 |              0 |   298 302 |      982 |   6 052 901 |           4 512.07 |
| Australia/Oceania |    12 154 |        239 |     133 |           3 |     9 533 |             93 |     2 488 |       28 |   3 672 053 |          89 719.88 |
+-------------------+-----------+------------+---------+-------------+-----------+----------------+-----------+----------+-------------+--------------------+
```
---

**Render all continent data chart**
```shell
covid19-cli all_continents --chart
```
**Output**
```shell
                       +++%%%%********
                   +++++++%%%%************
               +++++++++++%%%%****************
            +++++++++++++++%%%*******************
          +++++++++++++++++%%%*********************
        +++++++++++++++++++%%%***********************
      ++++++++++++++++++++++%%*************************
     +++++++++++++++++++++++%%**************************
   +++++++++++++++++++++++++%%****************************
   ++++++++++++++++++++++++++%****************************       * North America 30.92%
  +++++++++++++++++++++++++++%*****************************
 ++++++++++++++++++++++++++++%******************************     x South America 22.17%
 +++++++++++++++++++++++++++++******************************
@@@@++++++++++++++++++++++++++*******************************    @ Asia 23.09%
@@@@@@@@@@@@@@@@@+++++++++++++*******************************
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@x******************************    + Europe 19.02%
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@xxx****************************
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@xxxxxx*************************    % Africa 4.70%
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@xxxxxxxx**********************
 @@@@@@@@@@@@@@@@@@@@@@@@@@@@@xxxxxxxxxxx*******************     # Australia/Oceania 0.09%
  @@@@@@@@@@@@@@@@@@@@@@@@@@@@xxxxxxxxxxxxx****************
   @@@@@@@@@@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxx************
   @@@@@@@@@@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxx**********
     @@@@@@@@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxxx*****
      @@@@@@@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxxxxxx*
        @@@@@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxxxxx
          @@@@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxxxx
            @@@@@@@@@@@@@@@@xxxxxxxxxxxxxxxxxxxxx
               @@@@@@@@@@@@@xxxxxxxxxxxxxxxxxx
                   @@@@@@@@@xxxxxxxxxxxxxx
                       @@@@@xxxxxxxxxx
```

---

**Get countries general data in hash format**
```shell
covid19-cli all_countries
```
**Output**
```shell
{"updated"=>1594779763557, "country"=>"Afghanistan", "countryInfo"=>{"_id"=>4, "iso2"=>"AF", "iso3"=>"AFG", "lat"=>33, "long"=>65, "flag"=>"https://disease.sh/assets/img/flags/af.png"}, "cases"=>34740, "todayCases"=>0, "deaths"=>1048, "todayDeaths"=>0, "recovered"=>21454, "todayRecovered"=>0, "active"=>12238, "critical"=>31, "casesPerOneMillion"=>892, "deathsPerOneMillion"=>27, "tests"=>81252, "testsPerOneMillion"=>2086, "population"=>38954218, "continent"=>"Asia", "oneCasePerPeople"=>1121, "oneDeathPerPeople"=>37170, "oneTestPerPeople"=>479, "activePerOneMillion"=>314.16, "recoveredPerOneMillion"=>550.75, "criticalPerOneMillion"=>0.8}
{"updated"=>1594779763626, "country"=>"Albania", "countryInfo"=>{"_id"=>8, "iso2"=>"AL", "iso3"=>"ALB", "lat"=>41, "long"=>20, "flag"=>"https://disease.sh/assets/img/flags/al.png"}, "cases"=>3667, "todayCases"=>0, "deaths"=>97, "todayDeaths"=>0, "recovered"=>2062, "todayRecovered"=>0, "active"=>1508, "critical"=>10, "casesPerOneMillion"=>1274, "deathsPerOneMillion"=>34, "tests"=>29334, "testsPerOneMillion"=>10194, "population"=>2877667, "continent"=>"Europe", "oneCasePerPeople"=>785, "oneDeathPerPeople"=>29667, "oneTestPerPeople"=>98, "activePerOneMillion"=>524.04, "recoveredPerOneMillion"=>716.55, "criticalPerOneMillion"=>3.48}
{"updated"=>1594779763575, "country"=>"Algeria", "countryInfo"=>{"_id"=>12, "iso2"=>"DZ", "iso3"=>"DZA", "lat"=>28, "long"=>3, "flag"=>"https://disease.sh/assets/img/flags/dz.png"}, "cases"=>20216, "todayCases"=>0, "deaths"=>1028, "todayDeaths"=>0, "recovered"=>14295, "todayRecovered"=>0, "active"=>4893, "critical"=>61, "casesPerOneMillion"=>461, "deathsPerOneMillion"=>23, "tests"=>0, "testsPerOneMillion"=>0, "population"=>43876253, "continent"=>"Africa", "oneCasePerPeople"=>2170, "oneDeathPerPeople"=>42681, "oneTestPerPeople"=>0, "activePerOneMillion"=>111.52, "recoveredPerOneMillion"=>325.8, "criticalPerOneMillion"=>1.39}
{"updated"=>1594779763684, "country"=>"Andorra", "countryInfo"=>{"_id"=>20, "iso2"=>"AD", "iso3"=>"AND", "lat"=>42.5, "long"=>1.6, "flag"=>"https://disease.sh/assets/img/flags/ad.png"}, "cases"=>861, "todayCases"=>0, "deaths"=>52, "todayDeaths"=>0, "recovered"=>803, "todayRecovered"=>0, "active"=>6, "critical"=>0, "casesPerOneMillion"=>11143, "deathsPerOneMillion"=>673, "tests"=>3750, "testsPerOneMillion"=>48531, "population"=>77270, "continent"=>"Europe", "oneCasePerPeople"=>90, "oneDeathPerPeople"=>1486, "oneTestPerPeople"=>21, "activePerOneMillion"=>77.65, "recoveredPerOneMillion"=>10392.13, "criticalPerOneMillion"=>0}
{"updated"=>1594779763695, "country"=>"Angola", "countryInfo"=>{"_id"=>24, "iso2"=>"AO", "iso3"=>"AGO", "lat"=>-12.5, "long"=>18.5, "flag"=>"https://disease.sh/assets/img/flags/ao.png"}, "cases"=>541, "todayCases"=>0, "deaths"=>26, "todayDeaths"=>0, "recovered"=>118, "todayRecovered"=>0, "active"=>397, "critical"=>6, "casesPerOneMillion"=>16, "deathsPerOneMillion"=>0.8, "tests"=>10000, "testsPerOneMillion"=>304, "population"=>32891752, "continent"=>"Africa", "oneCasePerPeople"=>60798, "oneDeathPerPeople"=>1265067, "oneTestPerPeople"=>3289, "activePerOneMillion"=>12.07, "recoveredPerOneMillion"=>3.59, "criticalPerOneMillion"=>0.18}
{"updated"=>1594779763757, "country"=>"Anguilla", "countryInfo"=>{"_id"=>660, "iso2"=>"AI", "iso3"=>"AIA", "lat"=>18.25, "long"=>-63.1667, "flag"=>"https://disease.sh/assets/img/flags/ai.png"}, "cases"=>3, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>3, "todayRecovered"=>0, "active"=>0, "critical"=>0, "casesPerOneMillion"=>200, "deathsPerOneMillion"=>0, "tests"=>380, "testsPerOneMillion"=>25320, "population"=>15008, "continent"=>"North America", "oneCasePerPeople"=>5003, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>39, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>199.89, "criticalPerOneMillion"=>0}
{"updated"=>1594779763730, "country"=>"Antigua and Barbuda", "countryInfo"=>{"_id"=>28, "iso2"=>"AG", "iso3"=>"ATG", "lat"=>17.05, "long"=>-61.8, "flag"=>"https://disease.sh/assets/img/flags/ag.png"}, "cases"=>74, "todayCases"=>0, "deaths"=>3, "todayDeaths"=>0, "recovered"=>57, "todayRecovered"=>0, "active"=>14, "critical"=>1, "casesPerOneMillion"=>755, "deathsPerOneMillion"=>31, "tests"=>866, "testsPerOneMillion"=>8840, "population"=>97959, "continent"=>"North America", "oneCasePerPeople"=>1324, "oneDeathPerPeople"=>32653, "oneTestPerPeople"=>113, "activePerOneMillion"=>142.92, "recoveredPerOneMillion"=>581.88, "criticalPerOneMillion"=>10.21}
{"updated"=>1594779763527, "country"=>"Argentina", "countryInfo"=>{"_id"=>32, "iso2"=>"AR", "iso3"=>"ARG", "lat"=>-34, "long"=>-64, "flag"=>"https://disease.sh/assets/img/flags/ar.png"}, "cases"=>106910, "todayCases"=>0, "deaths"=>1968, "todayDeaths"=>0, "recovered"=>45467, "todayRecovered"=>0, "active"=>59475, "critical"=>752, "casesPerOneMillion"=>2365, "deathsPerOneMillion"=>44, "tests"=>483799, "testsPerOneMillion"=>10701, "population"=>45210848, "continent"=>"South America", "oneCasePerPeople"=>423, "oneDeathPerPeople"=>22973, "oneTestPerPeople"=>93, "activePerOneMillion"=>1315.5, "recoveredPerOneMillion"=>1005.67, "criticalPerOneMillion"=>16.63}
{"updated"=>1594779763562, "country"=>"Armenia", "countryInfo"=>{"_id"=>51, "iso2"=>"AM", "iso3"=>"ARM", "lat"=>40, "long"=>45, "flag"=>"https://disease.sh/assets/img/flags/am.png"}, "cases"=>32490, "todayCases"=>0, "deaths"=>581, "todayDeaths"=>0, "recovered"=>20729, "todayRecovered"=>0, "active"=>11180, "critical"=>10, "casesPerOneMillion"=>10964, "deathsPerOneMillion"=>196, "tests"=>136802, "testsPerOneMillion"=>46163, "population"=>2963464, "continent"=>"Asia", "oneCasePerPeople"=>91, "oneDeathPerPeople"=>5101, "oneTestPerPeople"=>22, "activePerOneMillion"=>3772.61, "recoveredPerOneMillion"=>6994.85, "criticalPerOneMillion"=>3.37}
{"updated"=>1594779763721, "country"=>"Aruba", "countryInfo"=>{"_id"=>533, "iso2"=>"AW", "iso3"=>"ABW", "lat"=>12.5, "long"=>-69.9667, "flag"=>"https://disease.sh/assets/img/flags/aw.png"}, "cases"=>106, "todayCases"=>0, "deaths"=>3, "todayDeaths"=>0, "recovered"=>99, "todayRecovered"=>0, "active"=>4, "critical"=>0, "casesPerOneMillion"=>993, "deathsPerOneMillion"=>28, "tests"=>4012, "testsPerOneMillion"=>37571, "population"=>106784, "continent"=>"North America", "oneCasePerPeople"=>1007, "oneDeathPerPeople"=>35595, "oneTestPerPeople"=>27, "activePerOneMillion"=>37.46, "recoveredPerOneMillion"=>927.11, "criticalPerOneMillion"=>0}
{"updated"=>1594779763590, "country"=>"Australia", "countryInfo"=>{"_id"=>36, "iso2"=>"AU", "iso3"=>"AUS", "lat"=>-27, "long"=>133, "flag"=>"https://disease.sh/assets/img/flags/au.png"}, "cases"=>10487, "todayCases"=>237, "deaths"=>111, "todayDeaths"=>3, "recovered"=>7928, "todayRecovered"=>93, "active"=>2448, "critical"=>28, "casesPerOneMillion"=>411, "deathsPerOneMillion"=>4, "tests"=>3213715, "testsPerOneMillion"=>125977, "population"=>25510278, "continent"=>"Australia/Oceania", "oneCasePerPeople"=>2433, "oneDeathPerPeople"=>229822, "oneTestPerPeople"=>8, "activePerOneMillion"=>95.96, "recoveredPerOneMillion"=>310.78, "criticalPerOneMillion"=>1.1}
{"updated"=>1594779763577, "country"=>"Austria", "countryInfo"=>{"_id"=>40, "iso2"=>"AT", "iso3"=>"AUT", "lat"=>47.3333, "long"=>13.3333, "flag"=>"https://disease.sh/assets/img/flags/at.png"}, "cases"=>19021, "todayCases"=>0, "deaths"=>709, "todayDeaths"=>0, "recovered"=>17073, "todayRecovered"=>0, "active"=>1239, "critical"=>9, "casesPerOneMillion"=>2111, "deathsPerOneMillion"=>79, "tests"=>708128, "testsPerOneMillion"=>78608, "population"=>9008354, "continent"=>"Europe", "oneCasePerPeople"=>474, "oneDeathPerPeople"=>12706, "oneTestPerPeople"=>13, "activePerOneMillion"=>137.54, "recoveredPerOneMillion"=>1895.24, "criticalPerOneMillion"=>1}
{"updated"=>1594779763569, "country"=>"Azerbaijan", "countryInfo"=>{"_id"=>31, "iso2"=>"AZ", "iso3"=>"AZE", "lat"=>40.5, "long"=>47.5, "flag"=>"https://disease.sh/assets/img/flags/az.png"}, "cases"=>25113, "todayCases"=>0, "deaths"=>319, "todayDeaths"=>0, "recovered"=>16150, "todayRecovered"=>0, "active"=>8644, "critical"=>66, "casesPerOneMillion"=>2476, "deathsPerOneMillion"=>31, "tests"=>576249, "testsPerOneMillion"=>56815, "population"=>10142506, "continent"=>"Asia", "oneCasePerPeople"=>404, "oneDeathPerPeople"=>31795, "oneTestPerPeople"=>18, "activePerOneMillion"=>852.25, "recoveredPerOneMillion"=>1592.31, "criticalPerOneMillion"=>6.51}
{"updated"=>1594779763719, "country"=>"Bahamas", "countryInfo"=>{"_id"=>44, "iso2"=>"BS", "iso3"=>"BHS", "lat"=>24.25, "long"=>-76, "flag"=>"https://disease.sh/assets/img/flags/bs.png"}, "cases"=>116, "todayCases"=>3, "deaths"=>11, "todayDeaths"=>0, "recovered"=>91, "todayRecovered"=>0, "active"=>14, "critical"=>1, "casesPerOneMillion"=>295, "deathsPerOneMillion"=>28, "tests"=>2545, "testsPerOneMillion"=>6470, "population"=>393380, "continent"=>"North America", "oneCasePerPeople"=>3391, "oneDeathPerPeople"=>35762, "oneTestPerPeople"=>155, "activePerOneMillion"=>35.59, "recoveredPerOneMillion"=>231.33, "criticalPerOneMillion"=>2.54}
{"updated"=>1594779763558, "country"=>"Bahrain", "countryInfo"=>{"_id"=>48, "iso2"=>"BH", "iso3"=>"BHR", "lat"=>26, "long"=>50.55, "flag"=>"https://disease.sh/assets/img/flags/bh.png"}, "cases"=>34078, "todayCases"=>0, "deaths"=>111, "todayDeaths"=>0, "recovered"=>29753, "todayRecovered"=>0, "active"=>4214, "critical"=>51, "casesPerOneMillion"=>20011, "deathsPerOneMillion"=>65, "tests"=>685318, "testsPerOneMillion"=>402434, "population"=>1702931, "continent"=>"Asia", "oneCasePerPeople"=>50, "oneDeathPerPeople"=>15342, "oneTestPerPeople"=>2, "activePerOneMillion"=>2474.56, "recoveredPerOneMillion"=>17471.64, "criticalPerOneMillion"=>29.95}
{"updated"=>1594779763522, "country"=>"Bangladesh", "countryInfo"=>{"_id"=>50, "iso2"=>"BD", "iso3"=>"BGD", "lat"=>24, "long"=>90, "flag"=>"https://disease.sh/assets/img/flags/bd.png"}, "cases"=>190057, "todayCases"=>0, "deaths"=>2424, "todayDeaths"=>0, "recovered"=>103227, "todayRecovered"=>0, "active"=>84406, "critical"=>1, "casesPerOneMillion"=>1154, "deathsPerOneMillion"=>15, "tests"=>966400, "testsPerOneMillion"=>5866, "population"=>164748373, "continent"=>"Asia", "oneCasePerPeople"=>867, "oneDeathPerPeople"=>67966, "oneTestPerPeople"=>170, "activePerOneMillion"=>512.33, "recoveredPerOneMillion"=>626.57, "criticalPerOneMillion"=>0.01}
{"updated"=>1594779763721, "country"=>"Barbados", "countryInfo"=>{"_id"=>52, "iso2"=>"BB", "iso3"=>"BRB", "lat"=>13.1667, "long"=>-59.5333, "flag"=>"https://disease.sh/assets/img/flags/bb.png"}, "cases"=>103, "todayCases"=>0, "deaths"=>7, "todayDeaths"=>0, "recovered"=>90, "todayRecovered"=>0, "active"=>6, "critical"=>0, "casesPerOneMillion"=>358, "deathsPerOneMillion"=>24, "tests"=>9026, "testsPerOneMillion"=>31407, "population"=>287389, "continent"=>"North America", "oneCasePerPeople"=>2790, "oneDeathPerPeople"=>41056, "oneTestPerPeople"=>32, "activePerOneMillion"=>20.88, "recoveredPerOneMillion"=>313.16, "criticalPerOneMillion"=>0}
{"updated"=>1594779763537, "country"=>"Belarus", "countryInfo"=>{"_id"=>112, "iso2"=>"BY", "iso3"=>"BLR", "lat"=>53, "long"=>28, "flag"=>"https://disease.sh/assets/img/flags/by.png"}, "cases"=>65269, "todayCases"=>0, "deaths"=>474, "todayDeaths"=>0, "recovered"=>55799, "todayRecovered"=>0, "active"=>8996, "critical"=>89, "casesPerOneMillion"=>6907, "deathsPerOneMillion"=>50, "tests"=>1144696, "testsPerOneMillion"=>121142, "population"=>9449196, "continent"=>"Europe", "oneCasePerPeople"=>145, "oneDeathPerPeople"=>19935, "oneTestPerPeople"=>8, "activePerOneMillion"=>952.04, "recoveredPerOneMillion"=>5905.16, "criticalPerOneMillion"=>9.42}
{"updated"=>1594779763538, "country"=>"Belgium", "countryInfo"=>{"_id"=>56, "iso2"=>"BE", "iso3"=>"BEL", "lat"=>50.8333, "long"=>4, "flag"=>"https://disease.sh/assets/img/flags/be.png"}, "cases"=>62781, "todayCases"=>0, "deaths"=>9787, "todayDeaths"=>0, "recovered"=>17223, "todayRecovered"=>0, "active"=>35771, "critical"=>23, "casesPerOneMillion"=>5416, "deathsPerOneMillion"=>844, "tests"=>1390593, "testsPerOneMillion"=>119966, "population"=>11591576, "continent"=>"Europe", "oneCasePerPeople"=>185, "oneDeathPerPeople"=>1184, "oneTestPerPeople"=>8, "activePerOneMillion"=>3085.95, "recoveredPerOneMillion"=>1485.82, "criticalPerOneMillion"=>1.98}
{"updated"=>1594779763736, "country"=>"Belize", "countryInfo"=>{"_id"=>84, "iso2"=>"BZ", "iso3"=>"BLZ", "lat"=>17.25, "long"=>-88.75, "flag"=>"https://disease.sh/assets/img/flags/bz.png"}, "cases"=>39, "todayCases"=>0, "deaths"=>2, "todayDeaths"=>0, "recovered"=>21, "todayRecovered"=>0, "active"=>16, "critical"=>0, "casesPerOneMillion"=>98, "deathsPerOneMillion"=>5, "tests"=>2665, "testsPerOneMillion"=>6698, "population"=>397857, "continent"=>"North America", "oneCasePerPeople"=>10201, "oneDeathPerPeople"=>198929, "oneTestPerPeople"=>149, "activePerOneMillion"=>40.22, "recoveredPerOneMillion"=>52.78, "criticalPerOneMillion"=>0}
{"updated"=>1594779763666, "country"=>"Benin", "countryInfo"=>{"_id"=>204, "iso2"=>"BJ", "iso3"=>"BEN", "lat"=>9.5, "long"=>2.25, "flag"=>"https://disease.sh/assets/img/flags/bj.png"}, "cases"=>1378, "todayCases"=>0, "deaths"=>26, "todayDeaths"=>0, "recovered"=>557, "todayRecovered"=>0, "active"=>795, "critical"=>1, "casesPerOneMillion"=>114, "deathsPerOneMillion"=>2, "tests"=>67622, "testsPerOneMillion"=>5574, "population"=>12131954, "continent"=>"Africa", "oneCasePerPeople"=>8804, "oneDeathPerPeople"=>466614, "oneTestPerPeople"=>179, "activePerOneMillion"=>65.53, "recoveredPerOneMillion"=>45.91, "criticalPerOneMillion"=>0.08}
{"updated"=>1594779763716, "country"=>"Bermuda", "countryInfo"=>{"_id"=>60, "iso2"=>"BM", "iso3"=>"BMU", "lat"=>32.3333, "long"=>-64.75, "flag"=>"https://disease.sh/assets/img/flags/bm.png"}, "cases"=>150, "todayCases"=>0, "deaths"=>9, "todayDeaths"=>0, "recovered"=>137, "todayRecovered"=>0, "active"=>4, "critical"=>1, "casesPerOneMillion"=>2409, "deathsPerOneMillion"=>145, "tests"=>14467, "testsPerOneMillion"=>232334, "population"=>62268, "continent"=>"North America", "oneCasePerPeople"=>415, "oneDeathPerPeople"=>6919, "oneTestPerPeople"=>4, "activePerOneMillion"=>64.24, "recoveredPerOneMillion"=>2200.17, "criticalPerOneMillion"=>16.06}
{"updated"=>1594779763727, "country"=>"Bhutan", "countryInfo"=>{"_id"=>64, "iso2"=>"BT", "iso3"=>"BTN", "lat"=>27.5, "long"=>90.5, "flag"=>"https://disease.sh/assets/img/flags/bt.png"}, "cases"=>84, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>78, "todayRecovered"=>0, "active"=>6, "critical"=>0, "casesPerOneMillion"=>109, "deathsPerOneMillion"=>0, "tests"=>36867, "testsPerOneMillion"=>47761, "population"=>771909, "continent"=>"Asia", "oneCasePerPeople"=>9189, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>21, "activePerOneMillion"=>7.77, "recoveredPerOneMillion"=>101.05, "criticalPerOneMillion"=>0}
{"updated"=>1594779763548, "country"=>"Bolivia", "countryInfo"=>{"_id"=>68, "iso2"=>"BO", "iso3"=>"BOL", "lat"=>-17, "long"=>-65, "flag"=>"https://disease.sh/assets/img/flags/bo.png"}, "cases"=>50867, "todayCases"=>1617, "deaths"=>1898, "todayDeaths"=>32, "recovered"=>15819, "todayRecovered"=>525, "active"=>33150, "critical"=>71, "casesPerOneMillion"=>4356, "deathsPerOneMillion"=>163, "tests"=>111416, "testsPerOneMillion"=>9540, "population"=>11678450, "continent"=>"South America", "oneCasePerPeople"=>230, "oneDeathPerPeople"=>6153, "oneTestPerPeople"=>105, "activePerOneMillion"=>2838.56, "recoveredPerOneMillion"=>1354.55, "criticalPerOneMillion"=>6.08}
{"updated"=>1594779763606, "country"=>"Bosnia", "countryInfo"=>{"_id"=>70, "iso2"=>"BA", "iso3"=>"BIH", "lat"=>44, "long"=>18, "flag"=>"https://disease.sh/assets/img/flags/ba.png"}, "cases"=>6981, "todayCases"=>0, "deaths"=>226, "todayDeaths"=>0, "recovered"=>3179, "todayRecovered"=>0, "active"=>3576, "critical"=>4, "casesPerOneMillion"=>2128, "deathsPerOneMillion"=>69, "tests"=>111536, "testsPerOneMillion"=>34006, "population"=>3279925, "continent"=>"Europe", "oneCasePerPeople"=>470, "oneDeathPerPeople"=>14513, "oneTestPerPeople"=>29, "activePerOneMillion"=>1090.27, "recoveredPerOneMillion"=>969.23, "criticalPerOneMillion"=>1.22}
{"updated"=>1594779763699, "country"=>"Botswana", "countryInfo"=>{"_id"=>72, "iso2"=>"BW", "iso3"=>"BWA", "lat"=>-22, "long"=>24, "flag"=>"https://disease.sh/assets/img/flags/bw.png"}, "cases"=>399, "todayCases"=>0, "deaths"=>1, "todayDeaths"=>0, "recovered"=>38, "todayRecovered"=>0, "active"=>360, "critical"=>1, "casesPerOneMillion"=>170, "deathsPerOneMillion"=>0.4, "tests"=>51379, "testsPerOneMillion"=>21835, "population"=>2353086, "continent"=>"Africa", "oneCasePerPeople"=>5897, "oneDeathPerPeople"=>2353086, "oneTestPerPeople"=>46, "activePerOneMillion"=>152.99, "recoveredPerOneMillion"=>16.15, "criticalPerOneMillion"=>0.42}
{"updated"=>1594779763497, "country"=>"Brazil", "countryInfo"=>{"_id"=>76, "iso2"=>"BR", "iso3"=>"BRA", "lat"=>-10, "long"=>-55, "flag"=>"https://disease.sh/assets/img/flags/br.png"}, "cases"=>1931204, "todayCases"=>0, "deaths"=>74262, "todayDeaths"=>0, "recovered"=>1213512, "todayRecovered"=>0, "active"=>643430, "critical"=>8318, "casesPerOneMillion"=>9083, "deathsPerOneMillion"=>349, "tests"=>4572796, "testsPerOneMillion"=>21507, "population"=>212615886, "continent"=>"South America", "oneCasePerPeople"=>110, "oneDeathPerPeople"=>2863, "oneTestPerPeople"=>46, "activePerOneMillion"=>3026.26, "recoveredPerOneMillion"=>5707.53, "criticalPerOneMillion"=>39.12}
{"updated"=>1594779763754, "country"=>"British Virgin Islands", "countryInfo"=>{"_id"=>92, "iso2"=>"VG", "iso3"=>"VGB", "lat"=>18.5, "long"=>-64.5, "flag"=>"https://disease.sh/assets/img/flags/vg.png"}, "cases"=>8, "todayCases"=>0, "deaths"=>1, "todayDeaths"=>0, "recovered"=>7, "todayRecovered"=>0, "active"=>0, "critical"=>0, "casesPerOneMillion"=>265, "deathsPerOneMillion"=>33, "tests"=>439, "testsPerOneMillion"=>14518, "population"=>30239, "continent"=>"North America", "oneCasePerPeople"=>3780, "oneDeathPerPeople"=>30239, "oneTestPerPeople"=>69, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>231.49, "criticalPerOneMillion"=>0}
{"updated"=>1594779763717, "country"=>"Brunei", "countryInfo"=>{"_id"=>96, "iso2"=>"BN", "iso3"=>"BRN", "lat"=>4.5, "long"=>114.6667, "flag"=>"https://disease.sh/assets/img/flags/bn.png"}, "cases"=>141, "todayCases"=>0, "deaths"=>3, "todayDeaths"=>0, "recovered"=>138, "todayRecovered"=>0, "active"=>0, "critical"=>0, "casesPerOneMillion"=>322, "deathsPerOneMillion"=>7, "tests"=>29841, "testsPerOneMillion"=>68188, "population"=>437630, "continent"=>"Asia", "oneCasePerPeople"=>3104, "oneDeathPerPeople"=>145877, "oneTestPerPeople"=>15, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>315.33, "criticalPerOneMillion"=>0}
{"updated"=>1594779763603, "country"=>"Bulgaria", "countryInfo"=>{"_id"=>100, "iso2"=>"BG", "iso3"=>"BGR", "lat"=>43, "long"=>25, "flag"=>"https://disease.sh/assets/img/flags/bg.png"}, "cases"=>7645, "todayCases"=>0, "deaths"=>283, "todayDeaths"=>0, "recovered"=>3663, "todayRecovered"=>0, "active"=>3699, "critical"=>27, "casesPerOneMillion"=>1101, "deathsPerOneMillion"=>41, "tests"=>184560, "testsPerOneMillion"=>26570, "population"=>6946122, "continent"=>"Europe", "oneCasePerPeople"=>909, "oneDeathPerPeople"=>24545, "oneTestPerPeople"=>38, "activePerOneMillion"=>532.53, "recoveredPerOneMillion"=>527.34, "criticalPerOneMillion"=>3.89}
{"updated"=>1594779763676, "country"=>"Burkina Faso", "countryInfo"=>{"_id"=>854, "iso2"=>"BF", "iso3"=>"BFA", "lat"=>13, "long"=>-2, "flag"=>"https://disease.sh/assets/img/flags/bf.png"}, "cases"=>1037, "todayCases"=>0, "deaths"=>53, "todayDeaths"=>0, "recovered"=>873, "todayRecovered"=>0, "active"=>111, "critical"=>0, "casesPerOneMillion"=>50, "deathsPerOneMillion"=>3, "tests"=>0, "testsPerOneMillion"=>0, "population"=>20918698, "continent"=>"Africa", "oneCasePerPeople"=>20172, "oneDeathPerPeople"=>394692, "oneTestPerPeople"=>0, "activePerOneMillion"=>5.31, "recoveredPerOneMillion"=>41.73, "criticalPerOneMillion"=>0}
{"updated"=>1594779763707, "country"=>"Burundi", "countryInfo"=>{"_id"=>108, "iso2"=>"BI", "iso3"=>"BDI", "lat"=>-3.5, "long"=>30, "flag"=>"https://disease.sh/assets/img/flags/bi.png"}, "cases"=>269, "todayCases"=>0, "deaths"=>1, "todayDeaths"=>0, "recovered"=>207, "todayRecovered"=>0, "active"=>61, "critical"=>0, "casesPerOneMillion"=>23, "deathsPerOneMillion"=>0.08, "tests"=>6697, "testsPerOneMillion"=>563, "population"=>11899864, "continent"=>"Africa", "oneCasePerPeople"=>44237, "oneDeathPerPeople"=>11899864, "oneTestPerPeople"=>1777, "activePerOneMillion"=>5.13, "recoveredPerOneMillion"=>17.4, "criticalPerOneMillion"=>0}
{"updated"=>1594779763657, "country"=>"Cabo Verde", "countryInfo"=>{"_id"=>132, "iso2"=>"CV", "iso3"=>"CPV", "lat"=>16, "long"=>-24, "flag"=>"https://disease.sh/assets/img/flags/cv.png"}, "cases"=>1722, "todayCases"=>0, "deaths"=>19, "todayDeaths"=>0, "recovered"=>772, "todayRecovered"=>0, "active"=>931, "critical"=>0, "casesPerOneMillion"=>3096, "deathsPerOneMillion"=>34, "tests"=>40475, "testsPerOneMillion"=>72770, "population"=>556201, "continent"=>"Africa", "oneCasePerPeople"=>323, "oneDeathPerPeople"=>29274, "oneTestPerPeople"=>14, "activePerOneMillion"=>1673.86, "recoveredPerOneMillion"=>1387.99, "criticalPerOneMillion"=>0}
{"updated"=>1594779763715, "country"=>"Cambodia", "countryInfo"=>{"_id"=>116, "iso2"=>"KH", "iso3"=>"KHM", "lat"=>13, "long"=>105, "flag"=>"https://disease.sh/assets/img/flags/kh.png"}, "cases"=>165, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>133, "todayRecovered"=>0, "active"=>32, "critical"=>1, "casesPerOneMillion"=>10, "deathsPerOneMillion"=>0, "tests"=>47702, "testsPerOneMillion"=>2852, "population"=>16726831, "continent"=>"Asia", "oneCasePerPeople"=>101375, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>351, "activePerOneMillion"=>1.91, "recoveredPerOneMillion"=>7.95, "criticalPerOneMillion"=>0.06}
{"updated"=>1594779763582, "country"=>"Cameroon", "countryInfo"=>{"_id"=>120, "iso2"=>"CM", "iso3"=>"CMR", "lat"=>6, "long"=>12, "flag"=>"https://disease.sh/assets/img/flags/cm.png"}, "cases"=>15173, "todayCases"=>0, "deaths"=>359, "todayDeaths"=>0, "recovered"=>11928, "todayRecovered"=>0, "active"=>2886, "critical"=>52, "casesPerOneMillion"=>571, "deathsPerOneMillion"=>14, "tests"=>120837, "testsPerOneMillion"=>4549, "population"=>26564536, "continent"=>"Africa", "oneCasePerPeople"=>1751, "oneDeathPerPeople"=>73996, "oneTestPerPeople"=>220, "activePerOneMillion"=>108.64, "recoveredPerOneMillion"=>449.02, "criticalPerOneMillion"=>1.96}
{"updated"=>1594779763526, "country"=>"Canada", "countryInfo"=>{"_id"=>124, "iso2"=>"CA", "iso3"=>"CAN", "lat"=>60, "long"=>-95, "flag"=>"https://disease.sh/assets/img/flags/ca.png"}, "cases"=>108486, "todayCases"=>0, "deaths"=>8798, "todayDeaths"=>0, "recovered"=>72170, "todayRecovered"=>0, "active"=>27518, "critical"=>2170, "casesPerOneMillion"=>2873, "deathsPerOneMillion"=>233, "tests"=>3302483, "testsPerOneMillion"=>87473, "population"=>37754249, "continent"=>"North America", "oneCasePerPeople"=>348, "oneDeathPerPeople"=>4291, "oneTestPerPeople"=>11, "activePerOneMillion"=>728.87, "recoveredPerOneMillion"=>1911.57, "criticalPerOneMillion"=>57.48}
{"updated"=>1594779763755, "country"=>"Caribbean Netherlands", "countryInfo"=>{"_id"=>535, "iso2"=>"BQ", "iso3"=>"BES", "lat"=>12.2, "long"=>-68.26, "flag"=>"https://disease.sh/assets/img/flags/bq.png"}, "cases"=>7, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>7, "todayRecovered"=>0, "active"=>0, "critical"=>0, "casesPerOneMillion"=>267, "deathsPerOneMillion"=>0, "tests"=>424, "testsPerOneMillion"=>16163, "population"=>26232, "continent"=>"North America", "oneCasePerPeople"=>3747, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>62, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>266.85, "criticalPerOneMillion"=>0}
{"updated"=>1594779763712, "country"=>"Cayman Islands", "countryInfo"=>{"_id"=>136, "iso2"=>"KY", "iso3"=>"CYM", "lat"=>19.5, "long"=>-80.5, "flag"=>"https://disease.sh/assets/img/flags/ky.png"}, "cases"=>203, "todayCases"=>0, "deaths"=>1, "todayDeaths"=>0, "recovered"=>200, "todayRecovered"=>0, "active"=>2, "critical"=>0, "casesPerOneMillion"=>3087, "deathsPerOneMillion"=>15, "tests"=>26919, "testsPerOneMillion"=>409421, "population"=>65749, "continent"=>"North America", "oneCasePerPeople"=>324, "oneDeathPerPeople"=>65749, "oneTestPerPeople"=>2, "activePerOneMillion"=>30.42, "recoveredPerOneMillion"=>3041.87, "criticalPerOneMillion"=>0}
{"updated"=>1594779763620, "country"=>"Central African Republic", "countryInfo"=>{"_id"=>140, "iso2"=>"CF", "iso3"=>"CAF", "lat"=>7, "long"=>21, "flag"=>"https://disease.sh/assets/img/flags/cf.png"}, "cases"=>4356, "todayCases"=>0, "deaths"=>53, "todayDeaths"=>0, "recovered"=>1229, "todayRecovered"=>0, "active"=>3074, "critical"=>2, "casesPerOneMillion"=>901, "deathsPerOneMillion"=>11, "tests"=>27561, "testsPerOneMillion"=>5703, "population"=>4832469, "continent"=>"Africa", "oneCasePerPeople"=>1109, "oneDeathPerPeople"=>91179, "oneTestPerPeople"=>175, "activePerOneMillion"=>636.11, "recoveredPerOneMillion"=>254.32, "criticalPerOneMillion"=>0.41}
{"updated"=>1594779763682, "country"=>"Chad", "countryInfo"=>{"_id"=>148, "iso2"=>"TD", "iso3"=>"TCD", "lat"=>15, "long"=>19, "flag"=>"https://disease.sh/assets/img/flags/td.png"}, "cases"=>884, "todayCases"=>0, "deaths"=>75, "todayDeaths"=>0, "recovered"=>798, "todayRecovered"=>0, "active"=>11, "critical"=>0, "casesPerOneMillion"=>54, "deathsPerOneMillion"=>5, "tests"=>0, "testsPerOneMillion"=>0, "population"=>16438226, "continent"=>"Africa", "oneCasePerPeople"=>18595, "oneDeathPerPeople"=>219176, "oneTestPerPeople"=>0, "activePerOneMillion"=>0.67, "recoveredPerOneMillion"=>48.55, "criticalPerOneMillion"=>0}
{"updated"=>1594779763694, "country"=>"Channel Islands", "countryInfo"=>{"_id"=>832, "iso2"=>"JE", "iso3"=>"JEY", "lat"=>49.21, "long"=>-2.13, "flag"=>"https://disease.sh/assets/img/flags/je.png"}, "cases"=>581, "todayCases"=>0, "deaths"=>47, "todayDeaths"=>0, "recovered"=>512, "todayRecovered"=>0, "active"=>22, "critical"=>0, "casesPerOneMillion"=>3341, "deathsPerOneMillion"=>270, "tests"=>21410, "testsPerOneMillion"=>123102, "population"=>173921, "continent"=>"Europe", "oneCasePerPeople"=>299, "oneDeathPerPeople"=>3700, "oneTestPerPeople"=>8, "activePerOneMillion"=>126.49, "recoveredPerOneMillion"=>2943.87, "criticalPerOneMillion"=>0}
{"updated"=>1594779763503, "country"=>"Chile", "countryInfo"=>{"_id"=>152, "iso2"=>"CL", "iso3"=>"CHL", "lat"=>-30, "long"=>-71, "flag"=>"https://disease.sh/assets/img/flags/cl.png"}, "cases"=>319493, "todayCases"=>0, "deaths"=>7069, "todayDeaths"=>0, "recovered"=>289220, "todayRecovered"=>0, "active"=>23204, "critical"=>1915, "casesPerOneMillion"=>16708, "deathsPerOneMillion"=>370, "tests"=>1322503, "testsPerOneMillion"=>69161, "population"=>19122213, "continent"=>"South America", "oneCasePerPeople"=>60, "oneDeathPerPeople"=>2705, "oneTestPerPeople"=>14, "activePerOneMillion"=>1213.46, "recoveredPerOneMillion"=>15124.82, "criticalPerOneMillion"=>100.15}
{"updated"=>1594779763758, "country"=>"China", "countryInfo"=>{"_id"=>156, "iso2"=>"CN", "iso3"=>"CHN", "lat"=>35, "long"=>105, "flag"=>"https://disease.sh/assets/img/flags/cn.png"}, "cases"=>83611, "todayCases"=>6, "deaths"=>4634, "todayDeaths"=>0, "recovered"=>78693, "todayRecovered"=>19, "active"=>284, "critical"=>3, "casesPerOneMillion"=>58, "deathsPerOneMillion"=>3, "tests"=>90410000, "testsPerOneMillion"=>62814, "population"=>1439323776, "continent"=>"Asia", "oneCasePerPeople"=>17215, "oneDeathPerPeople"=>310601, "oneTestPerPeople"=>16, "activePerOneMillion"=>0.2, "recoveredPerOneMillion"=>54.67, "criticalPerOneMillion"=>0}
{"updated"=>1594779763525, "country"=>"Colombia", "countryInfo"=>{"_id"=>170, "iso2"=>"CO", "iso3"=>"COL", "lat"=>4, "long"=>-72, "flag"=>"https://disease.sh/assets/img/flags/co.png"}, "cases"=>159898, "todayCases"=>0, "deaths"=>5625, "todayDeaths"=>0, "recovered"=>68806, "todayRecovered"=>0, "active"=>85467, "critical"=>875, "casesPerOneMillion"=>3141, "deathsPerOneMillion"=>111, "tests"=>1082415, "testsPerOneMillion"=>21265, "population"=>50902201, "continent"=>"South America", "oneCasePerPeople"=>318, "oneDeathPerPeople"=>9049, "oneTestPerPeople"=>47, "activePerOneMillion"=>1679.04, "recoveredPerOneMillion"=>1351.73, "criticalPerOneMillion"=>17.19}
{"updated"=>1594779763705, "country"=>"Comoros", "countryInfo"=>{"_id"=>174, "iso2"=>"KM", "iso3"=>"COM", "lat"=>-12.1667, "long"=>44.25, "flag"=>"https://disease.sh/assets/img/flags/km.png"}, "cases"=>321, "todayCases"=>0, "deaths"=>7, "todayDeaths"=>0, "recovered"=>302, "todayRecovered"=>0, "active"=>12, "critical"=>0, "casesPerOneMillion"=>369, "deathsPerOneMillion"=>8, "tests"=>0, "testsPerOneMillion"=>0, "population"=>870160, "continent"=>"Africa", "oneCasePerPeople"=>2711, "oneDeathPerPeople"=>124309, "oneTestPerPeople"=>0, "activePerOneMillion"=>13.79, "recoveredPerOneMillion"=>347.06, "criticalPerOneMillion"=>0}
{"updated"=>1594779763645, "country"=>"Congo", "countryInfo"=>{"_id"=>178, "iso2"=>"CG", "iso3"=>"COG", "lat"=>-1, "long"=>15, "flag"=>"https://disease.sh/assets/img/flags/cg.png"}, "cases"=>2028, "todayCases"=>0, "deaths"=>47, "todayDeaths"=>0, "recovered"=>589, "todayRecovered"=>0, "active"=>1392, "critical"=>0, "casesPerOneMillion"=>367, "deathsPerOneMillion"=>9, "tests"=>0, "testsPerOneMillion"=>0, "population"=>5521945, "continent"=>"Africa", "oneCasePerPeople"=>2723, "oneDeathPerPeople"=>117488, "oneTestPerPeople"=>0, "activePerOneMillion"=>252.09, "recoveredPerOneMillion"=>106.67, "criticalPerOneMillion"=>0}
{"updated"=>1594779763597, "country"=>"Costa Rica", "countryInfo"=>{"_id"=>188, "iso2"=>"CR", "iso3"=>"CRI", "lat"=>10, "long"=>-84, "flag"=>"https://disease.sh/assets/img/flags/cr.png"}, "cases"=>8482, "todayCases"=>0, "deaths"=>37, "todayDeaths"=>1, "recovered"=>2441, "todayRecovered"=>0, "active"=>6004, "critical"=>30, "casesPerOneMillion"=>1665, "deathsPerOneMillion"=>7, "tests"=>61216, "testsPerOneMillion"=>12013, "population"=>5095810, "continent"=>"North America", "oneCasePerPeople"=>601, "oneDeathPerPeople"=>137725, "oneTestPerPeople"=>83, "activePerOneMillion"=>1178.22, "recoveredPerOneMillion"=>479.02, "criticalPerOneMillion"=>5.89}
{"updated"=>1594779763624, "country"=>"Croatia", "countryInfo"=>{"_id"=>191, "iso2"=>"HR", "iso3"=>"HRV", "lat"=>45.1667, "long"=>15.5, "flag"=>"https://disease.sh/assets/img/flags/hr.png"}, "cases"=>3827, "todayCases"=>0, "deaths"=>120, "todayDeaths"=>0, "recovered"=>2558, "todayRecovered"=>0, "active"=>1149, "critical"=>5, "casesPerOneMillion"=>932, "deathsPerOneMillion"=>29, "tests"=>95920, "testsPerOneMillion"=>23371, "population"=>4104159, "continent"=>"Europe", "oneCasePerPeople"=>1072, "oneDeathPerPeople"=>34201, "oneTestPerPeople"=>43, "activePerOneMillion"=>279.96, "recoveredPerOneMillion"=>623.27, "criticalPerOneMillion"=>1.22}
{"updated"=>1594779763640, "country"=>"Cuba", "countryInfo"=>{"_id"=>192, "iso2"=>"CU", "iso3"=>"CUB", "lat"=>21.5, "long"=>-80, "flag"=>"https://disease.sh/assets/img/flags/cu.png"}, "cases"=>2432, "todayCases"=>0, "deaths"=>87, "todayDeaths"=>0, "recovered"=>2275, "todayRecovered"=>0, "active"=>70, "critical"=>2, "casesPerOneMillion"=>215, "deathsPerOneMillion"=>8, "tests"=>211427, "testsPerOneMillion"=>18667, "population"=>11326332, "continent"=>"North America", "oneCasePerPeople"=>4657, "oneDeathPerPeople"=>130188, "oneTestPerPeople"=>54, "activePerOneMillion"=>6.18, "recoveredPerOneMillion"=>200.86, "criticalPerOneMillion"=>0.18}
{"updated"=>1594779763739, "country"=>"Curaçao", "countryInfo"=>{"_id"=>531, "iso2"=>"CW", "iso3"=>"CUW", "lat"=>12.15, "long"=>-68.97, "flag"=>"https://disease.sh/assets/img/flags/cw.png"}, "cases"=>25, "todayCases"=>0, "deaths"=>1, "todayDeaths"=>0, "recovered"=>24, "todayRecovered"=>0, "active"=>0, "critical"=>0, "casesPerOneMillion"=>152, "deathsPerOneMillion"=>6, "tests"=>1080, "testsPerOneMillion"=>6581, "population"=>164119, "continent"=>"North America", "oneCasePerPeople"=>6565, "oneDeathPerPeople"=>164119, "oneTestPerPeople"=>152, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>146.24, "criticalPerOneMillion"=>0}
{"updated"=>1594779763678, "country"=>"Cyprus", "countryInfo"=>{"_id"=>196, "iso2"=>"CY", "iso3"=>"CYP", "lat"=>35, "long"=>33, "flag"=>"https://disease.sh/assets/img/flags/cy.png"}, "cases"=>1023, "todayCases"=>0, "deaths"=>19, "todayDeaths"=>0, "recovered"=>839, "todayRecovered"=>0, "active"=>165, "critical"=>0, "casesPerOneMillion"=>847, "deathsPerOneMillion"=>16, "tests"=>167394, "testsPerOneMillion"=>138607, "population"=>1207687, "continent"=>"Asia", "oneCasePerPeople"=>1181, "oneDeathPerPeople"=>63562, "oneTestPerPeople"=>7, "activePerOneMillion"=>136.62, "recoveredPerOneMillion"=>694.72, "criticalPerOneMillion"=>0}
{"updated"=>1594779763585, "country"=>"Czechia", "countryInfo"=>{"_id"=>203, "iso2"=>"CZ", "iso3"=>"CZE", "lat"=>49.75, "long"=>15.5, "flag"=>"https://disease.sh/assets/img/flags/cz.png"}, "cases"=>13341, "todayCases"=>0, "deaths"=>355, "todayDeaths"=>0, "recovered"=>8441, "todayRecovered"=>0, "active"=>4545, "critical"=>21, "casesPerOneMillion"=>1246, "deathsPerOneMillion"=>33, "tests"=>602670, "testsPerOneMillion"=>56273, "population"=>10709775, "continent"=>"Europe", "oneCasePerPeople"=>803, "oneDeathPerPeople"=>30168, "oneTestPerPeople"=>18, "activePerOneMillion"=>424.38, "recoveredPerOneMillion"=>788.16, "criticalPerOneMillion"=>1.96}
{"updated"=>1594779763587, "country"=>"Côte d'Ivoire", "countryInfo"=>{"_id"=>384, "iso2"=>"CI", "iso3"=>"CIV", "lat"=>8, "long"=>-5, "flag"=>"https://disease.sh/assets/img/flags/ci.png"}, "cases"=>13037, "todayCases"=>0, "deaths"=>87, "todayDeaths"=>0, "recovered"=>6908, "todayRecovered"=>0, "active"=>6042, "critical"=>0, "casesPerOneMillion"=>494, "deathsPerOneMillion"=>3, "tests"=>78066, "testsPerOneMillion"=>2957, "population"=>26396778, "continent"=>"Africa", "oneCasePerPeople"=>2025, "oneDeathPerPeople"=>303411, "oneTestPerPeople"=>338, "activePerOneMillion"=>228.89, "recoveredPerOneMillion"=>261.7, "criticalPerOneMillion"=>0}
{"updated"=>1594779763601, "country"=>"DRC", "countryInfo"=>{"_id"=>180, "iso2"=>"CD", "iso3"=>"COD", "lat"=>0, "long"=>25, "flag"=>"https://disease.sh/assets/img/flags/cd.png"}, "cases"=>8135, "todayCases"=>0, "deaths"=>190, "todayDeaths"=>0, "recovered"=>3948, "todayRecovered"=>0, "active"=>3997, "critical"=>0, "casesPerOneMillion"=>91, "deathsPerOneMillion"=>2, "tests"=>0, "testsPerOneMillion"=>0, "population"=>89630305, "continent"=>"Africa", "oneCasePerPeople"=>11018, "oneDeathPerPeople"=>471738, "oneTestPerPeople"=>0, "activePerOneMillion"=>44.59, "recoveredPerOneMillion"=>44.05, "criticalPerOneMillion"=>0}
{"updated"=>1594779763586, "country"=>"Denmark", "countryInfo"=>{"_id"=>208, "iso2"=>"DK", "iso3"=>"DNK", "lat"=>56, "long"=>10, "flag"=>"https://disease.sh/assets/img/flags/dk.png"}, "cases"=>13061, "todayCases"=>0, "deaths"=>610, "todayDeaths"=>0, "recovered"=>12160, "todayRecovered"=>0, "active"=>291, "critical"=>3, "casesPerOneMillion"=>2255, "deathsPerOneMillion"=>105, "tests"=>1257157, "testsPerOneMillion"=>217013, "population"=>5793000, "continent"=>"Europe", "oneCasePerPeople"=>444, "oneDeathPerPeople"=>9497, "oneTestPerPeople"=>5, "activePerOneMillion"=>50.23, "recoveredPerOneMillion"=>2099.09, "criticalPerOneMillion"=>0.52}
{"updated"=>1594779763690, "country"=>"Diamond Princess", "countryInfo"=>{"_id"=>nil, "iso2"=>nil, "iso3"=>nil, "lat"=>0, "long"=>0, "flag"=>"https://disease.sh/assets/img/flags/unknown.png"}, "cases"=>712, "todayCases"=>0, "deaths"=>13, "todayDeaths"=>0, "recovered"=>651, "todayRecovered"=>0, "active"=>48, "critical"=>4, "casesPerOneMillion"=>0, "deathsPerOneMillion"=>0, "tests"=>0, "testsPerOneMillion"=>0, "population"=>0, "continent"=>"", "oneCasePerPeople"=>0, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>0, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>0, "criticalPerOneMillion"=>0}
{"updated"=>1594779763618, "country"=>"Djibouti", "countryInfo"=>{"_id"=>262, "iso2"=>"DJ", "iso3"=>"DJI", "lat"=>11.5, "long"=>43, "flag"=>"https://disease.sh/assets/img/flags/dj.png"}, "cases"=>4979, "todayCases"=>0, "deaths"=>56, "todayDeaths"=>0, "recovered"=>4743, "todayRecovered"=>0, "active"=>180, "critical"=>0, "casesPerOneMillion"=>5037, "deathsPerOneMillion"=>57, "tests"=>51843, "testsPerOneMillion"=>52447, "population"=>988483, "continent"=>"Africa", "oneCasePerPeople"=>199, "oneDeathPerPeople"=>17651, "oneTestPerPeople"=>19, "activePerOneMillion"=>182.1, "recoveredPerOneMillion"=>4798.26, "criticalPerOneMillion"=>0}
{"updated"=>1594779763745, "country"=>"Dominica", "countryInfo"=>{"_id"=>212, "iso2"=>"DM", "iso3"=>"DMA", "lat"=>15.4167, "long"=>-61.3333, "flag"=>"https://disease.sh/assets/img/flags/dm.png"}, "cases"=>18, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>18, "todayRecovered"=>0, "active"=>0, "critical"=>0, "casesPerOneMillion"=>250, "deathsPerOneMillion"=>0, "tests"=>623, "testsPerOneMillion"=>8654, "population"=>71993, "continent"=>"North America", "oneCasePerPeople"=>4000, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>116, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>250.02, "criticalPerOneMillion"=>0}
{"updated"=>1594779763553, "country"=>"Dominican Republic", "countryInfo"=>{"_id"=>214, "iso2"=>"DO", "iso3"=>"DOM", "lat"=>19, "long"=>-70.6667, "flag"=>"https://disease.sh/assets/img/flags/do.png"}, "cases"=>46305, "todayCases"=>0, "deaths"=>910, "todayDeaths"=>0, "recovered"=>23134, "todayRecovered"=>0, "active"=>22261, "critical"=>226, "casesPerOneMillion"=>4267, "deathsPerOneMillion"=>84, "tests"=>189391, "testsPerOneMillion"=>17452, "population"=>10851818, "continent"=>"North America", "oneCasePerPeople"=>234, "oneDeathPerPeople"=>11925, "oneTestPerPeople"=>57, "activePerOneMillion"=>2051.36, "recoveredPerOneMillion"=>2131.81, "criticalPerOneMillion"=>20.83}
{"updated"=>1594779763536, "country"=>"Ecuador", "countryInfo"=>{"_id"=>218, "iso2"=>"EC", "iso3"=>"ECU", "lat"=>-2, "long"=>-77.5, "flag"=>"https://disease.sh/assets/img/flags/ec.png"}, "cases"=>69570, "todayCases"=>0, "deaths"=>5130, "todayDeaths"=>0, "recovered"=>30484, "todayRecovered"=>0, "active"=>33956, "critical"=>313, "casesPerOneMillion"=>3941, "deathsPerOneMillion"=>291, "tests"=>186879, "testsPerOneMillion"=>10587, "population"=>17651979, "continent"=>"South America", "oneCasePerPeople"=>254, "oneDeathPerPeople"=>3441, "oneTestPerPeople"=>94, "activePerOneMillion"=>1923.64, "recoveredPerOneMillion"=>1726.95, "criticalPerOneMillion"=>17.73}
{"updated"=>1594779763531, "country"=>"Egypt", "countryInfo"=>{"_id"=>818, "iso2"=>"EG", "iso3"=>"EGY", "lat"=>27, "long"=>30, "flag"=>"https://disease.sh/assets/img/flags/eg.png"}, "cases"=>83930, "todayCases"=>0, "deaths"=>4008, "todayDeaths"=>0, "recovered"=>25544, "todayRecovered"=>0, "active"=>54378, "critical"=>41, "casesPerOneMillion"=>820, "deathsPerOneMillion"=>39, "tests"=>135000, "testsPerOneMillion"=>1318, "population"=>102395050, "continent"=>"Africa", "oneCasePerPeople"=>1220, "oneDeathPerPeople"=>25548, "oneTestPerPeople"=>758, "activePerOneMillion"=>531.06, "recoveredPerOneMillion"=>249.47, "criticalPerOneMillion"=>0.4}
{"updated"=>1594779763593, "country"=>"El Salvador", "countryInfo"=>{"_id"=>222, "iso2"=>"SV", "iso3"=>"SLV", "lat"=>13.8333, "long"=>-88.9167, "flag"=>"https://disease.sh/assets/img/flags/sv.png"}, "cases"=>10303, "todayCases"=>0, "deaths"=>278, "todayDeaths"=>0, "recovered"=>5919, "todayRecovered"=>0, "active"=>4106, "critical"=>357, "casesPerOneMillion"=>1588, "deathsPerOneMillion"=>43, "tests"=>197151, "testsPerOneMillion"=>30390, "population"=>6487461, "continent"=>"North America", "oneCasePerPeople"=>630, "oneDeathPerPeople"=>23336, "oneTestPerPeople"=>33, "activePerOneMillion"=>632.91, "recoveredPerOneMillion"=>912.38, "criticalPerOneMillion"=>55.03}
{"updated"=>1594779763632, "country"=>"Equatorial Guinea", "countryInfo"=>{"_id"=>226, "iso2"=>"GQ", "iso3"=>"GNQ", "lat"=>2, "long"=>10, "flag"=>"https://disease.sh/assets/img/flags/gq.png"}, "cases"=>3071, "todayCases"=>0, "deaths"=>51, "todayDeaths"=>0, "recovered"=>842, "todayRecovered"=>0, "active"=>2178, "critical"=>0, "casesPerOneMillion"=>2187, "deathsPerOneMillion"=>36, "tests"=>16000, "testsPerOneMillion"=>11395, "population"=>1404090, "continent"=>"Africa", "oneCasePerPeople"=>457, "oneDeathPerPeople"=>27531, "oneTestPerPeople"=>88, "activePerOneMillion"=>1551.18, "recoveredPerOneMillion"=>599.68, "criticalPerOneMillion"=>0}
{"updated"=>1594779763711, "country"=>"Eritrea", "countryInfo"=>{"_id"=>232, "iso2"=>"ER", "iso3"=>"ERI", "lat"=>15, "long"=>39, "flag"=>"https://disease.sh/assets/img/flags/er.png"}, "cases"=>232, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>107, "todayRecovered"=>0, "active"=>125, "critical"=>0, "casesPerOneMillion"=>65, "deathsPerOneMillion"=>0, "tests"=>0, "testsPerOneMillion"=>0, "population"=>3548090, "continent"=>"Africa", "oneCasePerPeople"=>15293, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>0, "activePerOneMillion"=>35.23, "recoveredPerOneMillion"=>30.16, "criticalPerOneMillion"=>0}
{"updated"=>1594779763646, "country"=>"Estonia", "countryInfo"=>{"_id"=>233, "iso2"=>"EE", "iso3"=>"EST", "lat"=>59, "long"=>26, "flag"=>"https://disease.sh/assets/img/flags/ee.png"}, "cases"=>2015, "todayCases"=>0, "deaths"=>69, "todayDeaths"=>0, "recovered"=>1897, "todayRecovered"=>0, "active"=>49, "critical"=>1, "casesPerOneMillion"=>1519, "deathsPerOneMillion"=>52, "tests"=>112594, "testsPerOneMillion"=>84876, "population"=>1326571, "continent"=>"Europe", "oneCasePerPeople"=>658, "oneDeathPerPeople"=>19226, "oneTestPerPeople"=>12, "activePerOneMillion"=>36.94, "recoveredPerOneMillion"=>1430, "criticalPerOneMillion"=>0.75}
{"updated"=>1594779763602, "country"=>"Ethiopia", "countryInfo"=>{"_id"=>231, "iso2"=>"ET", "iso3"=>"ETH", "lat"=>8, "long"=>38, "flag"=>"https://disease.sh/assets/img/flags/et.png"}, "cases"=>7969, "todayCases"=>0, "deaths"=>139, "todayDeaths"=>0, "recovered"=>2430, "todayRecovered"=>0, "active"=>5400, "critical"=>35, "casesPerOneMillion"=>69, "deathsPerOneMillion"=>1, "tests"=>250604, "testsPerOneMillion"=>2178, "population"=>115044244, "continent"=>"Africa", "oneCasePerPeople"=>14436, "oneDeathPerPeople"=>827656, "oneTestPerPeople"=>459, "activePerOneMillion"=>46.94, "recoveredPerOneMillion"=>21.12, "criticalPerOneMillion"=>0.3}
{"updated"=>1594779763747, "country"=>"Falkland Islands (Malvinas)", "countryInfo"=>{"_id"=>238, "iso2"=>"FK", "iso3"=>"FLK", "lat"=>-51.75, "long"=>-59, "flag"=>"https://disease.sh/assets/img/flags/fk.png"}, "cases"=>13, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>13, "todayRecovered"=>0, "active"=>0, "critical"=>0, "casesPerOneMillion"=>3732, "deathsPerOneMillion"=>0, "tests"=>1393, "testsPerOneMillion"=>399943, "population"=>3483, "continent"=>"South America", "oneCasePerPeople"=>268, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>3, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>3732.41, "criticalPerOneMillion"=>0}
{"updated"=>1594779763714, "country"=>"Faroe Islands", "countryInfo"=>{"_id"=>234, "iso2"=>"FO", "iso3"=>"FRO", "lat"=>62, "long"=>-7, "flag"=>"https://disease.sh/assets/img/flags/fo.png"}, "cases"=>188, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>188, "todayRecovered"=>0, "active"=>0, "critical"=>0, "casesPerOneMillion"=>3847, "deathsPerOneMillion"=>0, "tests"=>24704, "testsPerOneMillion"=>505504, "population"=>48870, "continent"=>"Europe", "oneCasePerPeople"=>260, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>2, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>3846.94, "criticalPerOneMillion"=>0}
{"updated"=>1594779763738, "country"=>"Fiji", "countryInfo"=>{"_id"=>242, "iso2"=>"FJ", "iso3"=>"FJI", "lat"=>-18, "long"=>175, "flag"=>"https://disease.sh/assets/img/flags/fj.png"}, "cases"=>26, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>18, "todayRecovered"=>0, "active"=>8, "critical"=>0, "casesPerOneMillion"=>29, "deathsPerOneMillion"=>0, "tests"=>4000, "testsPerOneMillion"=>4461, "population"=>896687, "continent"=>"Australia/Oceania", "oneCasePerPeople"=>34488, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>224, "activePerOneMillion"=>8.92, "recoveredPerOneMillion"=>20.07, "criticalPerOneMillion"=>0}
{"updated"=>1594779763604, "country"=>"Finland", "countryInfo"=>{"_id"=>246, "iso2"=>"FI", "iso3"=>"FIN", "lat"=>64, "long"=>26, "flag"=>"https://disease.sh/assets/img/flags/fi.png"}, "cases"=>7301, "todayCases"=>0, "deaths"=>329, "todayDeaths"=>0, "recovered"=>6800, "todayRecovered"=>0, "active"=>172, "critical"=>1, "casesPerOneMillion"=>1318, "deathsPerOneMillion"=>59, "tests"=>278800, "testsPerOneMillion"=>50315, "population"=>5541065, "continent"=>"Europe", "oneCasePerPeople"=>759, "oneDeathPerPeople"=>16842, "oneTestPerPeople"=>20, "activePerOneMillion"=>31.04, "recoveredPerOneMillion"=>1227.2, "criticalPerOneMillion"=>0.18}
{"updated"=>1594779763524, "country"=>"France", "countryInfo"=>{"_id"=>250, "iso2"=>"FR", "iso3"=>"FRA", "lat"=>46, "long"=>2, "flag"=>"https://disease.sh/assets/img/flags/fr.png"}, "cases"=>172377, "todayCases"=>0, "deaths"=>30029, "todayDeaths"=>0, "recovered"=>78597, "todayRecovered"=>0, "active"=>63751, "critical"=>492, "casesPerOneMillion"=>2641, "deathsPerOneMillion"=>460, "tests"=>2489269, "testsPerOneMillion"=>38133, "population"=>65279255, "continent"=>"Europe", "oneCasePerPeople"=>379, "oneDeathPerPeople"=>2174, "oneTestPerPeople"=>26, "activePerOneMillion"=>976.59, "recoveredPerOneMillion"=>1204.01, "criticalPerOneMillion"=>7.54}
{"updated"=>1594779763610, "country"=>"French Guiana", "countryInfo"=>{"_id"=>254, "iso2"=>"GF", "iso3"=>"GUF", "lat"=>4, "long"=>-53, "flag"=>"https://disease.sh/assets/img/flags/gf.png"}, "cases"=>6229, "todayCases"=>0, "deaths"=>31, "todayDeaths"=>0, "recovered"=>3472, "todayRecovered"=>0, "active"=>2726, "critical"=>25, "casesPerOneMillion"=>20840, "deathsPerOneMillion"=>104, "tests"=>10919, "testsPerOneMillion"=>36531, "population"=>298897, "continent"=>"South America", "oneCasePerPeople"=>48, "oneDeathPerPeople"=>9642, "oneTestPerPeople"=>27, "activePerOneMillion"=>9120.2, "recoveredPerOneMillion"=>11616.04, "criticalPerOneMillion"=>83.64}
{"updated"=>1594779763733, "country"=>"French Polynesia", "countryInfo"=>{"_id"=>258, "iso2"=>"PF", "iso3"=>"PYF", "lat"=>-15, "long"=>-140, "flag"=>"https://disease.sh/assets/img/flags/pf.png"}, "cases"=>62, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>60, "todayRecovered"=>0, "active"=>2, "critical"=>0, "casesPerOneMillion"=>221, "deathsPerOneMillion"=>0, "tests"=>4649, "testsPerOneMillion"=>16546, "population"=>280970, "continent"=>"Australia/Oceania", "oneCasePerPeople"=>4532, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>60, "activePerOneMillion"=>7.12, "recoveredPerOneMillion"=>213.55, "criticalPerOneMillion"=>0}
{"updated"=>1594779763612, "country"=>"Gabon", "countryInfo"=>{"_id"=>266, "iso2"=>"GA", "iso3"=>"GAB", "lat"=>-1, "long"=>11.75, "flag"=>"https://disease.sh/assets/img/flags/ga.png"}, "cases"=>6026, "todayCases"=>0, "deaths"=>46, "todayDeaths"=>0, "recovered"=>3475, "todayRecovered"=>0, "active"=>2505, "critical"=>11, "casesPerOneMillion"=>2706, "deathsPerOneMillion"=>21, "tests"=>49853, "testsPerOneMillion"=>22383, "population"=>2227254, "continent"=>"Africa", "oneCasePerPeople"=>370, "oneDeathPerPeople"=>48419, "oneTestPerPeople"=>45, "activePerOneMillion"=>1124.7, "recoveredPerOneMillion"=>1560.22, "criticalPerOneMillion"=>4.94}
{"updated"=>1594779763732, "country"=>"Gambia", "countryInfo"=>{"_id"=>270, "iso2"=>"GM", "iso3"=>"GMB", "lat"=>13.4667, "long"=>-16.5667, "flag"=>"https://disease.sh/assets/img/flags/gm.png"}, "cases"=>64, "todayCases"=>0, "deaths"=>3, "todayDeaths"=>0, "recovered"=>34, "todayRecovered"=>0, "active"=>27, "critical"=>0, "casesPerOneMillion"=>26, "deathsPerOneMillion"=>1, "tests"=>3573, "testsPerOneMillion"=>1477, "population"=>2418471, "continent"=>"Africa", "oneCasePerPeople"=>37789, "oneDeathPerPeople"=>806157, "oneTestPerPeople"=>677, "activePerOneMillion"=>11.16, "recoveredPerOneMillion"=>14.06, "criticalPerOneMillion"=>0}
{"updated"=>1594779763679, "country"=>"Georgia", "countryInfo"=>{"_id"=>268, "iso2"=>"GE", "iso3"=>"GEO", "lat"=>42, "long"=>43.5, "flag"=>"https://disease.sh/assets/img/flags/ge.png"}, "cases"=>999, "todayCases"=>0, "deaths"=>15, "todayDeaths"=>0, "recovered"=>870, "todayRecovered"=>0, "active"=>114, "critical"=>5, "casesPerOneMillion"=>250, "deathsPerOneMillion"=>4, "tests"=>148188, "testsPerOneMillion"=>37151, "population"=>3988847, "continent"=>"Asia", "oneCasePerPeople"=>3993, "oneDeathPerPeople"=>265923, "oneTestPerPeople"=>27, "activePerOneMillion"=>28.58, "recoveredPerOneMillion"=>218.11, "criticalPerOneMillion"=>1.25}
{"updated"=>1594779763521, "country"=>"Germany", "countryInfo"=>{"_id"=>276, "iso2"=>"DE", "iso3"=>"DEU", "lat"=>51, "long"=>9, "flag"=>"https://disease.sh/assets/img/flags/de.png"}, "cases"=>200766, "todayCases"=>0, "deaths"=>9144, "todayDeaths"=>0, "recovered"=>185500, "todayRecovered"=>0, "active"=>6122, "critical"=>264, "casesPerOneMillion"=>2396, "deathsPerOneMillion"=>109, "tests"=>6376054, "testsPerOneMillion"=>76092, "population"=>83794469, "continent"=>"Europe", "oneCasePerPeople"=>417, "oneDeathPerPeople"=>9164, "oneTestPerPeople"=>13, "activePerOneMillion"=>73.06, "recoveredPerOneMillion"=>2213.75, "criticalPerOneMillion"=>3.15}
{"updated"=>1594779763570, "country"=>"Ghana", "countryInfo"=>{"_id"=>288, "iso2"=>"GH", "iso3"=>"GHA", "lat"=>8, "long"=>-2, "flag"=>"https://disease.sh/assets/img/flags/gh.png"}, "cases"=>24988, "todayCases"=>0, "deaths"=>139, "todayDeaths"=>0, "recovered"=>21067, "todayRecovered"=>0, "active"=>3782, "critical"=>8, "casesPerOneMillion"=>804, "deathsPerOneMillion"=>4, "tests"=>331366, "testsPerOneMillion"=>10657, "population"=>31092641, "continent"=>"Africa", "oneCasePerPeople"=>1244, "oneDeathPerPeople"=>223688, "oneTestPerPeople"=>94, "activePerOneMillion"=>121.64, "recoveredPerOneMillion"=>677.56, "criticalPerOneMillion"=>0.26}
{"updated"=>1594779763714, "country"=>"Gibraltar", "countryInfo"=>{"_id"=>292, "iso2"=>"GI", "iso3"=>"GIB", "lat"=>36.1833, "long"=>-5.3667, "flag"=>"https://disease.sh/assets/img/flags/gi.png"}, "cases"=>180, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>179, "todayRecovered"=>0, "active"=>1, "critical"=>0, "casesPerOneMillion"=>5343, "deathsPerOneMillion"=>0, "tests"=>16532, "testsPerOneMillion"=>490695, "population"=>33691, "continent"=>"Europe", "oneCasePerPeople"=>187, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>2, "activePerOneMillion"=>29.68, "recoveredPerOneMillion"=>5312.99, "criticalPerOneMillion"=>0}
{"updated"=>1594779763623, "country"=>"Greece", "countryInfo"=>{"_id"=>300, "iso2"=>"GR", "iso3"=>"GRC", "lat"=>39, "long"=>22, "flag"=>"https://disease.sh/assets/img/flags/gr.png"}, "cases"=>3883, "todayCases"=>0, "deaths"=>193, "todayDeaths"=>0, "recovered"=>1374, "todayRecovered"=>0, "active"=>2316, "critical"=>13, "casesPerOneMillion"=>373, "deathsPerOneMillion"=>19, "tests"=>386307, "testsPerOneMillion"=>37071, "population"=>10420856, "continent"=>"Europe", "oneCasePerPeople"=>2684, "oneDeathPerPeople"=>53994, "oneTestPerPeople"=>27, "activePerOneMillion"=>222.25, "recoveredPerOneMillion"=>131.85, "criticalPerOneMillion"=>1.25}
{"updated"=>1594779763748, "country"=>"Greenland", "countryInfo"=>{"_id"=>304, "iso2"=>"GL", "iso3"=>"GRL", "lat"=>72, "long"=>-40, "flag"=>"https://disease.sh/assets/img/flags/gl.png"}, "cases"=>13, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>13, "todayRecovered"=>0, "active"=>0, "critical"=>0, "casesPerOneMillion"=>229, "deathsPerOneMillion"=>0, "tests"=>4789, "testsPerOneMillion"=>84352, "population"=>56774, "continent"=>"North America", "oneCasePerPeople"=>4367, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>12, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>228.98, "criticalPerOneMillion"=>0}
{"updated"=>1594779763741, "country"=>"Grenada", "countryInfo"=>{"_id"=>308, "iso2"=>"GD", "iso3"=>"GRD", "lat"=>12.1167, "long"=>-61.6667, "flag"=>"https://disease.sh/assets/img/flags/gd.png"}, "cases"=>23, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>23, "todayRecovered"=>0, "active"=>0, "critical"=>0, "casesPerOneMillion"=>204, "deathsPerOneMillion"=>0, "tests"=>5465, "testsPerOneMillion"=>48559, "population"=>112543, "continent"=>"North America", "oneCasePerPeople"=>4893, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>21, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>204.37, "criticalPerOneMillion"=>0}
{"updated"=>1594779763713, "country"=>"Guadeloupe", "countryInfo"=>{"_id"=>312, "iso2"=>"GP", "iso3"=>"GLP", "lat"=>16.25, "long"=>-61.5833, "flag"=>"https://disease.sh/assets/img/flags/gp.png"}, "cases"=>190, "todayCases"=>0, "deaths"=>14, "todayDeaths"=>0, "recovered"=>157, "todayRecovered"=>0, "active"=>19, "critical"=>4, "casesPerOneMillion"=>475, "deathsPerOneMillion"=>35, "tests"=>11538, "testsPerOneMillion"=>28836, "population"=>400127, "continent"=>"North America", "oneCasePerPeople"=>2106, "oneDeathPerPeople"=>28581, "oneTestPerPeople"=>35, "activePerOneMillion"=>47.48, "recoveredPerOneMillion"=>392.38, "criticalPerOneMillion"=>10}
{"updated"=>1594779763564, "country"=>"Guatemala", "countryInfo"=>{"_id"=>320, "iso2"=>"GT", "iso3"=>"GTM", "lat"=>15.5, "long"=>-90.25, "flag"=>"https://disease.sh/assets/img/flags/gt.png"}, "cases"=>30872, "todayCases"=>0, "deaths"=>1302, "todayDeaths"=>0, "recovered"=>4453, "todayRecovered"=>0, "active"=>25117, "critical"=>5, "casesPerOneMillion"=>1722, "deathsPerOneMillion"=>73, "tests"=>64590, "testsPerOneMillion"=>3603, "population"=>17926043, "continent"=>"North America", "oneCasePerPeople"=>581, "oneDeathPerPeople"=>13768, "oneTestPerPeople"=>278, "activePerOneMillion"=>1401.15, "recoveredPerOneMillion"=>248.41, "criticalPerOneMillion"=>0.28}
{"updated"=>1594779763611, "country"=>"Guinea", "countryInfo"=>{"_id"=>324, "iso2"=>"GN", "iso3"=>"GIN", "lat"=>11, "long"=>-10, "flag"=>"https://disease.sh/assets/img/flags/gn.png"}, "cases"=>6200, "todayCases"=>0, "deaths"=>38, "todayDeaths"=>0, "recovered"=>4951, "todayRecovered"=>0, "active"=>1211, "critical"=>24, "casesPerOneMillion"=>472, "deathsPerOneMillion"=>3, "tests"=>14407, "testsPerOneMillion"=>1096, "population"=>13142438, "continent"=>"Africa", "oneCasePerPeople"=>2120, "oneDeathPerPeople"=>345854, "oneTestPerPeople"=>912, "activePerOneMillion"=>92.14, "recoveredPerOneMillion"=>376.72, "criticalPerOneMillion"=>1.83}
{"updated"=>1594779763652, "country"=>"Guinea-Bissau", "countryInfo"=>{"_id"=>624, "iso2"=>"GW", "iso3"=>"GNB", "lat"=>12, "long"=>-15, "flag"=>"https://disease.sh/assets/img/flags/gw.png"}, "cases"=>1842, "todayCases"=>0, "deaths"=>26, "todayDeaths"=>0, "recovered"=>773, "todayRecovered"=>0, "active"=>1043, "critical"=>5, "casesPerOneMillion"=>935, "deathsPerOneMillion"=>13, "tests"=>1500, "testsPerOneMillion"=>762, "population"=>1969346, "continent"=>"Africa", "oneCasePerPeople"=>1069, "oneDeathPerPeople"=>75744, "oneTestPerPeople"=>1313, "activePerOneMillion"=>529.62, "recoveredPerOneMillion"=>392.52, "criticalPerOneMillion"=>2.54}
{"updated"=>1594779763706, "country"=>"Guyana", "countryInfo"=>{"_id"=>328, "iso2"=>"GY", "iso3"=>"GUY", "lat"=>5, "long"=>-59, "flag"=>"https://disease.sh/assets/img/flags/gy.png"}, "cases"=>308, "todayCases"=>0, "deaths"=>17, "todayDeaths"=>0, "recovered"=>156, "todayRecovered"=>0, "active"=>135, "critical"=>5, "casesPerOneMillion"=>392, "deathsPerOneMillion"=>22, "tests"=>3379, "testsPerOneMillion"=>4295, "population"=>786698, "continent"=>"South America", "oneCasePerPeople"=>2554, "oneDeathPerPeople"=>46276, "oneTestPerPeople"=>233, "activePerOneMillion"=>171.6, "recoveredPerOneMillion"=>198.3, "criticalPerOneMillion"=>6.36}
{"updated"=>1594779763608, "country"=>"Haiti", "countryInfo"=>{"_id"=>332, "iso2"=>"HT", "iso3"=>"HTI", "lat"=>19, "long"=>-72.4167, "flag"=>"https://disease.sh/assets/img/flags/ht.png"}, "cases"=>6727, "todayCases"=>0, "deaths"=>141, "todayDeaths"=>0, "recovered"=>3022, "todayRecovered"=>0, "active"=>3564, "critical"=>0, "casesPerOneMillion"=>590, "deathsPerOneMillion"=>12, "tests"=>14544, "testsPerOneMillion"=>1275, "population"=>11407370, "continent"=>"North America", "oneCasePerPeople"=>1696, "oneDeathPerPeople"=>80903, "oneTestPerPeople"=>784, "activePerOneMillion"=>312.43, "recoveredPerOneMillion"=>264.92, "criticalPerOneMillion"=>0}
{"updated"=>1594779763750, "country"=>"Holy See (Vatican City State)", "countryInfo"=>{"_id"=>336, "iso2"=>"VA", "iso3"=>"VAT", "lat"=>41.9, "long"=>12.45, "flag"=>"https://disease.sh/assets/img/flags/va.png"}, "cases"=>12, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>12, "todayRecovered"=>0, "active"=>0, "critical"=>0, "casesPerOneMillion"=>14981, "deathsPerOneMillion"=>0, "tests"=>0, "testsPerOneMillion"=>0, "population"=>801, "continent"=>"Europe", "oneCasePerPeople"=>67, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>0, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>14981.27, "criticalPerOneMillion"=>0}
{"updated"=>1594779763566, "country"=>"Honduras", "countryInfo"=>{"_id"=>340, "iso2"=>"HN", "iso3"=>"HND", "lat"=>15, "long"=>-86.5, "flag"=>"https://disease.sh/assets/img/flags/hn.png"}, "cases"=>28579, "todayCases"=>0, "deaths"=>789, "todayDeaths"=>0, "recovered"=>3123, "todayRecovered"=>0, "active"=>24667, "critical"=>58, "casesPerOneMillion"=>2884, "deathsPerOneMillion"=>80, "tests"=>49308, "testsPerOneMillion"=>4976, "population"=>9909797, "continent"=>"North America", "oneCasePerPeople"=>347, "oneDeathPerPeople"=>12560, "oneTestPerPeople"=>201, "activePerOneMillion"=>2489.15, "recoveredPerOneMillion"=>315.14, "criticalPerOneMillion"=>5.85}
{"updated"=>1594779763660, "country"=>"Hong Kong", "countryInfo"=>{"_id"=>344, "iso2"=>"HK", "iso3"=>"HKG", "lat"=>22.25, "long"=>114.1667, "flag"=>"https://disease.sh/assets/img/flags/hk.png"}, "cases"=>1570, "todayCases"=>0, "deaths"=>8, "todayDeaths"=>0, "recovered"=>1229, "todayRecovered"=>0, "active"=>333, "critical"=>6, "casesPerOneMillion"=>209, "deathsPerOneMillion"=>1, "tests"=>376645, "testsPerOneMillion"=>50225, "population"=>7499224, "continent"=>"Asia", "oneCasePerPeople"=>4777, "oneDeathPerPeople"=>937403, "oneTestPerPeople"=>20, "activePerOneMillion"=>44.4, "recoveredPerOneMillion"=>163.88, "criticalPerOneMillion"=>0.8}
{"updated"=>1594779763621, "country"=>"Hungary", "countryInfo"=>{"_id"=>348, "iso2"=>"HU", "iso3"=>"HUN", "lat"=>47, "long"=>20, "flag"=>"https://disease.sh/assets/img/flags/hu.png"}, "cases"=>4258, "todayCases"=>0, "deaths"=>595, "todayDeaths"=>0, "recovered"=>3106, "todayRecovered"=>0, "active"=>557, "critical"=>5, "casesPerOneMillion"=>441, "deathsPerOneMillion"=>62, "tests"=>296358, "testsPerOneMillion"=>30681, "population"=>9659319, "continent"=>"Europe", "oneCasePerPeople"=>2269, "oneDeathPerPeople"=>16234, "oneTestPerPeople"=>33, "activePerOneMillion"=>57.66, "recoveredPerOneMillion"=>321.55, "criticalPerOneMillion"=>0.52}
{"updated"=>1594779763648, "country"=>"Iceland", "countryInfo"=>{"_id"=>352, "iso2"=>"IS", "iso3"=>"ISL", "lat"=>65, "long"=>-18, "flag"=>"https://disease.sh/assets/img/flags/is.png"}, "cases"=>1905, "todayCases"=>0, "deaths"=>10, "todayDeaths"=>0, "recovered"=>1882, "todayRecovered"=>0, "active"=>13, "critical"=>0, "casesPerOneMillion"=>5581, "deathsPerOneMillion"=>29, "tests"=>104713, "testsPerOneMillion"=>306783, "population"=>341326, "continent"=>"Europe", "oneCasePerPeople"=>179, "oneDeathPerPeople"=>34133, "oneTestPerPeople"=>3, "activePerOneMillion"=>38.09, "recoveredPerOneMillion"=>5513.79, "criticalPerOneMillion"=>0}
{"updated"=>1594779763499, "country"=>"India", "countryInfo"=>{"_id"=>356, "iso2"=>"IN", "iso3"=>"IND", "lat"=>20, "long"=>77, "flag"=>"https://disease.sh/assets/img/flags/in.png"}, "cases"=>937487, "todayCases"=>0, "deaths"=>24315, "todayDeaths"=>0, "recovered"=>593080, "todayRecovered"=>0, "active"=>320092, "critical"=>8944, "casesPerOneMillion"=>679, "deathsPerOneMillion"=>18, "tests"=>12092503, "testsPerOneMillion"=>8760, "population"=>1380493070, "continent"=>"Asia", "oneCasePerPeople"=>1473, "oneDeathPerPeople"=>56775, "oneTestPerPeople"=>114, "activePerOneMillion"=>231.87, "recoveredPerOneMillion"=>429.61, "criticalPerOneMillion"=>6.48}
{"updated"=>1594779763534, "country"=>"Indonesia", "countryInfo"=>{"_id"=>360, "iso2"=>"ID", "iso3"=>"IDN", "lat"=>-5, "long"=>120, "flag"=>"https://disease.sh/assets/img/flags/id.png"}, "cases"=>78572, "todayCases"=>0, "deaths"=>3710, "todayDeaths"=>0, "recovered"=>37636, "todayRecovered"=>0, "active"=>37226, "critical"=>0, "casesPerOneMillion"=>287, "deathsPerOneMillion"=>14, "tests"=>1097468, "testsPerOneMillion"=>4011, "population"=>273626716, "continent"=>"Asia", "oneCasePerPeople"=>3482, "oneDeathPerPeople"=>73754, "oneTestPerPeople"=>249, "activePerOneMillion"=>136.05, "recoveredPerOneMillion"=>137.55, "criticalPerOneMillion"=>0}
{"updated"=>1594779763511, "country"=>"Iran", "countryInfo"=>{"_id"=>364, "iso2"=>"IR", "iso3"=>"IRN", "lat"=>32, "long"=>53, "flag"=>"https://disease.sh/assets/img/flags/ir.png"}, "cases"=>262173, "todayCases"=>0, "deaths"=>13211, "todayDeaths"=>0, "recovered"=>225270, "todayRecovered"=>0, "active"=>23692, "critical"=>3389, "casesPerOneMillion"=>3120, "deathsPerOneMillion"=>157, "tests"=>2023079, "testsPerOneMillion"=>24076, "population"=>84030066, "continent"=>"Asia", "oneCasePerPeople"=>321, "oneDeathPerPeople"=>6361, "oneTestPerPeople"=>42, "activePerOneMillion"=>281.95, "recoveredPerOneMillion"=>2680.83, "criticalPerOneMillion"=>40.33}
{"updated"=>1594779763532, "country"=>"Iraq", "countryInfo"=>{"_id"=>368, "iso2"=>"IQ", "iso3"=>"IRQ", "lat"=>33, "long"=>44, "flag"=>"https://disease.sh/assets/img/flags/iq.png"}, "cases"=>81757, "todayCases"=>0, "deaths"=>3345, "todayDeaths"=>0, "recovered"=>50782, "todayRecovered"=>0, "active"=>27630, "critical"=>412, "casesPerOneMillion"=>2031, "deathsPerOneMillion"=>83, "tests"=>698012, "testsPerOneMillion"=>17342, "population"=>40249168, "continent"=>"Asia", "oneCasePerPeople"=>492, "oneDeathPerPeople"=>12033, "oneTestPerPeople"=>58, "activePerOneMillion"=>686.47, "recoveredPerOneMillion"=>1261.69, "criticalPerOneMillion"=>10.24}
{"updated"=>1594779763567, "country"=>"Ireland", "countryInfo"=>{"_id"=>372, "iso2"=>"IE", "iso3"=>"IRL", "lat"=>53, "long"=>-8, "flag"=>"https://disease.sh/assets/img/flags/ie.png"}, "cases"=>25670, "todayCases"=>0, "deaths"=>1746, "todayDeaths"=>0, "recovered"=>23364, "todayRecovered"=>0, "active"=>560, "critical"=>9, "casesPerOneMillion"=>5197, "deathsPerOneMillion"=>353, "tests"=>523277, "testsPerOneMillion"=>105932, "population"=>4939736, "continent"=>"Europe", "oneCasePerPeople"=>192, "oneDeathPerPeople"=>2829, "oneTestPerPeople"=>9, "activePerOneMillion"=>113.37, "recoveredPerOneMillion"=>4729.81, "criticalPerOneMillion"=>1.82}
{"updated"=>1594779763703, "country"=>"Isle of Man", "countryInfo"=>{"_id"=>833, "iso2"=>"IM", "iso3"=>"IMN", "lat"=>54.23, "long"=>-4.55, "flag"=>"https://disease.sh/assets/img/flags/im.png"}, "cases"=>336, "todayCases"=>0, "deaths"=>24, "todayDeaths"=>0, "recovered"=>312, "todayRecovered"=>0, "active"=>0, "critical"=>0, "casesPerOneMillion"=>3951, "deathsPerOneMillion"=>282, "tests"=>7301, "testsPerOneMillion"=>85844, "population"=>85050, "continent"=>"Europe", "oneCasePerPeople"=>253, "oneDeathPerPeople"=>3544, "oneTestPerPeople"=>12, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>3668.43, "criticalPerOneMillion"=>0}
{"updated"=>1594779763554, "country"=>"Israel", "countryInfo"=>{"_id"=>376, "iso2"=>"IL", "iso3"=>"ISR", "lat"=>31.5, "long"=>34.75, "flag"=>"https://disease.sh/assets/img/flags/il.png"}, "cases"=>42360, "todayCases"=>0, "deaths"=>371, "todayDeaths"=>0, "recovered"=>19665, "todayRecovered"=>0, "active"=>22324, "critical"=>183, "casesPerOneMillion"=>4606, "deathsPerOneMillion"=>40, "tests"=>1317362, "testsPerOneMillion"=>143229, "population"=>9197590, "continent"=>"Asia", "oneCasePerPeople"=>217, "oneDeathPerPeople"=>24791, "oneTestPerPeople"=>7, "activePerOneMillion"=>2427.16, "recoveredPerOneMillion"=>2138.06, "criticalPerOneMillion"=>19.9}
{"updated"=>1594779763513, "country"=>"Italy", "countryInfo"=>{"_id"=>380, "iso2"=>"IT", "iso3"=>"ITA", "lat"=>42.8333, "long"=>12.8333, "flag"=>"https://disease.sh/assets/img/flags/it.png"}, "cases"=>243344, "todayCases"=>0, "deaths"=>34984, "todayDeaths"=>0, "recovered"=>195441, "todayRecovered"=>0, "active"=>12919, "critical"=>60, "casesPerOneMillion"=>4025, "deathsPerOneMillion"=>579, "tests"=>6004611, "testsPerOneMillion"=>99319, "population"=>60458132, "continent"=>"Europe", "oneCasePerPeople"=>248, "oneDeathPerPeople"=>1728, "oneTestPerPeople"=>10, "activePerOneMillion"=>213.69, "recoveredPerOneMillion"=>3232.67, "criticalPerOneMillion"=>0.99}
{"updated"=>1594779763687, "country"=>"Jamaica", "countryInfo"=>{"_id"=>388, "iso2"=>"JM", "iso3"=>"JAM", "lat"=>18.25, "long"=>-77.5, "flag"=>"https://disease.sh/assets/img/flags/jm.png"}, "cases"=>762, "todayCases"=>3, "deaths"=>10, "todayDeaths"=>0, "recovered"=>643, "todayRecovered"=>15, "active"=>109, "critical"=>0, "casesPerOneMillion"=>257, "deathsPerOneMillion"=>3, "tests"=>28603, "testsPerOneMillion"=>9658, "population"=>2961667, "continent"=>"North America", "oneCasePerPeople"=>3887, "oneDeathPerPeople"=>296167, "oneTestPerPeople"=>104, "activePerOneMillion"=>36.8, "recoveredPerOneMillion"=>217.11, "criticalPerOneMillion"=>0}
{"updated"=>1594779763571, "country"=>"Japan", "countryInfo"=>{"_id"=>392, "iso2"=>"JP", "iso3"=>"JPN", "lat"=>36, "long"=>138, "flag"=>"https://disease.sh/assets/img/flags/jp.png"}, "cases"=>22220, "todayCases"=>0, "deaths"=>982, "todayDeaths"=>0, "recovered"=>18282, "todayRecovered"=>0, "active"=>2956, "critical"=>40, "casesPerOneMillion"=>176, "deathsPerOneMillion"=>8, "tests"=>574432, "testsPerOneMillion"=>4542, "population"=>126460083, "continent"=>"Asia", "oneCasePerPeople"=>5691, "oneDeathPerPeople"=>128778, "oneTestPerPeople"=>220, "activePerOneMillion"=>23.37, "recoveredPerOneMillion"=>144.57, "criticalPerOneMillion"=>0.32}
{"updated"=>1594779763671, "country"=>"Jordan", "countryInfo"=>{"_id"=>400, "iso2"=>"JO", "iso3"=>"JOR", "lat"=>31, "long"=>36, "flag"=>"https://disease.sh/assets/img/flags/jo.png"}, "cases"=>1198, "todayCases"=>0, "deaths"=>10, "todayDeaths"=>0, "recovered"=>1013, "todayRecovered"=>0, "active"=>175, "critical"=>3, "casesPerOneMillion"=>117, "deathsPerOneMillion"=>1, "tests"=>477448, "testsPerOneMillion"=>46778, "population"=>10206777, "continent"=>"Asia", "oneCasePerPeople"=>8520, "oneDeathPerPeople"=>1020678, "oneTestPerPeople"=>21, "activePerOneMillion"=>17.15, "recoveredPerOneMillion"=>99.25, "criticalPerOneMillion"=>0.29}
{"updated"=>1594779763539, "country"=>"Kazakhstan", "countryInfo"=>{"_id"=>398, "iso2"=>"KZ", "iso3"=>"KAZ", "lat"=>48, "long"=>68, "flag"=>"https://disease.sh/assets/img/flags/kz.png"}, "cases"=>61755, "todayCases"=>0, "deaths"=>375, "todayDeaths"=>0, "recovered"=>35911, "todayRecovered"=>0, "active"=>25469, "critical"=>221, "casesPerOneMillion"=>3288, "deathsPerOneMillion"=>20, "tests"=>1719295, "testsPerOneMillion"=>91527, "population"=>18784556, "continent"=>"Asia", "oneCasePerPeople"=>304, "oneDeathPerPeople"=>50092, "oneTestPerPeople"=>11, "activePerOneMillion"=>1355.85, "recoveredPerOneMillion"=>1911.73, "criticalPerOneMillion"=>11.76}
{"updated"=>1594779763589, "country"=>"Kenya", "countryInfo"=>{"_id"=>404, "iso2"=>"KE", "iso3"=>"KEN", "lat"=>1, "long"=>38, "flag"=>"https://disease.sh/assets/img/flags/ke.png"}, "cases"=>10791, "todayCases"=>0, "deaths"=>202, "todayDeaths"=>0, "recovered"=>3017, "todayRecovered"=>0, "active"=>7572, "critical"=>44, "casesPerOneMillion"=>201, "deathsPerOneMillion"=>4, "tests"=>221234, "testsPerOneMillion"=>4112, "population"=>53806557, "continent"=>"Africa", "oneCasePerPeople"=>4986, "oneDeathPerPeople"=>266369, "oneTestPerPeople"=>243, "activePerOneMillion"=>140.73, "recoveredPerOneMillion"=>56.07, "criticalPerOneMillion"=>0.82}
{"updated"=>1594779763543, "country"=>"Kuwait", "countryInfo"=>{"_id"=>414, "iso2"=>"KW", "iso3"=>"KWT", "lat"=>29.3375, "long"=>47.6581, "flag"=>"https://disease.sh/assets/img/flags/kw.png"}, "cases"=>56174, "todayCases"=>0, "deaths"=>396, "todayDeaths"=>0, "recovered"=>46161, "todayRecovered"=>0, "active"=>9617, "critical"=>156, "casesPerOneMillion"=>13147, "deathsPerOneMillion"=>93, "tests"=>441143, "testsPerOneMillion"=>103247, "population"=>4272688, "continent"=>"Asia", "oneCasePerPeople"=>76, "oneDeathPerPeople"=>10790, "oneTestPerPeople"=>10, "activePerOneMillion"=>2250.81, "recoveredPerOneMillion"=>10803.74, "criticalPerOneMillion"=>36.51}
{"updated"=>1594779763588, "country"=>"Kyrgyzstan", "countryInfo"=>{"_id"=>417, "iso2"=>"KG", "iso3"=>"KGZ", "lat"=>41, "long"=>75, "flag"=>"https://disease.sh/assets/img/flags/kg.png"}, "cases"=>11444, "todayCases"=>0, "deaths"=>149, "todayDeaths"=>0, "recovered"=>3538, "todayRecovered"=>0, "active"=>7757, "critical"=>24, "casesPerOneMillion"=>1753, "deathsPerOneMillion"=>23, "tests"=>256698, "testsPerOneMillion"=>39324, "population"=>6527708, "continent"=>"Asia", "oneCasePerPeople"=>570, "oneDeathPerPeople"=>43810, "oneTestPerPeople"=>25, "activePerOneMillion"=>1188.32, "recoveredPerOneMillion"=>542, "criticalPerOneMillion"=>3.68}
{"updated"=>1594779763744, "country"=>"Lao People's Democratic Republic", "countryInfo"=>{"_id"=>418, "iso2"=>"LA", "iso3"=>"LAO", "lat"=>18, "long"=>105, "flag"=>"https://disease.sh/assets/img/flags/la.png"}, "cases"=>19, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>19, "todayRecovered"=>0, "active"=>0, "critical"=>0, "casesPerOneMillion"=>3, "deathsPerOneMillion"=>0, "tests"=>20769, "testsPerOneMillion"=>2853, "population"=>7279113, "continent"=>"Asia", "oneCasePerPeople"=>383111, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>350, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>2.61, "criticalPerOneMillion"=>0}
{"updated"=>1594779763672, "country"=>"Latvia", "countryInfo"=>{"_id"=>428, "iso2"=>"LV", "iso3"=>"LVA", "lat"=>57, "long"=>25, "flag"=>"https://disease.sh/assets/img/flags/lv.png"}, "cases"=>1174, "todayCases"=>0, "deaths"=>31, "todayDeaths"=>0, "recovered"=>1022, "todayRecovered"=>0, "active"=>121, "critical"=>1, "casesPerOneMillion"=>623, "deathsPerOneMillion"=>16, "tests"=>172078, "testsPerOneMillion"=>91277, "population"=>1885238, "continent"=>"Europe", "oneCasePerPeople"=>1606, "oneDeathPerPeople"=>60814, "oneTestPerPeople"=>11, "activePerOneMillion"=>64.18, "recoveredPerOneMillion"=>542.11, "criticalPerOneMillion"=>0.53}
{"updated"=>1594779763638, "country"=>"Lebanon", "countryInfo"=>{"_id"=>422, "iso2"=>"LB", "iso3"=>"LBN", "lat"=>33.8333, "long"=>35.8333, "flag"=>"https://disease.sh/assets/img/flags/lb.png"}, "cases"=>2451, "todayCases"=>0, "deaths"=>37, "todayDeaths"=>0, "recovered"=>1452, "todayRecovered"=>0, "active"=>962, "critical"=>20, "casesPerOneMillion"=>359, "deathsPerOneMillion"=>5, "tests"=>184425, "testsPerOneMillion"=>27025, "population"=>6824132, "continent"=>"Asia", "oneCasePerPeople"=>2784, "oneDeathPerPeople"=>184436, "oneTestPerPeople"=>37, "activePerOneMillion"=>140.97, "recoveredPerOneMillion"=>212.77, "criticalPerOneMillion"=>2.93}
{"updated"=>1594779763708, "country"=>"Lesotho", "countryInfo"=>{"_id"=>426, "iso2"=>"LS", "iso3"=>"LSO", "lat"=>-29.5, "long"=>28.5, "flag"=>"https://disease.sh/assets/img/flags/ls.png"}, "cases"=>256, "todayCases"=>0, "deaths"=>3, "todayDeaths"=>0, "recovered"=>48, "todayRecovered"=>0, "active"=>205, "critical"=>0, "casesPerOneMillion"=>119, "deathsPerOneMillion"=>1, "tests"=>6033, "testsPerOneMillion"=>2815, "population"=>2142877, "continent"=>"Africa", "oneCasePerPeople"=>8371, "oneDeathPerPeople"=>714292, "oneTestPerPeople"=>355, "activePerOneMillion"=>95.67, "recoveredPerOneMillion"=>22.4, "criticalPerOneMillion"=>0}
{"updated"=>1594779763677, "country"=>"Liberia", "countryInfo"=>{"_id"=>430, "iso2"=>"LR", "iso3"=>"LBR", "lat"=>6.5, "long"=>-9.5, "flag"=>"https://disease.sh/assets/img/flags/lr.png"}, "cases"=>1024, "todayCases"=>0, "deaths"=>51, "todayDeaths"=>0, "recovered"=>439, "todayRecovered"=>0, "active"=>534, "critical"=>0, "casesPerOneMillion"=>202, "deathsPerOneMillion"=>10, "tests"=>0, "testsPerOneMillion"=>0, "population"=>5061128, "continent"=>"Africa", "oneCasePerPeople"=>4943, "oneDeathPerPeople"=>99238, "oneTestPerPeople"=>0, "activePerOneMillion"=>105.51, "recoveredPerOneMillion"=>86.74, "criticalPerOneMillion"=>0}
{"updated"=>1594779763661, "country"=>"Libyan Arab Jamahiriya", "countryInfo"=>{"_id"=>434, "iso2"=>"LY", "iso3"=>"LBY", "lat"=>25, "long"=>17, "flag"=>"https://disease.sh/assets/img/flags/ly.png"}, "cases"=>1563, "todayCases"=>0, "deaths"=>42, "todayDeaths"=>0, "recovered"=>370, "todayRecovered"=>0, "active"=>1151, "critical"=>0, "casesPerOneMillion"=>227, "deathsPerOneMillion"=>6, "tests"=>36524, "testsPerOneMillion"=>5313, "population"=>6874480, "continent"=>"Africa", "oneCasePerPeople"=>4398, "oneDeathPerPeople"=>163678, "oneTestPerPeople"=>188, "activePerOneMillion"=>167.43, "recoveredPerOneMillion"=>53.82, "criticalPerOneMillion"=>0}
{"updated"=>1594779763723, "country"=>"Liechtenstein", "countryInfo"=>{"_id"=>438, "iso2"=>"LI", "iso3"=>"LIE", "lat"=>47.1667, "long"=>9.5333, "flag"=>"https://disease.sh/assets/img/flags/li.png"}, "cases"=>84, "todayCases"=>0, "deaths"=>1, "todayDeaths"=>0, "recovered"=>81, "todayRecovered"=>0, "active"=>2, "critical"=>0, "casesPerOneMillion"=>2203, "deathsPerOneMillion"=>26, "tests"=>900, "testsPerOneMillion"=>23602, "population"=>38132, "continent"=>"Europe", "oneCasePerPeople"=>454, "oneDeathPerPeople"=>38132, "oneTestPerPeople"=>42, "activePerOneMillion"=>52.45, "recoveredPerOneMillion"=>2124.2, "criticalPerOneMillion"=>0}
{"updated"=>1594779763650, "country"=>"Lithuania", "countryInfo"=>{"_id"=>440, "iso2"=>"LT", "iso3"=>"LTU", "lat"=>56, "long"=>24, "flag"=>"https://disease.sh/assets/img/flags/lt.png"}, "cases"=>1875, "todayCases"=>0, "deaths"=>79, "todayDeaths"=>0, "recovered"=>1571, "todayRecovered"=>0, "active"=>225, "critical"=>15, "casesPerOneMillion"=>689, "deathsPerOneMillion"=>29, "tests"=>465396, "testsPerOneMillion"=>171071, "population"=>2720490, "continent"=>"Europe", "oneCasePerPeople"=>1451, "oneDeathPerPeople"=>34437, "oneTestPerPeople"=>6, "activePerOneMillion"=>82.71, "recoveredPerOneMillion"=>577.47, "criticalPerOneMillion"=>5.51}
{"updated"=>1594779763617, "country"=>"Luxembourg", "countryInfo"=>{"_id"=>442, "iso2"=>"LU", "iso3"=>"LUX", "lat"=>49.75, "long"=>6.1667, "flag"=>"https://disease.sh/assets/img/flags/lu.png"}, "cases"=>5056, "todayCases"=>0, "deaths"=>111, "todayDeaths"=>0, "recovered"=>4195, "todayRecovered"=>0, "active"=>750, "critical"=>3, "casesPerOneMillion"=>8073, "deathsPerOneMillion"=>177, "tests"=>292711, "testsPerOneMillion"=>467357, "population"=>626312, "continent"=>"Europe", "oneCasePerPeople"=>124, "oneDeathPerPeople"=>5642, "oneTestPerPeople"=>2, "activePerOneMillion"=>1197.49, "recoveredPerOneMillion"=>6697.94, "criticalPerOneMillion"=>4.79}
{"updated"=>1594779763753, "country"=>"MS Zaandam", "countryInfo"=>{"_id"=>nil, "iso2"=>nil, "iso3"=>nil, "lat"=>0, "long"=>0, "flag"=>"https://disease.sh/assets/img/flags/unknown.png"}, "cases"=>9, "todayCases"=>0, "deaths"=>2, "todayDeaths"=>0, "recovered"=>0, "todayRecovered"=>0, "active"=>7, "critical"=>0, "casesPerOneMillion"=>0, "deathsPerOneMillion"=>0, "tests"=>0, "testsPerOneMillion"=>0, "population"=>0, "continent"=>"", "oneCasePerPeople"=>0, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>0, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>0, "criticalPerOneMillion"=>0}
{"updated"=>1594779763734, "country"=>"Macao", "countryInfo"=>{"_id"=>446, "iso2"=>"MO", "iso3"=>"MAC", "lat"=>22.1667, "long"=>113.55, "flag"=>"https://disease.sh/assets/img/flags/mo.png"}, "cases"=>46, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>45, "todayRecovered"=>0, "active"=>1, "critical"=>0, "casesPerOneMillion"=>71, "deathsPerOneMillion"=>0, "tests"=>4071, "testsPerOneMillion"=>6267, "population"=>649637, "continent"=>"Asia", "oneCasePerPeople"=>14123, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>160, "activePerOneMillion"=>1.54, "recoveredPerOneMillion"=>69.27, "criticalPerOneMillion"=>0}
{"updated"=>1594779763598, "country"=>"Macedonia", "countryInfo"=>{"_id"=>807, "iso2"=>"MK", "iso3"=>"MKD", "lat"=>41.8333, "long"=>22, "flag"=>"https://disease.sh/assets/img/flags/mk.png"}, "cases"=>8332, "todayCases"=>0, "deaths"=>389, "todayDeaths"=>0, "recovered"=>4468, "todayRecovered"=>0, "active"=>3475, "critical"=>55, "casesPerOneMillion"=>3999, "deathsPerOneMillion"=>187, "tests"=>79392, "testsPerOneMillion"=>38107, "population"=>2083371, "continent"=>"Europe", "oneCasePerPeople"=>250, "oneDeathPerPeople"=>5356, "oneTestPerPeople"=>26, "activePerOneMillion"=>1667.97, "recoveredPerOneMillion"=>2144.6, "criticalPerOneMillion"=>26.4}
{"updated"=>1594779763615, "country"=>"Madagascar", "countryInfo"=>{"_id"=>450, "iso2"=>"MG", "iso3"=>"MDG", "lat"=>-20, "long"=>47, "flag"=>"https://disease.sh/assets/img/flags/mg.png"}, "cases"=>5343, "todayCases"=>0, "deaths"=>39, "todayDeaths"=>0, "recovered"=>2646, "todayRecovered"=>0, "active"=>2658, "critical"=>45, "casesPerOneMillion"=>193, "deathsPerOneMillion"=>1, "tests"=>30100, "testsPerOneMillion"=>1086, "population"=>27710827, "continent"=>"Africa", "oneCasePerPeople"=>5186, "oneDeathPerPeople"=>710534, "oneTestPerPeople"=>921, "activePerOneMillion"=>95.92, "recoveredPerOneMillion"=>95.49, "criticalPerOneMillion"=>1.62}
{"updated"=>1594779763637, "country"=>"Malawi", "countryInfo"=>{"_id"=>454, "iso2"=>"MW", "iso3"=>"MWI", "lat"=>-13.5, "long"=>34, "flag"=>"https://disease.sh/assets/img/flags/mw.png"}, "cases"=>2497, "todayCases"=>0, "deaths"=>40, "todayDeaths"=>0, "recovered"=>795, "todayRecovered"=>0, "active"=>1662, "critical"=>4, "casesPerOneMillion"=>130, "deathsPerOneMillion"=>2, "tests"=>21532, "testsPerOneMillion"=>1125, "population"=>19143672, "continent"=>"Africa", "oneCasePerPeople"=>7667, "oneDeathPerPeople"=>478592, "oneTestPerPeople"=>889, "activePerOneMillion"=>86.82, "recoveredPerOneMillion"=>41.53, "criticalPerOneMillion"=>0.21}
{"updated"=>1594779763596, "country"=>"Malaysia", "countryInfo"=>{"_id"=>458, "iso2"=>"MY", "iso3"=>"MYS", "lat"=>2.5, "long"=>112.5, "flag"=>"https://disease.sh/assets/img/flags/my.png"}, "cases"=>8729, "todayCases"=>0, "deaths"=>122, "todayDeaths"=>0, "recovered"=>8524, "todayRecovered"=>0, "active"=>83, "critical"=>6, "casesPerOneMillion"=>270, "deathsPerOneMillion"=>4, "tests"=>850423, "testsPerOneMillion"=>26264, "population"=>32380313, "continent"=>"Asia", "oneCasePerPeople"=>3710, "oneDeathPerPeople"=>265412, "oneTestPerPeople"=>38, "activePerOneMillion"=>2.56, "recoveredPerOneMillion"=>263.25, "criticalPerOneMillion"=>0.19}
{"updated"=>1594779763633, "country"=>"Maldives", "countryInfo"=>{"_id"=>462, "iso2"=>"MV", "iso3"=>"MDV", "lat"=>3.25, "long"=>73, "flag"=>"https://disease.sh/assets/img/flags/mv.png"}, "cases"=>2801, "todayCases"=>0, "deaths"=>14, "todayDeaths"=>0, "recovered"=>2302, "todayRecovered"=>0, "active"=>485, "critical"=>12, "casesPerOneMillion"=>5179, "deathsPerOneMillion"=>26, "tests"=>63559, "testsPerOneMillion"=>117517, "population"=>540849, "continent"=>"Asia", "oneCasePerPeople"=>193, "oneDeathPerPeople"=>38632, "oneTestPerPeople"=>9, "activePerOneMillion"=>896.74, "recoveredPerOneMillion"=>4256.27, "criticalPerOneMillion"=>22.19}
{"updated"=>1594779763641, "country"=>"Mali", "countryInfo"=>{"_id"=>466, "iso2"=>"ML", "iso3"=>"MLI", "lat"=>17, "long"=>-4, "flag"=>"https://disease.sh/assets/img/flags/ml.png"}, "cases"=>2423, "todayCases"=>0, "deaths"=>121, "todayDeaths"=>0, "recovered"=>1748, "todayRecovered"=>0, "active"=>554, "critical"=>0, "casesPerOneMillion"=>120, "deathsPerOneMillion"=>6, "tests"=>16317, "testsPerOneMillion"=>805, "population"=>20266097, "continent"=>"Africa", "oneCasePerPeople"=>8364, "oneDeathPerPeople"=>167488, "oneTestPerPeople"=>1242, "activePerOneMillion"=>27.34, "recoveredPerOneMillion"=>86.25, "criticalPerOneMillion"=>0}
{"updated"=>1594779763692, "country"=>"Malta", "countryInfo"=>{"_id"=>470, "iso2"=>"MT", "iso3"=>"MLT", "lat"=>35.8333, "long"=>14.5833, "flag"=>"https://disease.sh/assets/img/flags/mt.png"}, "cases"=>674, "todayCases"=>0, "deaths"=>9, "todayDeaths"=>0, "recovered"=>660, "todayRecovered"=>0, "active"=>5, "critical"=>0, "casesPerOneMillion"=>1526, "deathsPerOneMillion"=>20, "tests"=>108553, "testsPerOneMillion"=>245823, "population"=>441590, "continent"=>"Europe", "oneCasePerPeople"=>655, "oneDeathPerPeople"=>49066, "oneTestPerPeople"=>4, "activePerOneMillion"=>11.32, "recoveredPerOneMillion"=>1494.6, "criticalPerOneMillion"=>0}
{"updated"=>1594779763709, "country"=>"Martinique", "countryInfo"=>{"_id"=>474, "iso2"=>"MQ", "iso3"=>"MTQ", "lat"=>14.6667, "long"=>-61, "flag"=>"https://disease.sh/assets/img/flags/mq.png"}, "cases"=>255, "todayCases"=>0, "deaths"=>15, "todayDeaths"=>0, "recovered"=>98, "todayRecovered"=>0, "active"=>142, "critical"=>5, "casesPerOneMillion"=>680, "deathsPerOneMillion"=>40, "tests"=>0, "testsPerOneMillion"=>0, "population"=>375253, "continent"=>"North America", "oneCasePerPeople"=>1472, "oneDeathPerPeople"=>25017, "oneTestPerPeople"=>0, "activePerOneMillion"=>378.41, "recoveredPerOneMillion"=>261.16, "criticalPerOneMillion"=>13.32}
{"updated"=>1594779763613, "country"=>"Mauritania", "countryInfo"=>{"_id"=>478, "iso2"=>"MR", "iso3"=>"MRT", "lat"=>20, "long"=>-12, "flag"=>"https://disease.sh/assets/img/flags/mr.png"}, "cases"=>5518, "todayCases"=>0, "deaths"=>147, "todayDeaths"=>0, "recovered"=>2664, "todayRecovered"=>0, "active"=>2707, "critical"=>5, "casesPerOneMillion"=>1186, "deathsPerOneMillion"=>32, "tests"=>13842, "testsPerOneMillion"=>2975, "population"=>4653021, "continent"=>"Africa", "oneCasePerPeople"=>843, "oneDeathPerPeople"=>31653, "oneTestPerPeople"=>336, "activePerOneMillion"=>581.77, "recoveredPerOneMillion"=>572.53, "criticalPerOneMillion"=>1.07}
{"updated"=>1594779763701, "country"=>"Mauritius", "countryInfo"=>{"_id"=>480, "iso2"=>"MU", "iso3"=>"MUS", "lat"=>-20.2833, "long"=>57.55, "flag"=>"https://disease.sh/assets/img/flags/mu.png"}, "cases"=>342, "todayCases"=>0, "deaths"=>10, "todayDeaths"=>0, "recovered"=>330, "todayRecovered"=>0, "active"=>2, "critical"=>0, "casesPerOneMillion"=>269, "deathsPerOneMillion"=>8, "tests"=>193561, "testsPerOneMillion"=>152188, "population"=>1271853, "continent"=>"Africa", "oneCasePerPeople"=>3719, "oneDeathPerPeople"=>127185, "oneTestPerPeople"=>7, "activePerOneMillion"=>1.57, "recoveredPerOneMillion"=>259.46, "criticalPerOneMillion"=>0}
{"updated"=>1594779763635, "country"=>"Mayotte", "countryInfo"=>{"_id"=>175, "iso2"=>"YT", "iso3"=>"MYT", "lat"=>-12.8333, "long"=>45.1667, "flag"=>"https://disease.sh/assets/img/flags/yt.png"}, "cases"=>2724, "todayCases"=>0, "deaths"=>37, "todayDeaths"=>0, "recovered"=>2480, "todayRecovered"=>0, "active"=>207, "critical"=>3, "casesPerOneMillion"=>9978, "deathsPerOneMillion"=>136, "tests"=>13000, "testsPerOneMillion"=>47618, "population"=>273004, "continent"=>"Africa", "oneCasePerPeople"=>100, "oneDeathPerPeople"=>7378, "oneTestPerPeople"=>21, "activePerOneMillion"=>758.23, "recoveredPerOneMillion"=>9084.12, "criticalPerOneMillion"=>10.99}
{"updated"=>1594779763504, "country"=>"Mexico", "countryInfo"=>{"_id"=>484, "iso2"=>"MX", "iso3"=>"MEX", "lat"=>23, "long"=>-102, "flag"=>"https://disease.sh/assets/img/flags/mx.png"}, "cases"=>311486, "todayCases"=>7051, "deaths"=>36327, "todayDeaths"=>836, "recovered"=>193976, "todayRecovered"=>4913, "active"=>81183, "critical"=>378, "casesPerOneMillion"=>2415, "deathsPerOneMillion"=>282, "tests"=>756137, "testsPerOneMillion"=>5862, "population"=>128981086, "continent"=>"North America", "oneCasePerPeople"=>414, "oneDeathPerPeople"=>3551, "oneTestPerPeople"=>171, "activePerOneMillion"=>629.42, "recoveredPerOneMillion"=>1503.91, "criticalPerOneMillion"=>2.93}
{"updated"=>1594779763576, "country"=>"Moldova", "countryInfo"=>{"_id"=>498, "iso2"=>"MD", "iso3"=>"MDA", "lat"=>47, "long"=>29, "flag"=>"https://disease.sh/assets/img/flags/md.png"}, "cases"=>19708, "todayCases"=>0, "deaths"=>655, "todayDeaths"=>0, "recovered"=>13033, "todayRecovered"=>0, "active"=>6020, "critical"=>358, "casesPerOneMillion"=>4886, "deathsPerOneMillion"=>162, "tests"=>101180, "testsPerOneMillion"=>25084, "population"=>4033570, "continent"=>"Europe", "oneCasePerPeople"=>205, "oneDeathPerPeople"=>6158, "oneTestPerPeople"=>40, "activePerOneMillion"=>1492.47, "recoveredPerOneMillion"=>3231.13, "criticalPerOneMillion"=>88.76}
{"updated"=>1594779763720, "country"=>"Monaco", "countryInfo"=>{"_id"=>492, "iso2"=>"MC", "iso3"=>"MCO", "lat"=>43.7333, "long"=>7.4, "flag"=>"https://disease.sh/assets/img/flags/mc.png"}, "cases"=>109, "todayCases"=>0, "deaths"=>4, "todayDeaths"=>0, "recovered"=>97, "todayRecovered"=>0, "active"=>8, "critical"=>0, "casesPerOneMillion"=>2777, "deathsPerOneMillion"=>102, "tests"=>16200, "testsPerOneMillion"=>412718, "population"=>39252, "continent"=>"Europe", "oneCasePerPeople"=>360, "oneDeathPerPeople"=>9813, "oneTestPerPeople"=>2, "activePerOneMillion"=>203.81, "recoveredPerOneMillion"=>2471.21, "criticalPerOneMillion"=>0}
{"updated"=>1594779763710, "country"=>"Mongolia", "countryInfo"=>{"_id"=>496, "iso2"=>"MN", "iso3"=>"MNG", "lat"=>46, "long"=>105, "flag"=>"https://disease.sh/assets/img/flags/mn.png"}, "cases"=>243, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>204, "todayRecovered"=>0, "active"=>39, "critical"=>3, "casesPerOneMillion"=>74, "deathsPerOneMillion"=>0, "tests"=>27905, "testsPerOneMillion"=>8508, "population"=>3280024, "continent"=>"Asia", "oneCasePerPeople"=>13498, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>118, "activePerOneMillion"=>11.89, "recoveredPerOneMillion"=>62.19, "criticalPerOneMillion"=>0.91}
{"updated"=>1594779763669, "country"=>"Montenegro", "countryInfo"=>{"_id"=>499, "iso2"=>"ME", "iso3"=>"MNE", "lat"=>42, "long"=>19, "flag"=>"https://disease.sh/assets/img/flags/me.png"}, "cases"=>1287, "todayCases"=>0, "deaths"=>24, "todayDeaths"=>0, "recovered"=>330, "todayRecovered"=>0, "active"=>933, "critical"=>7, "casesPerOneMillion"=>2049, "deathsPerOneMillion"=>38, "tests"=>24972, "testsPerOneMillion"=>39760, "population"=>628069, "continent"=>"Europe", "oneCasePerPeople"=>488, "oneDeathPerPeople"=>26170, "oneTestPerPeople"=>25, "activePerOneMillion"=>1485.51, "recoveredPerOneMillion"=>525.42, "criticalPerOneMillion"=>11.15}
{"updated"=>1594779763748, "country"=>"Montserrat", "countryInfo"=>{"_id"=>500, "iso2"=>"MS", "iso3"=>"MSR", "lat"=>16.75, "long"=>-62.2, "flag"=>"https://disease.sh/assets/img/flags/ms.png"}, "cases"=>12, "todayCases"=>0, "deaths"=>1, "todayDeaths"=>0, "recovered"=>10, "todayRecovered"=>0, "active"=>1, "critical"=>0, "casesPerOneMillion"=>2404, "deathsPerOneMillion"=>200, "tests"=>61, "testsPerOneMillion"=>12220, "population"=>4992, "continent"=>"North America", "oneCasePerPeople"=>416, "oneDeathPerPeople"=>4992, "oneTestPerPeople"=>82, "activePerOneMillion"=>200.32, "recoveredPerOneMillion"=>2003.21, "criticalPerOneMillion"=>0}
{"updated"=>1594779763580, "country"=>"Morocco", "countryInfo"=>{"_id"=>504, "iso2"=>"MA", "iso3"=>"MAR", "lat"=>32, "long"=>-5, "flag"=>"https://disease.sh/assets/img/flags/ma.png"}, "cases"=>16097, "todayCases"=>0, "deaths"=>257, "todayDeaths"=>0, "recovered"=>13442, "todayRecovered"=>0, "active"=>2398, "critical"=>31, "casesPerOneMillion"=>436, "deathsPerOneMillion"=>7, "tests"=>915140, "testsPerOneMillion"=>24783, "population"=>36925874, "continent"=>"Africa", "oneCasePerPeople"=>2294, "oneDeathPerPeople"=>143680, "oneTestPerPeople"=>40, "activePerOneMillion"=>64.94, "recoveredPerOneMillion"=>364.03, "criticalPerOneMillion"=>0.84}
{"updated"=>1594779763670, "country"=>"Mozambique", "countryInfo"=>{"_id"=>508, "iso2"=>"MZ", "iso3"=>"MOZ", "lat"=>-18.25, "long"=>35, "flag"=>"https://disease.sh/assets/img/flags/mz.png"}, "cases"=>1268, "todayCases"=>0, "deaths"=>9, "todayDeaths"=>0, "recovered"=>373, "todayRecovered"=>0, "active"=>886, "critical"=>0, "casesPerOneMillion"=>41, "deathsPerOneMillion"=>0.3, "tests"=>40861, "testsPerOneMillion"=>1306, "population"=>31278721, "continent"=>"Africa", "oneCasePerPeople"=>24668, "oneDeathPerPeople"=>3475413, "oneTestPerPeople"=>765, "activePerOneMillion"=>28.33, "recoveredPerOneMillion"=>11.93, "criticalPerOneMillion"=>0}
{"updated"=>1594779763702, "country"=>"Myanmar", "countryInfo"=>{"_id"=>104, "iso2"=>"MM", "iso3"=>"MMR", "lat"=>22, "long"=>98, "flag"=>"https://disease.sh/assets/img/flags/mm.png"}, "cases"=>337, "todayCases"=>0, "deaths"=>6, "todayDeaths"=>0, "recovered"=>261, "todayRecovered"=>0, "active"=>70, "critical"=>0, "casesPerOneMillion"=>6, "deathsPerOneMillion"=>0.1, "tests"=>94168, "testsPerOneMillion"=>1730, "population"=>54423505, "continent"=>"Asia", "oneCasePerPeople"=>161494, "oneDeathPerPeople"=>9070584, "oneTestPerPeople"=>578, "activePerOneMillion"=>1.29, "recoveredPerOneMillion"=>4.8, "criticalPerOneMillion"=>0}
{"updated"=>1594779763683, "country"=>"Namibia", "countryInfo"=>{"_id"=>516, "iso2"=>"NA", "iso3"=>"NAM", "lat"=>-22, "long"=>17, "flag"=>"https://disease.sh/assets/img/flags/na.png"}, "cases"=>864, "todayCases"=>0, "deaths"=>2, "todayDeaths"=>0, "recovered"=>29, "todayRecovered"=>0, "active"=>833, "critical"=>1, "casesPerOneMillion"=>340, "deathsPerOneMillion"=>0.8, "tests"=>15439, "testsPerOneMillion"=>6073, "population"=>2542369, "continent"=>"Africa", "oneCasePerPeople"=>2943, "oneDeathPerPeople"=>1271185, "oneTestPerPeople"=>165, "activePerOneMillion"=>327.65, "recoveredPerOneMillion"=>11.41, "criticalPerOneMillion"=>0.39}
{"updated"=>1594779763579, "country"=>"Nepal", "countryInfo"=>{"_id"=>524, "iso2"=>"NP", "iso3"=>"NPL", "lat"=>28, "long"=>84, "flag"=>"https://disease.sh/assets/img/flags/np.png"}, "cases"=>17061, "todayCases"=>0, "deaths"=>38, "todayDeaths"=>0, "recovered"=>10328, "todayRecovered"=>0, "active"=>6695, "critical"=>0, "casesPerOneMillion"=>585, "deathsPerOneMillion"=>1, "tests"=>606141, "testsPerOneMillion"=>20791, "population"=>29153511, "continent"=>"Asia", "oneCasePerPeople"=>1709, "oneDeathPerPeople"=>767198, "oneTestPerPeople"=>48, "activePerOneMillion"=>229.65, "recoveredPerOneMillion"=>354.26, "criticalPerOneMillion"=>0}
{"updated"=>1594779763546, "country"=>"Netherlands", "countryInfo"=>{"_id"=>528, "iso2"=>"NL", "iso3"=>"NLD", "lat"=>52.5, "long"=>5.75, "flag"=>"https://disease.sh/assets/img/flags/nl.png"}, "cases"=>51146, "todayCases"=>0, "deaths"=>6135, "todayDeaths"=>0, "recovered"=>0, "todayRecovered"=>0, "active"=>45011, "critical"=>20, "casesPerOneMillion"=>2985, "deathsPerOneMillion"=>358, "tests"=>764079, "testsPerOneMillion"=>44588, "population"=>17136380, "continent"=>"Europe", "oneCasePerPeople"=>335, "oneDeathPerPeople"=>2793, "oneTestPerPeople"=>22, "activePerOneMillion"=>2626.63, "recoveredPerOneMillion"=>0, "criticalPerOneMillion"=>1.17}
{"updated"=>1594779763743, "country"=>"New Caledonia", "countryInfo"=>{"_id"=>540, "iso2"=>"NC", "iso3"=>"NCL", "lat"=>-21.5, "long"=>165.5, "flag"=>"https://disease.sh/assets/img/flags/nc.png"}, "cases"=>21, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>21, "todayRecovered"=>0, "active"=>0, "critical"=>0, "casesPerOneMillion"=>74, "deathsPerOneMillion"=>0, "tests"=>9218, "testsPerOneMillion"=>32276, "population"=>285597, "continent"=>"Australia/Oceania", "oneCasePerPeople"=>13600, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>31, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>73.53, "criticalPerOneMillion"=>0}
{"updated"=>1594779763662, "country"=>"New Zealand", "countryInfo"=>{"_id"=>554, "iso2"=>"NZ", "iso3"=>"NZL", "lat"=>-41, "long"=>174, "flag"=>"https://disease.sh/assets/img/flags/nz.png"}, "cases"=>1547, "todayCases"=>2, "deaths"=>22, "todayDeaths"=>0, "recovered"=>1498, "todayRecovered"=>0, "active"=>27, "critical"=>0, "casesPerOneMillion"=>309, "deathsPerOneMillion"=>4, "tests"=>433324, "testsPerOneMillion"=>86628, "population"=>5002100, "continent"=>"Australia/Oceania", "oneCasePerPeople"=>3233, "oneDeathPerPeople"=>227368, "oneTestPerPeople"=>12, "activePerOneMillion"=>5.4, "recoveredPerOneMillion"=>299.47, "criticalPerOneMillion"=>0}
{"updated"=>1594779763628, "country"=>"Nicaragua", "countryInfo"=>{"_id"=>558, "iso2"=>"NI", "iso3"=>"NIC", "lat"=>13, "long"=>-85, "flag"=>"https://disease.sh/assets/img/flags/ni.png"}, "cases"=>3147, "todayCases"=>0, "deaths"=>99, "todayDeaths"=>0, "recovered"=>2282, "todayRecovered"=>0, "active"=>766, "critical"=>0, "casesPerOneMillion"=>475, "deathsPerOneMillion"=>15, "tests"=>0, "testsPerOneMillion"=>0, "population"=>6627311, "continent"=>"North America", "oneCasePerPeople"=>2106, "oneDeathPerPeople"=>66943, "oneTestPerPeople"=>0, "activePerOneMillion"=>115.58, "recoveredPerOneMillion"=>344.33, "criticalPerOneMillion"=>0}
{"updated"=>1594779763673, "country"=>"Niger", "countryInfo"=>{"_id"=>562, "iso2"=>"NE", "iso3"=>"NER", "lat"=>16, "long"=>8, "flag"=>"https://disease.sh/assets/img/flags/ne.png"}, "cases"=>1099, "todayCases"=>0, "deaths"=>68, "todayDeaths"=>0, "recovered"=>992, "todayRecovered"=>0, "active"=>39, "critical"=>0, "casesPerOneMillion"=>45, "deathsPerOneMillion"=>3, "tests"=>6658, "testsPerOneMillion"=>275, "population"=>24226032, "continent"=>"Africa", "oneCasePerPeople"=>22044, "oneDeathPerPeople"=>356265, "oneTestPerPeople"=>3639, "activePerOneMillion"=>1.61, "recoveredPerOneMillion"=>40.95, "criticalPerOneMillion"=>0}
{"updated"=>1594779763559, "country"=>"Nigeria", "countryInfo"=>{"_id"=>566, "iso2"=>"NG", "iso3"=>"NGA", "lat"=>10, "long"=>8, "flag"=>"https://disease.sh/assets/img/flags/ng.png"}, "cases"=>33616, "todayCases"=>0, "deaths"=>754, "todayDeaths"=>0, "recovered"=>13792, "todayRecovered"=>0, "active"=>19070, "critical"=>7, "casesPerOneMillion"=>163, "deathsPerOneMillion"=>4, "tests"=>186309, "testsPerOneMillion"=>903, "population"=>206284260, "continent"=>"Africa", "oneCasePerPeople"=>6136, "oneDeathPerPeople"=>273587, "oneTestPerPeople"=>1107, "activePerOneMillion"=>92.45, "recoveredPerOneMillion"=>66.86, "criticalPerOneMillion"=>0.03}
{"updated"=>1594779763595, "country"=>"Norway", "countryInfo"=>{"_id"=>578, "iso2"=>"NO", "iso3"=>"NOR", "lat"=>62, "long"=>10, "flag"=>"https://disease.sh/assets/img/flags/no.png"}, "cases"=>9001, "todayCases"=>0, "deaths"=>253, "todayDeaths"=>0, "recovered"=>8138, "todayRecovered"=>0, "active"=>610, "critical"=>1, "casesPerOneMillion"=>1660, "deathsPerOneMillion"=>47, "tests"=>383149, "testsPerOneMillion"=>70655, "population"=>5422810, "continent"=>"Europe", "oneCasePerPeople"=>602, "oneDeathPerPeople"=>21434, "oneTestPerPeople"=>14, "activePerOneMillion"=>112.49, "recoveredPerOneMillion"=>1500.7, "criticalPerOneMillion"=>0.18}
{"updated"=>1594779763540, "country"=>"Oman", "countryInfo"=>{"_id"=>512, "iso2"=>"OM", "iso3"=>"OMN", "lat"=>21, "long"=>57, "flag"=>"https://disease.sh/assets/img/flags/om.png"}, "cases"=>59568, "todayCases"=>0, "deaths"=>273, "todayDeaths"=>0, "recovered"=>37987, "todayRecovered"=>0, "active"=>21308, "critical"=>149, "casesPerOneMillion"=>11657, "deathsPerOneMillion"=>53, "tests"=>244831, "testsPerOneMillion"=>47910, "population"=>5110259, "continent"=>"Asia", "oneCasePerPeople"=>86, "oneDeathPerPeople"=>18719, "oneTestPerPeople"=>21, "activePerOneMillion"=>4169.65, "recoveredPerOneMillion"=>7433.48, "criticalPerOneMillion"=>29.16}
{"updated"=>1594779763512, "country"=>"Pakistan", "countryInfo"=>{"_id"=>586, "iso2"=>"PK", "iso3"=>"PAK", "lat"=>30, "long"=>70, "flag"=>"https://disease.sh/assets/img/flags/pk.png"}, "cases"=>253604, "todayCases"=>0, "deaths"=>5320, "todayDeaths"=>0, "recovered"=>170656, "todayRecovered"=>0, "active"=>77628, "critical"=>2151, "casesPerOneMillion"=>1147, "deathsPerOneMillion"=>24, "tests"=>1606190, "testsPerOneMillion"=>7267, "population"=>221025870, "continent"=>"Asia", "oneCasePerPeople"=>872, "oneDeathPerPeople"=>41546, "oneTestPerPeople"=>138, "activePerOneMillion"=>351.22, "recoveredPerOneMillion"=>772.11, "criticalPerOneMillion"=>9.73}
{"updated"=>1594779763607, "country"=>"Palestine", "countryInfo"=>{"_id"=>275, "iso2"=>"PS", "iso3"=>"PSE", "lat"=>32, "long"=>35.25, "flag"=>"https://disease.sh/assets/img/flags/ps.png"}, "cases"=>6764, "todayCases"=>0, "deaths"=>44, "todayDeaths"=>0, "recovered"=>1084, "todayRecovered"=>0, "active"=>5636, "critical"=>0, "casesPerOneMillion"=>1325, "deathsPerOneMillion"=>9, "tests"=>141444, "testsPerOneMillion"=>27708, "population"=>5104868, "continent"=>"Asia", "oneCasePerPeople"=>755, "oneDeathPerPeople"=>116020, "oneTestPerPeople"=>36, "activePerOneMillion"=>1104.04, "recoveredPerOneMillion"=>212.35, "criticalPerOneMillion"=>0}
{"updated"=>1594779763549, "country"=>"Panama", "countryInfo"=>{"_id"=>591, "iso2"=>"PA", "iso3"=>"PAN", "lat"=>9, "long"=>-80, "flag"=>"https://disease.sh/assets/img/flags/pa.png"}, "cases"=>48096, "todayCases"=>0, "deaths"=>960, "todayDeaths"=>0, "recovered"=>24667, "todayRecovered"=>4, "active"=>22469, "critical"=>157, "casesPerOneMillion"=>11141, "deathsPerOneMillion"=>222, "tests"=>171116, "testsPerOneMillion"=>39638, "population"=>4317010, "continent"=>"North America", "oneCasePerPeople"=>90, "oneDeathPerPeople"=>4497, "oneTestPerPeople"=>25, "activePerOneMillion"=>5204.76, "recoveredPerOneMillion"=>5713.91, "criticalPerOneMillion"=>36.37}
{"updated"=>1594779763751, "country"=>"Papua New Guinea", "countryInfo"=>{"_id"=>598, "iso2"=>"PG", "iso3"=>"PNG", "lat"=>-6, "long"=>147, "flag"=>"https://disease.sh/assets/img/flags/pg.png"}, "cases"=>11, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>8, "todayRecovered"=>0, "active"=>3, "critical"=>0, "casesPerOneMillion"=>1, "deathsPerOneMillion"=>0, "tests"=>7147, "testsPerOneMillion"=>798, "population"=>8952342, "continent"=>"Australia/Oceania", "oneCasePerPeople"=>813849, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>1253, "activePerOneMillion"=>0.34, "recoveredPerOneMillion"=>0.89, "criticalPerOneMillion"=>0}
{"updated"=>1594779763631, "country"=>"Paraguay", "countryInfo"=>{"_id"=>600, "iso2"=>"PY", "iso3"=>"PRY", "lat"=>-23, "long"=>-58, "flag"=>"https://disease.sh/assets/img/flags/py.png"}, "cases"=>3074, "todayCases"=>0, "deaths"=>25, "todayDeaths"=>0, "recovered"=>1308, "todayRecovered"=>0, "active"=>1741, "critical"=>10, "casesPerOneMillion"=>431, "deathsPerOneMillion"=>4, "tests"=>94328, "testsPerOneMillion"=>13219, "population"=>7135586, "continent"=>"South America", "oneCasePerPeople"=>2321, "oneDeathPerPeople"=>285423, "oneTestPerPeople"=>76, "activePerOneMillion"=>243.99, "recoveredPerOneMillion"=>183.31, "criticalPerOneMillion"=>1.4}
{"updated"=>1594779763501, "country"=>"Peru", "countryInfo"=>{"_id"=>604, "iso2"=>"PE", "iso3"=>"PER", "lat"=>-10, "long"=>-76, "flag"=>"https://disease.sh/assets/img/flags/pe.png"}, "cases"=>333867, "todayCases"=>0, "deaths"=>12229, "todayDeaths"=>0, "recovered"=>223261, "todayRecovered"=>0, "active"=>98377, "critical"=>1325, "casesPerOneMillion"=>10121, "deathsPerOneMillion"=>371, "tests"=>1963921, "testsPerOneMillion"=>59535, "population"=>32987448, "continent"=>"South America", "oneCasePerPeople"=>99, "oneDeathPerPeople"=>2697, "oneTestPerPeople"=>17, "activePerOneMillion"=>2982.26, "recoveredPerOneMillion"=>6768.06, "criticalPerOneMillion"=>40.17}
{"updated"=>1594779763542, "country"=>"Philippines", "countryInfo"=>{"_id"=>608, "iso2"=>"PH", "iso3"=>"PHL", "lat"=>13, "long"=>122, "flag"=>"https://disease.sh/assets/img/flags/ph.png"}, "cases"=>57545, "todayCases"=>0, "deaths"=>1603, "todayDeaths"=>0, "recovered"=>20459, "todayRecovered"=>0, "active"=>35483, "critical"=>333, "casesPerOneMillion"=>525, "deathsPerOneMillion"=>15, "tests"=>1017723, "testsPerOneMillion"=>9283, "population"=>109631056, "continent"=>"Asia", "oneCasePerPeople"=>1905, "oneDeathPerPeople"=>68391, "oneTestPerPeople"=>108, "activePerOneMillion"=>323.66, "recoveredPerOneMillion"=>186.62, "criticalPerOneMillion"=>3.04}
{"updated"=>1594779763555, "country"=>"Poland", "countryInfo"=>{"_id"=>616, "iso2"=>"PL", "iso3"=>"POL", "lat"=>52, "long"=>20, "flag"=>"https://disease.sh/assets/img/flags/pl.png"}, "cases"=>38457, "todayCases"=>0, "deaths"=>1588, "todayDeaths"=>0, "recovered"=>27756, "todayRecovered"=>0, "active"=>9113, "critical"=>74, "casesPerOneMillion"=>1016, "deathsPerOneMillion"=>42, "tests"=>1813365, "testsPerOneMillion"=>47916, "population"=>37844896, "continent"=>"Europe", "oneCasePerPeople"=>984, "oneDeathPerPeople"=>23832, "oneTestPerPeople"=>21, "activePerOneMillion"=>240.8, "recoveredPerOneMillion"=>733.41, "criticalPerOneMillion"=>1.96}
{"updated"=>1594779763550, "country"=>"Portugal", "countryInfo"=>{"_id"=>620, "iso2"=>"PT", "iso3"=>"PRT", "lat"=>39.5, "long"=>-8, "flag"=>"https://disease.sh/assets/img/flags/pt.png"}, "cases"=>47051, "todayCases"=>0, "deaths"=>1668, "todayDeaths"=>0, "recovered"=>31550, "todayRecovered"=>0, "active"=>13833, "critical"=>69, "casesPerOneMillion"=>4615, "deathsPerOneMillion"=>164, "tests"=>1366864, "testsPerOneMillion"=>134066, "population"=>10195453, "continent"=>"Europe", "oneCasePerPeople"=>217, "oneDeathPerPeople"=>6112, "oneTestPerPeople"=>7, "activePerOneMillion"=>1356.78, "recoveredPerOneMillion"=>3094.52, "criticalPerOneMillion"=>6.77}
{"updated"=>1594779763530, "country"=>"Qatar", "countryInfo"=>{"_id"=>634, "iso2"=>"QA", "iso3"=>"QAT", "lat"=>25.5, "long"=>51.25, "flag"=>"https://disease.sh/assets/img/flags/qa.png"}, "cases"=>104533, "todayCases"=>0, "deaths"=>150, "todayDeaths"=>0, "recovered"=>101160, "todayRecovered"=>0, "active"=>3223, "critical"=>137, "casesPerOneMillion"=>37229, "deathsPerOneMillion"=>53, "tests"=>420649, "testsPerOneMillion"=>149814, "population"=>2807805, "continent"=>"Asia", "oneCasePerPeople"=>27, "oneDeathPerPeople"=>18719, "oneTestPerPeople"=>7, "activePerOneMillion"=>1147.87, "recoveredPerOneMillion"=>36028.14, "criticalPerOneMillion"=>48.79}
{"updated"=>1594779763560, "country"=>"Romania", "countryInfo"=>{"_id"=>642, "iso2"=>"RO", "iso3"=>"ROU", "lat"=>46, "long"=>25, "flag"=>"https://disease.sh/assets/img/flags/ro.png"}, "cases"=>33585, "todayCases"=>0, "deaths"=>1931, "todayDeaths"=>0, "recovered"=>21803, "todayRecovered"=>0, "active"=>9851, "critical"=>234, "casesPerOneMillion"=>1746, "deathsPerOneMillion"=>100, "tests"=>868478, "testsPerOneMillion"=>45158, "population"=>19232044, "continent"=>"Europe", "oneCasePerPeople"=>573, "oneDeathPerPeople"=>9960, "oneTestPerPeople"=>22, "activePerOneMillion"=>512.22, "recoveredPerOneMillion"=>1133.68, "criticalPerOneMillion"=>12.17}
{"updated"=>1594779763500, "country"=>"Russia", "countryInfo"=>{"_id"=>643, "iso2"=>"RU", "iso3"=>"RUS", "lat"=>60, "long"=>100, "flag"=>"https://disease.sh/assets/img/flags/ru.png"}, "cases"=>739947, "todayCases"=>0, "deaths"=>11614, "todayDeaths"=>0, "recovered"=>512825, "todayRecovered"=>0, "active"=>215508, "critical"=>2300, "casesPerOneMillion"=>5070, "deathsPerOneMillion"=>80, "tests"=>23495752, "testsPerOneMillion"=>160999, "population"=>145937005, "continent"=>"Europe", "oneCasePerPeople"=>197, "oneDeathPerPeople"=>12566, "oneTestPerPeople"=>6, "activePerOneMillion"=>1476.72, "recoveredPerOneMillion"=>3514.02, "criticalPerOneMillion"=>15.76}
{"updated"=>1594779763665, "country"=>"Rwanda", "countryInfo"=>{"_id"=>646, "iso2"=>"RW", "iso3"=>"RWA", "lat"=>-2, "long"=>30, "flag"=>"https://disease.sh/assets/img/flags/rw.png"}, "cases"=>1416, "todayCases"=>0, "deaths"=>4, "todayDeaths"=>0, "recovered"=>737, "todayRecovered"=>0, "active"=>675, "critical"=>0, "casesPerOneMillion"=>109, "deathsPerOneMillion"=>0.3, "tests"=>192379, "testsPerOneMillion"=>14843, "population"=>12961309, "continent"=>"Africa", "oneCasePerPeople"=>9153, "oneDeathPerPeople"=>3240327, "oneTestPerPeople"=>67, "activePerOneMillion"=>52.08, "recoveredPerOneMillion"=>56.86, "criticalPerOneMillion"=>0}
{"updated"=>1594779763693, "country"=>"Réunion", "countryInfo"=>{"_id"=>638, "iso2"=>"RE", "iso3"=>"REU", "lat"=>-21.1, "long"=>55.6, "flag"=>"https://disease.sh/assets/img/flags/re.png"}, "cases"=>599, "todayCases"=>0, "deaths"=>3, "todayDeaths"=>0, "recovered"=>472, "todayRecovered"=>0, "active"=>124, "critical"=>3, "casesPerOneMillion"=>669, "deathsPerOneMillion"=>3, "tests"=>35419, "testsPerOneMillion"=>39550, "population"=>895551, "continent"=>"Africa", "oneCasePerPeople"=>1495, "oneDeathPerPeople"=>298517, "oneTestPerPeople"=>25, "activePerOneMillion"=>138.46, "recoveredPerOneMillion"=>527.05, "criticalPerOneMillion"=>3.35}
{"updated"=>1594779763584, "country"=>"S. Korea", "countryInfo"=>{"_id"=>410, "iso2"=>"KR", "iso3"=>"KOR", "lat"=>37, "long"=>127.5, "flag"=>"https://disease.sh/assets/img/flags/kr.png"}, "cases"=>13551, "todayCases"=>39, "deaths"=>289, "todayDeaths"=>0, "recovered"=>12348, "todayRecovered"=>66, "active"=>914, "critical"=>15, "casesPerOneMillion"=>264, "deathsPerOneMillion"=>6, "tests"=>1431316, "testsPerOneMillion"=>27917, "population"=>51270969, "continent"=>"Asia", "oneCasePerPeople"=>3784, "oneDeathPerPeople"=>177408, "oneTestPerPeople"=>36, "activePerOneMillion"=>17.83, "recoveredPerOneMillion"=>240.84, "criticalPerOneMillion"=>0.29}
{"updated"=>1594779763746, "country"=>"Saint Kitts and Nevis", "countryInfo"=>{"_id"=>659, "iso2"=>"KN", "iso3"=>"KNA", "lat"=>17.3333, "long"=>-62.75, "flag"=>"https://disease.sh/assets/img/flags/kn.png"}, "cases"=>17, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>15, "todayRecovered"=>0, "active"=>2, "critical"=>0, "casesPerOneMillion"=>319, "deathsPerOneMillion"=>0, "tests"=>671, "testsPerOneMillion"=>12610, "population"=>53213, "continent"=>"North America", "oneCasePerPeople"=>3130, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>79, "activePerOneMillion"=>37.58, "recoveredPerOneMillion"=>281.89, "criticalPerOneMillion"=>0}
{"updated"=>1594779763742, "country"=>"Saint Lucia", "countryInfo"=>{"_id"=>662, "iso2"=>"LC", "iso3"=>"LCA", "lat"=>13.8833, "long"=>-61.1333, "flag"=>"https://disease.sh/assets/img/flags/lc.png"}, "cases"=>22, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>19, "todayRecovered"=>0, "active"=>3, "critical"=>0, "casesPerOneMillion"=>120, "deathsPerOneMillion"=>0, "tests"=>2048, "testsPerOneMillion"=>11151, "population"=>183659, "continent"=>"North America", "oneCasePerPeople"=>8348, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>90, "activePerOneMillion"=>16.33, "recoveredPerOneMillion"=>103.45, "criticalPerOneMillion"=>0}
{"updated"=>1594779763735, "country"=>"Saint Martin", "countryInfo"=>{"_id"=>663, "iso2"=>"MF", "iso3"=>"MAF", "lat"=>18.11, "long"=>-63.03, "flag"=>"https://disease.sh/assets/img/flags/mf.png"}, "cases"=>43, "todayCases"=>0, "deaths"=>3, "todayDeaths"=>0, "recovered"=>37, "todayRecovered"=>0, "active"=>3, "critical"=>1, "casesPerOneMillion"=>1111, "deathsPerOneMillion"=>78, "tests"=>851, "testsPerOneMillion"=>21997, "population"=>38687, "continent"=>"North America", "oneCasePerPeople"=>900, "oneDeathPerPeople"=>12896, "oneTestPerPeople"=>45, "activePerOneMillion"=>77.55, "recoveredPerOneMillion"=>956.39, "criticalPerOneMillion"=>25.85}
{"updated"=>1594779763758, "country"=>"Saint Pierre Miquelon", "countryInfo"=>{"_id"=>666, "iso2"=>"PM", "iso3"=>"SPM", "lat"=>46.8333, "long"=>-56.3333, "flag"=>"https://disease.sh/assets/img/flags/pm.png"}, "cases"=>2, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>1, "todayRecovered"=>0, "active"=>1, "critical"=>0, "casesPerOneMillion"=>345, "deathsPerOneMillion"=>0, "tests"=>0, "testsPerOneMillion"=>0, "population"=>5793, "continent"=>"North America", "oneCasePerPeople"=>2897, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>0, "activePerOneMillion"=>172.62, "recoveredPerOneMillion"=>172.62, "criticalPerOneMillion"=>0}
{"updated"=>1594779763737, "country"=>"Saint Vincent and the Grenadines", "countryInfo"=>{"_id"=>670, "iso2"=>"VC", "iso3"=>"VCT", "lat"=>13.25, "long"=>-61.2, "flag"=>"https://disease.sh/assets/img/flags/vc.png"}, "cases"=>35, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>29, "todayRecovered"=>0, "active"=>6, "critical"=>0, "casesPerOneMillion"=>315, "deathsPerOneMillion"=>0, "tests"=>1213, "testsPerOneMillion"=>10932, "population"=>110954, "continent"=>"North America", "oneCasePerPeople"=>3170, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>91, "activePerOneMillion"=>54.08, "recoveredPerOneMillion"=>261.37, "criticalPerOneMillion"=>0}
{"updated"=>1594779763691, "country"=>"San Marino", "countryInfo"=>{"_id"=>674, "iso2"=>"SM", "iso3"=>"SMR", "lat"=>43.7667, "long"=>12.4167, "flag"=>"https://disease.sh/assets/img/flags/sm.png"}, "cases"=>699, "todayCases"=>0, "deaths"=>42, "todayDeaths"=>0, "recovered"=>656, "todayRecovered"=>0, "active"=>1, "critical"=>0, "casesPerOneMillion"=>20599, "deathsPerOneMillion"=>1238, "tests"=>5729, "testsPerOneMillion"=>168828, "population"=>33934, "continent"=>"Europe", "oneCasePerPeople"=>49, "oneDeathPerPeople"=>808, "oneTestPerPeople"=>6, "activePerOneMillion"=>29.47, "recoveredPerOneMillion"=>19331.64, "criticalPerOneMillion"=>0}
{"updated"=>1594779763688, "country"=>"Sao Tome and Principe", "countryInfo"=>{"_id"=>678, "iso2"=>"ST", "iso3"=>"STP", "lat"=>1, "long"=>7, "flag"=>"https://disease.sh/assets/img/flags/st.png"}, "cases"=>732, "todayCases"=>0, "deaths"=>14, "todayDeaths"=>0, "recovered"=>286, "todayRecovered"=>0, "active"=>432, "critical"=>0, "casesPerOneMillion"=>3338, "deathsPerOneMillion"=>64, "tests"=>1973, "testsPerOneMillion"=>8997, "population"=>219287, "continent"=>"Africa", "oneCasePerPeople"=>300, "oneDeathPerPeople"=>15663, "oneTestPerPeople"=>111, "activePerOneMillion"=>1970.02, "recoveredPerOneMillion"=>1304.23, "criticalPerOneMillion"=>0}
{"updated"=>1594779763516, "country"=>"Saudi Arabia", "countryInfo"=>{"_id"=>682, "iso2"=>"SA", "iso3"=>"SAU", "lat"=>25, "long"=>45, "flag"=>"https://disease.sh/assets/img/flags/sa.png"}, "cases"=>237803, "todayCases"=>0, "deaths"=>2283, "todayDeaths"=>0, "recovered"=>177560, "todayRecovered"=>0, "active"=>57960, "critical"=>2235, "casesPerOneMillion"=>6827, "deathsPerOneMillion"=>66, "tests"=>2336874, "testsPerOneMillion"=>67090, "population"=>34831824, "continent"=>"Asia", "oneCasePerPeople"=>146, "oneDeathPerPeople"=>15257, "oneTestPerPeople"=>15, "activePerOneMillion"=>1664, "recoveredPerOneMillion"=>5097.64, "criticalPerOneMillion"=>64.17}
{"updated"=>1594779763600, "country"=>"Senegal", "countryInfo"=>{"_id"=>686, "iso2"=>"SN", "iso3"=>"SEN", "lat"=>14, "long"=>-14, "flag"=>"https://disease.sh/assets/img/flags/sn.png"}, "cases"=>8243, "todayCases"=>0, "deaths"=>150, "todayDeaths"=>0, "recovered"=>5580, "todayRecovered"=>0, "active"=>2513, "critical"=>36, "casesPerOneMillion"=>492, "deathsPerOneMillion"=>9, "tests"=>92101, "testsPerOneMillion"=>5497, "population"=>16756053, "continent"=>"Africa", "oneCasePerPeople"=>2033, "oneDeathPerPeople"=>111707, "oneTestPerPeople"=>182, "activePerOneMillion"=>149.98, "recoveredPerOneMillion"=>333.01, "criticalPerOneMillion"=>2.15}
{"updated"=>1594779763578, "country"=>"Serbia", "countryInfo"=>{"_id"=>688, "iso2"=>"RS", "iso3"=>"SRB", "lat"=>44, "long"=>21, "flag"=>"https://disease.sh/assets/img/flags/rs.png"}, "cases"=>18983, "todayCases"=>0, "deaths"=>418, "todayDeaths"=>0, "recovered"=>13991, "todayRecovered"=>0, "active"=>4574, "critical"=>170, "casesPerOneMillion"=>2173, "deathsPerOneMillion"=>48, "tests"=>507002, "testsPerOneMillion"=>58037, "population"=>8735866, "continent"=>"Europe", "oneCasePerPeople"=>460, "oneDeathPerPeople"=>20899, "oneTestPerPeople"=>17, "activePerOneMillion"=>523.59, "recoveredPerOneMillion"=>1601.56, "criticalPerOneMillion"=>19.46}
{"updated"=>1594779763722, "country"=>"Seychelles", "countryInfo"=>{"_id"=>690, "iso2"=>"SC", "iso3"=>"SYC", "lat"=>-4.5833, "long"=>55.6667, "flag"=>"https://disease.sh/assets/img/flags/sc.png"}, "cases"=>100, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>11, "todayRecovered"=>0, "active"=>89, "critical"=>0, "casesPerOneMillion"=>1017, "deathsPerOneMillion"=>0, "tests"=>0, "testsPerOneMillion"=>0, "population"=>98370, "continent"=>"Africa", "oneCasePerPeople"=>984, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>0, "activePerOneMillion"=>904.75, "recoveredPerOneMillion"=>111.82, "criticalPerOneMillion"=>0}
{"updated"=>1594779763659, "country"=>"Sierra Leone", "countryInfo"=>{"_id"=>694, "iso2"=>"SL", "iso3"=>"SLE", "lat"=>8.5, "long"=>-11.5, "flag"=>"https://disease.sh/assets/img/flags/sl.png"}, "cases"=>1651, "todayCases"=>0, "deaths"=>64, "todayDeaths"=>0, "recovered"=>1190, "todayRecovered"=>0, "active"=>397, "critical"=>0, "casesPerOneMillion"=>207, "deathsPerOneMillion"=>8, "tests"=>0, "testsPerOneMillion"=>0, "population"=>7981956, "continent"=>"Africa", "oneCasePerPeople"=>4835, "oneDeathPerPeople"=>124718, "oneTestPerPeople"=>0, "activePerOneMillion"=>49.74, "recoveredPerOneMillion"=>149.09, "criticalPerOneMillion"=>0}
{"updated"=>1594779763552, "country"=>"Singapore", "countryInfo"=>{"_id"=>702, "iso2"=>"SG", "iso3"=>"SGP", "lat"=>1.3667, "long"=>103.8, "flag"=>"https://disease.sh/assets/img/flags/sg.png"}, "cases"=>46630, "todayCases"=>0, "deaths"=>27, "todayDeaths"=>0, "recovered"=>42737, "todayRecovered"=>0, "active"=>3866, "critical"=>0, "casesPerOneMillion"=>7968, "deathsPerOneMillion"=>5, "tests"=>1009532, "testsPerOneMillion"=>172509, "population"=>5852044, "continent"=>"Asia", "oneCasePerPeople"=>125, "oneDeathPerPeople"=>216742, "oneTestPerPeople"=>6, "activePerOneMillion"=>660.62, "recoveredPerOneMillion"=>7302.92, "criticalPerOneMillion"=>0}
{"updated"=>1594779763728, "country"=>"Sint Maarten", "countryInfo"=>{"_id"=>534, "iso2"=>"SX", "iso3"=>"SXM", "lat"=>18.02, "long"=>-63.06, "flag"=>"https://disease.sh/assets/img/flags/sx.png"}, "cases"=>78, "todayCases"=>0, "deaths"=>15, "todayDeaths"=>0, "recovered"=>63, "todayRecovered"=>0, "active"=>0, "critical"=>0, "casesPerOneMillion"=>1818, "deathsPerOneMillion"=>350, "tests"=>523, "testsPerOneMillion"=>12193, "population"=>42893, "continent"=>"North America", "oneCasePerPeople"=>550, "oneDeathPerPeople"=>2860, "oneTestPerPeople"=>82, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>1468.77, "criticalPerOneMillion"=>0}
{"updated"=>1594779763647, "country"=>"Slovakia", "countryInfo"=>{"_id"=>703, "iso2"=>"SK", "iso3"=>"SVK", "lat"=>48.6667, "long"=>19.5, "flag"=>"https://disease.sh/assets/img/flags/sk.png"}, "cases"=>1908, "todayCases"=>0, "deaths"=>28, "todayDeaths"=>0, "recovered"=>1493, "todayRecovered"=>0, "active"=>387, "critical"=>3, "casesPerOneMillion"=>349, "deathsPerOneMillion"=>5, "tests"=>231231, "testsPerOneMillion"=>42352, "population"=>5459749, "continent"=>"Europe", "oneCasePerPeople"=>2862, "oneDeathPerPeople"=>194991, "oneTestPerPeople"=>24, "activePerOneMillion"=>70.88, "recoveredPerOneMillion"=>273.46, "criticalPerOneMillion"=>0.55}
{"updated"=>1594779763651, "country"=>"Slovenia", "countryInfo"=>{"_id"=>705, "iso2"=>"SI", "iso3"=>"SVN", "lat"=>46, "long"=>15, "flag"=>"https://disease.sh/assets/img/flags/si.png"}, "cases"=>1859, "todayCases"=>0, "deaths"=>111, "todayDeaths"=>0, "recovered"=>1488, "todayRecovered"=>0, "active"=>260, "critical"=>1, "casesPerOneMillion"=>894, "deathsPerOneMillion"=>53, "tests"=>117241, "testsPerOneMillion"=>56394, "population"=>2078950, "continent"=>"Europe", "oneCasePerPeople"=>1118, "oneDeathPerPeople"=>18729, "oneTestPerPeople"=>18, "activePerOneMillion"=>125.06, "recoveredPerOneMillion"=>715.75, "criticalPerOneMillion"=>0.48}
{"updated"=>1594779763629, "country"=>"Somalia", "countryInfo"=>{"_id"=>706, "iso2"=>"SO", "iso3"=>"SOM", "lat"=>10, "long"=>49, "flag"=>"https://disease.sh/assets/img/flags/so.png"}, "cases"=>3076, "todayCases"=>0, "deaths"=>93, "todayDeaths"=>0, "recovered"=>1380, "todayRecovered"=>0, "active"=>1603, "critical"=>2, "casesPerOneMillion"=>193, "deathsPerOneMillion"=>6, "tests"=>0, "testsPerOneMillion"=>0, "population"=>15905041, "continent"=>"Africa", "oneCasePerPeople"=>5171, "oneDeathPerPeople"=>171022, "oneTestPerPeople"=>0, "activePerOneMillion"=>100.79, "recoveredPerOneMillion"=>86.76, "criticalPerOneMillion"=>0.13}
{"updated"=>1594779763507, "country"=>"South Africa", "countryInfo"=>{"_id"=>710, "iso2"=>"ZA", "iso3"=>"ZAF", "lat"=>-29, "long"=>24, "flag"=>"https://disease.sh/assets/img/flags/za.png"}, "cases"=>298292, "todayCases"=>0, "deaths"=>4346, "todayDeaths"=>0, "recovered"=>146279, "todayRecovered"=>0, "active"=>147667, "critical"=>539, "casesPerOneMillion"=>5027, "deathsPerOneMillion"=>73, "tests"=>2232738, "testsPerOneMillion"=>37630, "population"=>59334579, "continent"=>"Africa", "oneCasePerPeople"=>199, "oneDeathPerPeople"=>13653, "oneTestPerPeople"=>27, "activePerOneMillion"=>2488.72, "recoveredPerOneMillion"=>2465.32, "criticalPerOneMillion"=>9.08}
{"updated"=>1594779763643, "country"=>"South Sudan", "countryInfo"=>{"_id"=>728, "iso2"=>"SS", "iso3"=>"SSD", "lat"=>6.8769, "long"=>31.3069, "flag"=>"https://disease.sh/assets/img/flags/ss.png"}, "cases"=>2148, "todayCases"=>0, "deaths"=>41, "todayDeaths"=>0, "recovered"=>333, "todayRecovered"=>0, "active"=>1774, "critical"=>0, "casesPerOneMillion"=>192, "deathsPerOneMillion"=>4, "tests"=>10824, "testsPerOneMillion"=>967, "population"=>11198327, "continent"=>"Africa", "oneCasePerPeople"=>5213, "oneDeathPerPeople"=>273130, "oneTestPerPeople"=>1035, "activePerOneMillion"=>158.42, "recoveredPerOneMillion"=>29.74, "criticalPerOneMillion"=>0}
{"updated"=>1594779763506, "country"=>"Spain", "countryInfo"=>{"_id"=>724, "iso2"=>"ES", "iso3"=>"ESP", "lat"=>40, "long"=>-4, "flag"=>"https://disease.sh/assets/img/flags/es.png"}, "cases"=>303699, "todayCases"=>0, "deaths"=>28409, "todayDeaths"=>0, "recovered"=>0, "todayRecovered"=>0, "active"=>275290, "critical"=>617, "casesPerOneMillion"=>6495, "deathsPerOneMillion"=>608, "tests"=>6026446, "testsPerOneMillion"=>128893, "population"=>46755514, "continent"=>"Europe", "oneCasePerPeople"=>154, "oneDeathPerPeople"=>1646, "oneTestPerPeople"=>8, "activePerOneMillion"=>5887.86, "recoveredPerOneMillion"=>0, "criticalPerOneMillion"=>13.2}
{"updated"=>1594779763636, "country"=>"Sri Lanka", "countryInfo"=>{"_id"=>144, "iso2"=>"LK", "iso3"=>"LKA", "lat"=>7, "long"=>81, "flag"=>"https://disease.sh/assets/img/flags/lk.png"}, "cases"=>2665, "todayCases"=>0, "deaths"=>11, "todayDeaths"=>0, "recovered"=>1988, "todayRecovered"=>0, "active"=>666, "critical"=>1, "casesPerOneMillion"=>124, "deathsPerOneMillion"=>0.5, "tests"=>125632, "testsPerOneMillion"=>5866, "population"=>21416733, "continent"=>"Asia", "oneCasePerPeople"=>8036, "oneDeathPerPeople"=>1946976, "oneTestPerPeople"=>170, "activePerOneMillion"=>31.1, "recoveredPerOneMillion"=>92.82, "criticalPerOneMillion"=>0.05}
{"updated"=>1594779763756, "country"=>"St. Barth", "countryInfo"=>{"_id"=>652, "iso2"=>"BL", "iso3"=>"BLM", "lat"=>17.89, "long"=>-62.82, "flag"=>"https://disease.sh/assets/img/flags/bl.png"}, "cases"=>6, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>6, "todayRecovered"=>0, "active"=>0, "critical"=>0, "casesPerOneMillion"=>607, "deathsPerOneMillion"=>0, "tests"=>507, "testsPerOneMillion"=>51326, "population"=>9878, "continent"=>"North America", "oneCasePerPeople"=>1646, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>19, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>607.41, "criticalPerOneMillion"=>0}
{"updated"=>1594779763591, "country"=>"Sudan", "countryInfo"=>{"_id"=>736, "iso2"=>"SD", "iso3"=>"SDN", "lat"=>15, "long"=>30, "flag"=>"https://disease.sh/assets/img/flags/sd.png"}, "cases"=>10417, "todayCases"=>0, "deaths"=>659, "todayDeaths"=>0, "recovered"=>5579, "todayRecovered"=>0, "active"=>4179, "critical"=>0, "casesPerOneMillion"=>237, "deathsPerOneMillion"=>15, "tests"=>401, "testsPerOneMillion"=>9, "population"=>43879028, "continent"=>"Africa", "oneCasePerPeople"=>4212, "oneDeathPerPeople"=>66584, "oneTestPerPeople"=>109424, "activePerOneMillion"=>95.24, "recoveredPerOneMillion"=>127.15, "criticalPerOneMillion"=>0}
{"updated"=>1594779763686, "country"=>"Suriname", "countryInfo"=>{"_id"=>740, "iso2"=>"SR", "iso3"=>"SUR", "lat"=>4, "long"=>-56, "flag"=>"https://disease.sh/assets/img/flags/sr.png"}, "cases"=>801, "todayCases"=>0, "deaths"=>18, "todayDeaths"=>0, "recovered"=>543, "todayRecovered"=>0, "active"=>240, "critical"=>6, "casesPerOneMillion"=>1365, "deathsPerOneMillion"=>31, "tests"=>1244, "testsPerOneMillion"=>2120, "population"=>586824, "continent"=>"South America", "oneCasePerPeople"=>733, "oneDeathPerPeople"=>32601, "oneTestPerPeople"=>472, "activePerOneMillion"=>408.98, "recoveredPerOneMillion"=>925.32, "criticalPerOneMillion"=>10.22}
{"updated"=>1594779763664, "country"=>"Swaziland", "countryInfo"=>{"_id"=>748, "iso2"=>"SZ", "iso3"=>"SWZ", "lat"=>-26.5, "long"=>31.5, "flag"=>"https://disease.sh/assets/img/flags/sz.png"}, "cases"=>1434, "todayCases"=>0, "deaths"=>20, "todayDeaths"=>0, "recovered"=>695, "todayRecovered"=>0, "active"=>719, "critical"=>5, "casesPerOneMillion"=>1236, "deathsPerOneMillion"=>17, "tests"=>17559, "testsPerOneMillion"=>15129, "population"=>1160594, "continent"=>"Africa", "oneCasePerPeople"=>809, "oneDeathPerPeople"=>58030, "oneTestPerPeople"=>66, "activePerOneMillion"=>619.51, "recoveredPerOneMillion"=>598.83, "criticalPerOneMillion"=>4.31}
{"updated"=>1594779763535, "country"=>"Sweden", "countryInfo"=>{"_id"=>752, "iso2"=>"SE", "iso3"=>"SWE", "lat"=>62, "long"=>15, "flag"=>"https://disease.sh/assets/img/flags/se.png"}, "cases"=>76001, "todayCases"=>0, "deaths"=>5545, "todayDeaths"=>0, "recovered"=>0, "todayRecovered"=>0, "active"=>70456, "critical"=>81, "casesPerOneMillion"=>7524, "deathsPerOneMillion"=>549, "tests"=>681820, "testsPerOneMillion"=>67496, "population"=>10101646, "continent"=>"Europe", "oneCasePerPeople"=>133, "oneDeathPerPeople"=>1822, "oneTestPerPeople"=>15, "activePerOneMillion"=>6974.7, "recoveredPerOneMillion"=>0, "criticalPerOneMillion"=>8.02}
{"updated"=>1594779763561, "country"=>"Switzerland", "countryInfo"=>{"_id"=>756, "iso2"=>"CH", "iso3"=>"CHE", "lat"=>47, "long"=>8, "flag"=>"https://disease.sh/assets/img/flags/ch.png"}, "cases"=>33016, "todayCases"=>0, "deaths"=>1968, "todayDeaths"=>0, "recovered"=>29800, "todayRecovered"=>0, "active"=>1248, "critical"=>19, "casesPerOneMillion"=>3814, "deathsPerOneMillion"=>227, "tests"=>690701, "testsPerOneMillion"=>79785, "population"=>8656981, "continent"=>"Europe", "oneCasePerPeople"=>262, "oneDeathPerPeople"=>4399, "oneTestPerPeople"=>13, "activePerOneMillion"=>144.16, "recoveredPerOneMillion"=>3442.31, "criticalPerOneMillion"=>2.19}
{"updated"=>1594779763698, "country"=>"Syrian Arab Republic", "countryInfo"=>{"_id"=>760, "iso2"=>"SY", "iso3"=>"SYR", "lat"=>35, "long"=>38, "flag"=>"https://disease.sh/assets/img/flags/sy.png"}, "cases"=>439, "todayCases"=>0, "deaths"=>21, "todayDeaths"=>0, "recovered"=>138, "todayRecovered"=>0, "active"=>280, "critical"=>0, "casesPerOneMillion"=>25, "deathsPerOneMillion"=>1, "tests"=>0, "testsPerOneMillion"=>0, "population"=>17512807, "continent"=>"Asia", "oneCasePerPeople"=>39892, "oneDeathPerPeople"=>833943, "oneTestPerPeople"=>0, "activePerOneMillion"=>15.99, "recoveredPerOneMillion"=>7.88, "criticalPerOneMillion"=>0}
{"updated"=>1594779763697, "country"=>"Taiwan", "countryInfo"=>{"_id"=>158, "iso2"=>"TW", "iso3"=>"TWN", "lat"=>23.5, "long"=>121, "flag"=>"https://disease.sh/assets/img/flags/tw.png"}, "cases"=>451, "todayCases"=>0, "deaths"=>7, "todayDeaths"=>0, "recovered"=>440, "todayRecovered"=>0, "active"=>4, "critical"=>0, "casesPerOneMillion"=>19, "deathsPerOneMillion"=>0.3, "tests"=>78897, "testsPerOneMillion"=>3312, "population"=>23818498, "continent"=>"Asia", "oneCasePerPeople"=>52813, "oneDeathPerPeople"=>3402643, "oneTestPerPeople"=>302, "activePerOneMillion"=>0.17, "recoveredPerOneMillion"=>18.47, "criticalPerOneMillion"=>0}
{"updated"=>1594779763609, "country"=>"Tajikistan", "countryInfo"=>{"_id"=>762, "iso2"=>"TJ", "iso3"=>"TJK", "lat"=>39, "long"=>71, "flag"=>"https://disease.sh/assets/img/flags/tj.png"}, "cases"=>6643, "todayCases"=>0, "deaths"=>56, "todayDeaths"=>0, "recovered"=>5332, "todayRecovered"=>0, "active"=>1255, "critical"=>0, "casesPerOneMillion"=>696, "deathsPerOneMillion"=>6, "tests"=>0, "testsPerOneMillion"=>0, "population"=>9543974, "continent"=>"Asia", "oneCasePerPeople"=>1437, "oneDeathPerPeople"=>170428, "oneTestPerPeople"=>0, "activePerOneMillion"=>131.5, "recoveredPerOneMillion"=>558.68, "criticalPerOneMillion"=>0}
{"updated"=>1594779763696, "country"=>"Tanzania", "countryInfo"=>{"_id"=>834, "iso2"=>"TZ", "iso3"=>"TZA", "lat"=>-6, "long"=>35, "flag"=>"https://disease.sh/assets/img/flags/tz.png"}, "cases"=>509, "todayCases"=>0, "deaths"=>21, "todayDeaths"=>0, "recovered"=>183, "todayRecovered"=>0, "active"=>305, "critical"=>7, "casesPerOneMillion"=>9, "deathsPerOneMillion"=>0.4, "tests"=>0, "testsPerOneMillion"=>0, "population"=>59779035, "continent"=>"Africa", "oneCasePerPeople"=>117444, "oneDeathPerPeople"=>2846621, "oneTestPerPeople"=>0, "activePerOneMillion"=>5.1, "recoveredPerOneMillion"=>3.06, "criticalPerOneMillion"=>0.12}
{"updated"=>1594779763627, "country"=>"Thailand", "countryInfo"=>{"_id"=>764, "iso2"=>"TH", "iso3"=>"THA", "lat"=>15, "long"=>100, "flag"=>"https://disease.sh/assets/img/flags/th.png"}, "cases"=>3227, "todayCases"=>0, "deaths"=>58, "todayDeaths"=>0, "recovered"=>3091, "todayRecovered"=>0, "active"=>78, "critical"=>1, "casesPerOneMillion"=>46, "deathsPerOneMillion"=>0.8, "tests"=>603657, "testsPerOneMillion"=>8648, "population"=>69806919, "continent"=>"Asia", "oneCasePerPeople"=>21632, "oneDeathPerPeople"=>1203568, "oneTestPerPeople"=>116, "activePerOneMillion"=>1.12, "recoveredPerOneMillion"=>44.28, "criticalPerOneMillion"=>0.01}
{"updated"=>1594779763739, "country"=>"Timor-Leste", "countryInfo"=>{"_id"=>626, "iso2"=>"TL", "iso3"=>"TLS", "lat"=>-8.55, "long"=>125.5167, "flag"=>"https://disease.sh/assets/img/flags/tl.png"}, "cases"=>24, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>24, "todayRecovered"=>0, "active"=>0, "critical"=>0, "casesPerOneMillion"=>18, "deathsPerOneMillion"=>0, "tests"=>1568, "testsPerOneMillion"=>1189, "population"=>1319232, "continent"=>"Asia", "oneCasePerPeople"=>54968, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>841, "activePerOneMillion"=>0, "recoveredPerOneMillion"=>18.19, "criticalPerOneMillion"=>0}
{"updated"=>1594779763689, "country"=>"Togo", "countryInfo"=>{"_id"=>768, "iso2"=>"TG", "iso3"=>"TGO", "lat"=>8, "long"=>1.1667, "flag"=>"https://disease.sh/assets/img/flags/tg.png"}, "cases"=>731, "todayCases"=>0, "deaths"=>15, "todayDeaths"=>0, "recovered"=>528, "todayRecovered"=>0, "active"=>188, "critical"=>2, "casesPerOneMillion"=>88, "deathsPerOneMillion"=>2, "tests"=>36277, "testsPerOneMillion"=>4379, "population"=>8284356, "continent"=>"Africa", "oneCasePerPeople"=>11333, "oneDeathPerPeople"=>552290, "oneTestPerPeople"=>228, "activePerOneMillion"=>22.69, "recoveredPerOneMillion"=>63.73, "criticalPerOneMillion"=>0.24}
{"updated"=>1594779763718, "country"=>"Trinidad and Tobago", "countryInfo"=>{"_id"=>780, "iso2"=>"TT", "iso3"=>"TTO", "lat"=>11, "long"=>-61, "flag"=>"https://disease.sh/assets/img/flags/tt.png"}, "cases"=>133, "todayCases"=>0, "deaths"=>8, "todayDeaths"=>0, "recovered"=>124, "todayRecovered"=>0, "active"=>1, "critical"=>0, "casesPerOneMillion"=>95, "deathsPerOneMillion"=>6, "tests"=>5847, "testsPerOneMillion"=>4177, "population"=>1399666, "continent"=>"North America", "oneCasePerPeople"=>10524, "oneDeathPerPeople"=>174958, "oneTestPerPeople"=>239, "activePerOneMillion"=>0.71, "recoveredPerOneMillion"=>88.59, "criticalPerOneMillion"=>0}
{"updated"=>1594779763667, "country"=>"Tunisia", "countryInfo"=>{"_id"=>788, "iso2"=>"TN", "iso3"=>"TUN", "lat"=>34, "long"=>9, "flag"=>"https://disease.sh/assets/img/flags/tn.png"}, "cases"=>1306, "todayCases"=>0, "deaths"=>50, "todayDeaths"=>0, "recovered"=>1087, "todayRecovered"=>0, "active"=>169, "critical"=>0, "casesPerOneMillion"=>110, "deathsPerOneMillion"=>4, "tests"=>79144, "testsPerOneMillion"=>6694, "population"=>11823034, "continent"=>"Africa", "oneCasePerPeople"=>9053, "oneDeathPerPeople"=>236461, "oneTestPerPeople"=>149, "activePerOneMillion"=>14.29, "recoveredPerOneMillion"=>91.94, "criticalPerOneMillion"=>0}
{"updated"=>1594779763518, "country"=>"Turkey", "countryInfo"=>{"_id"=>792, "iso2"=>"TR", "iso3"=>"TUR", "lat"=>39, "long"=>35, "flag"=>"https://disease.sh/assets/img/flags/tr.png"}, "cases"=>214993, "todayCases"=>0, "deaths"=>5402, "todayDeaths"=>0, "recovered"=>196720, "todayRecovered"=>0, "active"=>12871, "critical"=>1204, "casesPerOneMillion"=>2548, "deathsPerOneMillion"=>64, "tests"=>4065178, "testsPerOneMillion"=>48182, "population"=>84371332, "continent"=>"Asia", "oneCasePerPeople"=>392, "oneDeathPerPeople"=>15619, "oneTestPerPeople"=>21, "activePerOneMillion"=>152.55, "recoveredPerOneMillion"=>2331.6, "criticalPerOneMillion"=>14.27}
{"updated"=>1594779763731, "country"=>"Turks and Caicos Islands", "countryInfo"=>{"_id"=>796, "iso2"=>"TC", "iso3"=>"TCA", "lat"=>21.75, "long"=>-71.5833, "flag"=>"https://disease.sh/assets/img/flags/tc.png"}, "cases"=>72, "todayCases"=>0, "deaths"=>2, "todayDeaths"=>0, "recovered"=>12, "todayRecovered"=>0, "active"=>58, "critical"=>4, "casesPerOneMillion"=>1859, "deathsPerOneMillion"=>52, "tests"=>946, "testsPerOneMillion"=>24422, "population"=>38735, "continent"=>"North America", "oneCasePerPeople"=>538, "oneDeathPerPeople"=>19368, "oneTestPerPeople"=>41, "activePerOneMillion"=>1497.35, "recoveredPerOneMillion"=>309.8, "criticalPerOneMillion"=>103.27}
{"updated"=>1594779763544, "country"=>"UAE", "countryInfo"=>{"_id"=>784, "iso2"=>"AE", "iso3"=>"ARE", "lat"=>24, "long"=>54, "flag"=>"https://disease.sh/assets/img/flags/ae.png"}, "cases"=>55573, "todayCases"=>0, "deaths"=>335, "todayDeaths"=>0, "recovered"=>46025, "todayRecovered"=>0, "active"=>9213, "critical"=>1, "casesPerOneMillion"=>5617, "deathsPerOneMillion"=>34, "tests"=>4000000, "testsPerOneMillion"=>404262, "population"=>9894571, "continent"=>"Asia", "oneCasePerPeople"=>178, "oneDeathPerPeople"=>29536, "oneTestPerPeople"=>2, "activePerOneMillion"=>931.12, "recoveredPerOneMillion"=>4651.54, "criticalPerOneMillion"=>0.1}
{"updated"=>1594779763509, "country"=>"UK", "countryInfo"=>{"_id"=>826, "iso2"=>"GB", "iso3"=>"GBR", "lat"=>54, "long"=>-2, "flag"=>"https://disease.sh/assets/img/flags/gb.png"}, "cases"=>291373, "todayCases"=>0, "deaths"=>44968, "todayDeaths"=>0, "recovered"=>0, "todayRecovered"=>0, "active"=>246405, "critical"=>162, "casesPerOneMillion"=>4291, "deathsPerOneMillion"=>662, "tests"=>12270317, "testsPerOneMillion"=>180712, "population"=>67899665, "continent"=>"Europe", "oneCasePerPeople"=>233, "oneDeathPerPeople"=>1510, "oneTestPerPeople"=>6, "activePerOneMillion"=>3628.96, "recoveredPerOneMillion"=>0, "criticalPerOneMillion"=>2.39}
{"updated"=>1594779763496, "country"=>"USA", "countryInfo"=>{"_id"=>840, "iso2"=>"US", "iso3"=>"USA", "lat"=>38, "long"=>-97, "flag"=>"https://disease.sh/assets/img/flags/us.png"}, "cases"=>3545077, "todayCases"=>0, "deaths"=>139143, "todayDeaths"=>0, "recovered"=>1600195, "todayRecovered"=>0, "active"=>1805739, "critical"=>16337, "casesPerOneMillion"=>10708, "deathsPerOneMillion"=>420, "tests"=>44030877, "testsPerOneMillion"=>132993, "population"=>331076384, "continent"=>"North America", "oneCasePerPeople"=>93, "oneDeathPerPeople"=>2379, "oneTestPerPeople"=>8, "activePerOneMillion"=>5454.15, "recoveredPerOneMillion"=>4833.31, "criticalPerOneMillion"=>49.35}
{"updated"=>1594779763675, "country"=>"Uganda", "countryInfo"=>{"_id"=>800, "iso2"=>"UG", "iso3"=>"UGA", "lat"=>1, "long"=>32, "flag"=>"https://disease.sh/assets/img/flags/ug.png"}, "cases"=>1040, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>984, "todayRecovered"=>0, "active"=>56, "critical"=>0, "casesPerOneMillion"=>23, "deathsPerOneMillion"=>0, "tests"=>230680, "testsPerOneMillion"=>5039, "population"=>45776636, "continent"=>"Africa", "oneCasePerPeople"=>44016, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>198, "activePerOneMillion"=>1.22, "recoveredPerOneMillion"=>21.5, "criticalPerOneMillion"=>0}
{"updated"=>1594779763545, "country"=>"Ukraine", "countryInfo"=>{"_id"=>804, "iso2"=>"UA", "iso3"=>"UKR", "lat"=>49, "long"=>32, "flag"=>"https://disease.sh/assets/img/flags/ua.png"}, "cases"=>54771, "todayCases"=>0, "deaths"=>1412, "todayDeaths"=>0, "recovered"=>27154, "todayRecovered"=>0, "active"=>26205, "critical"=>104, "casesPerOneMillion"=>1253, "deathsPerOneMillion"=>32, "tests"=>813396, "testsPerOneMillion"=>18604, "population"=>43722282, "continent"=>"Europe", "oneCasePerPeople"=>798, "oneDeathPerPeople"=>30965, "oneTestPerPeople"=>54, "activePerOneMillion"=>599.35, "recoveredPerOneMillion"=>621.06, "criticalPerOneMillion"=>2.38}
{"updated"=>1594779763681, "country"=>"Uruguay", "countryInfo"=>{"_id"=>858, "iso2"=>"UY", "iso3"=>"URY", "lat"=>-33, "long"=>-56, "flag"=>"https://disease.sh/assets/img/flags/uy.png"}, "cases"=>997, "todayCases"=>0, "deaths"=>31, "todayDeaths"=>0, "recovered"=>905, "todayRecovered"=>0, "active"=>61, "critical"=>0, "casesPerOneMillion"=>287, "deathsPerOneMillion"=>9, "tests"=>81446, "testsPerOneMillion"=>23443, "population"=>3474201, "continent"=>"South America", "oneCasePerPeople"=>3485, "oneDeathPerPeople"=>112071, "oneTestPerPeople"=>43, "activePerOneMillion"=>17.56, "recoveredPerOneMillion"=>260.49, "criticalPerOneMillion"=>0}
{"updated"=>1594779763583, "country"=>"Uzbekistan", "countryInfo"=>{"_id"=>860, "iso2"=>"UZ", "iso3"=>"UZB", "lat"=>41, "long"=>64, "flag"=>"https://disease.sh/assets/img/flags/uz.png"}, "cases"=>14085, "todayCases"=>0, "deaths"=>67, "todayDeaths"=>0, "recovered"=>8327, "todayRecovered"=>0, "active"=>5691, "critical"=>43, "casesPerOneMillion"=>421, "deathsPerOneMillion"=>2, "tests"=>1377915, "testsPerOneMillion"=>41150, "population"=>33485533, "continent"=>"Asia", "oneCasePerPeople"=>2377, "oneDeathPerPeople"=>499784, "oneTestPerPeople"=>24, "activePerOneMillion"=>169.95, "recoveredPerOneMillion"=>248.67, "criticalPerOneMillion"=>1.28}
{"updated"=>1594779763594, "country"=>"Venezuela", "countryInfo"=>{"_id"=>862, "iso2"=>"VE", "iso3"=>"VEN", "lat"=>8, "long"=>-66, "flag"=>"https://disease.sh/assets/img/flags/ve.png"}, "cases"=>10010, "todayCases"=>0, "deaths"=>96, "todayDeaths"=>0, "recovered"=>2671, "todayRecovered"=>0, "active"=>7243, "critical"=>25, "casesPerOneMillion"=>352, "deathsPerOneMillion"=>3, "tests"=>1386563, "testsPerOneMillion"=>48767, "population"=>28432540, "continent"=>"South America", "oneCasePerPeople"=>2840, "oneDeathPerPeople"=>296172, "oneTestPerPeople"=>21, "activePerOneMillion"=>254.74, "recoveredPerOneMillion"=>93.94, "criticalPerOneMillion"=>0.88}
{"updated"=>1594779763700, "country"=>"Vietnam", "countryInfo"=>{"_id"=>704, "iso2"=>"VN", "iso3"=>"VNM", "lat"=>21, "long"=>105.8, "flag"=>"https://disease.sh/assets/img/flags/vn.png"}, "cases"=>373, "todayCases"=>0, "deaths"=>0, "todayDeaths"=>0, "recovered"=>352, "todayRecovered"=>0, "active"=>21, "critical"=>1, "casesPerOneMillion"=>4, "deathsPerOneMillion"=>0, "tests"=>275000, "testsPerOneMillion"=>2824, "population"=>97370489, "continent"=>"Asia", "oneCasePerPeople"=>261047, "oneDeathPerPeople"=>0, "oneTestPerPeople"=>354, "activePerOneMillion"=>0.22, "recoveredPerOneMillion"=>3.62, "criticalPerOneMillion"=>0.01}
{"updated"=>1594779763752, "country"=>"Western Sahara", "countryInfo"=>{"_id"=>732, "iso2"=>"EH", "iso3"=>"ESH", "lat"=>24.5, "long"=>-13, "flag"=>"https://disease.sh/assets/img/flags/eh.png"}, "cases"=>10, "todayCases"=>0, "deaths"=>1, "todayDeaths"=>0, "recovered"=>8, "todayRecovered"=>0, "active"=>1, "critical"=>0, "casesPerOneMillion"=>17, "deathsPerOneMillion"=>2, "tests"=>0, "testsPerOneMillion"=>0, "population"=>597756, "continent"=>"Africa", "oneCasePerPeople"=>59776, "oneDeathPerPeople"=>597756, "oneTestPerPeople"=>0, "activePerOneMillion"=>1.67, "recoveredPerOneMillion"=>13.38, "criticalPerOneMillion"=>0}
{"updated"=>1594779763663, "country"=>"Yemen", "countryInfo"=>{"_id"=>887, "iso2"=>"YE", "iso3"=>"YEM", "lat"=>15, "long"=>48, "flag"=>"https://disease.sh/assets/img/flags/ye.png"}, "cases"=>1516, "todayCases"=>0, "deaths"=>429, "todayDeaths"=>0, "recovered"=>685, "todayRecovered"=>0, "active"=>402, "critical"=>0, "casesPerOneMillion"=>51, "deathsPerOneMillion"=>14, "tests"=>120, "testsPerOneMillion"=>4, "population"=>29845521, "continent"=>"Asia", "oneCasePerPeople"=>19687, "oneDeathPerPeople"=>69570, "oneTestPerPeople"=>248713, "activePerOneMillion"=>13.47, "recoveredPerOneMillion"=>22.95, "criticalPerOneMillion"=>0}
{"updated"=>1594779763649, "country"=>"Zambia", "countryInfo"=>{"_id"=>894, "iso2"=>"ZM", "iso3"=>"ZMB", "lat"=>-15, "long"=>30, "flag"=>"https://disease.sh/assets/img/flags/zm.png"}, "cases"=>1895, "todayCases"=>0, "deaths"=>42, "todayDeaths"=>0, "recovered"=>1412, "todayRecovered"=>0, "active"=>441, "critical"=>1, "casesPerOneMillion"=>103, "deathsPerOneMillion"=>2, "tests"=>56825, "testsPerOneMillion"=>3089, "population"=>18397649, "continent"=>"Africa", "oneCasePerPeople"=>9709, "oneDeathPerPeople"=>438039, "oneTestPerPeople"=>324, "activePerOneMillion"=>23.97, "recoveredPerOneMillion"=>76.75, "criticalPerOneMillion"=>0.05}
{"updated"=>1594779763674, "country"=>"Zimbabwe", "countryInfo"=>{"_id"=>716, "iso2"=>"ZW", "iso3"=>"ZWE", "lat"=>-20, "long"=>30, "flag"=>"https://disease.sh/assets/img/flags/zw.png"}, "cases"=>1064, "todayCases"=>0, "deaths"=>20, "todayDeaths"=>0, "recovered"=>343, "todayRecovered"=>0, "active"=>701, "critical"=>0, "casesPerOneMillion"=>72, "deathsPerOneMillion"=>1, "tests"=>93248, "testsPerOneMillion"=>6271, "population"=>14870201, "continent"=>"Africa", "oneCasePerPeople"=>13976, "oneDeathPerPeople"=>743510, "oneTestPerPeople"=>159, "activePerOneMillion"=>47.14, "recoveredPerOneMillion"=>23.07, "criticalPerOneMillion"=>0}
```

---

**Get countries general data in table format**
```shell
covid19-cli all_countries --table
```
**Output**
```shell
+----------------------------------+-----------+------------+---------+-------------+-----------+----------------+-----------+----------+------------+--------------------+---------------+
|             country              |   cases   | todayCases | deaths  | todayDeaths | recovered | todayRecovered |  active   | critical |   tests    | testsPerOneMillion |  population   |
+----------------------------------+-----------+------------+---------+-------------+-----------+----------------+-----------+----------+------------+--------------------+---------------+
|                      Afghanistan |    34 740 |          0 |   1 048 |           0 |    21 454 |              0 |    12 238 |       31 |     81 252 |              2 086 |    38 954 218 |
|                          Albania |     3 667 |          0 |      97 |           0 |     2 062 |              0 |     1 508 |       10 |     29 334 |             10 194 |     2 877 667 |
|                          Algeria |    20 216 |          0 |   1 028 |           0 |    14 295 |              0 |     4 893 |       61 |          0 |                  0 |    43 876 253 |
|                          Andorra |       861 |          0 |      52 |           0 |       803 |              0 |         6 |        0 |      3 750 |             48 531 |        77 270 |
|                           Angola |       541 |          0 |      26 |           0 |       118 |              0 |       397 |        6 |     10 000 |                304 |    32 891 752 |
|                         Anguilla |         3 |          0 |       0 |           0 |         3 |              0 |         0 |        0 |        380 |             25 320 |        15 008 |
|              Antigua and Barbuda |        74 |          0 |       3 |           0 |        57 |              0 |        14 |        1 |        866 |              8 840 |        97 959 |
|                        Argentina |   106 910 |          0 |   1 968 |           0 |    45 467 |              0 |    59 475 |      752 |    483 799 |             10 701 |    45 210 848 |
|                          Armenia |    32 490 |          0 |     581 |           0 |    20 729 |              0 |    11 180 |       10 |    136 802 |             46 163 |     2 963 464 |
|                            Aruba |       106 |          0 |       3 |           0 |        99 |              0 |         4 |        0 |      4 012 |             37 571 |       106 784 |
|                        Australia |    10 487 |        237 |     111 |           3 |     7 928 |             93 |     2 448 |       28 |  3 213 715 |            125 977 |    25 510 278 |
|                          Austria |    19 021 |          0 |     709 |           0 |    17 073 |              0 |     1 239 |        9 |    708 128 |             78 608 |     9 008 354 |
|                       Azerbaijan |    25 113 |          0 |     319 |           0 |    16 150 |              0 |     8 644 |       66 |    576 249 |             56 815 |    10 142 506 |
|                          Bahamas |       116 |          3 |      11 |           0 |        91 |              0 |        14 |        1 |      2 545 |              6 470 |       393 380 |
|                          Bahrain |    34 078 |          0 |     111 |           0 |    29 753 |              0 |     4 214 |       51 |    685 318 |            402 434 |     1 702 931 |
|                       Bangladesh |   190 057 |          0 |   2 424 |           0 |   103 227 |              0 |    84 406 |        1 |    966 400 |              5 866 |   164 748 373 |
|                         Barbados |       103 |          0 |       7 |           0 |        90 |              0 |         6 |        0 |      9 026 |             31 407 |       287 389 |
|                          Belarus |    65 269 |          0 |     474 |           0 |    55 799 |              0 |     8 996 |       89 |  1 144 696 |            121 142 |     9 449 196 |
|                          Belgium |    62 781 |          0 |   9 787 |           0 |    17 223 |              0 |    35 771 |       23 |  1 390 593 |            119 966 |    11 591 576 |
|                           Belize |        39 |          0 |       2 |           0 |        21 |              0 |        16 |        0 |      2 665 |              6 698 |       397 857 |
|                            Benin |     1 378 |          0 |      26 |           0 |       557 |              0 |       795 |        1 |     67 622 |              5 574 |    12 131 954 |
|                          Bermuda |       150 |          0 |       9 |           0 |       137 |              0 |         4 |        1 |     14 467 |            232 334 |        62 268 |
|                           Bhutan |        84 |          0 |       0 |           0 |        78 |              0 |         6 |        0 |     39 270 |             50 874 |       771 909 |
|                          Bolivia |    50 867 |      1 617 |   1 898 |          32 |    15 819 |            525 |    33 150 |       71 |    111 416 |              9 540 |    11 678 450 |
|                           Bosnia |     6 981 |          0 |     226 |           0 |     3 179 |              0 |     3 576 |        4 |    111 536 |             34 006 |     3 279 925 |
|                         Botswana |       399 |          0 |       1 |           0 |        38 |              0 |       360 |        1 |     51 379 |             21 835 |     2 353 086 |
|                           Brazil | 1 931 204 |          0 |  74 262 |           0 | 1 213 512 |              0 |   643 430 |    8 318 |  4 572 796 |             21 507 |   212 615 886 |
|           British Virgin Islands |         8 |          0 |       1 |           0 |         7 |              0 |         0 |        0 |        439 |             14 518 |        30 239 |
|                           Brunei |       141 |          0 |       3 |           0 |       138 |              0 |         0 |        0 |     29 841 |             68 188 |       437 630 |
|                         Bulgaria |     7 645 |          0 |     283 |           0 |     3 663 |              0 |     3 699 |       27 |    184 560 |             26 570 |     6 946 122 |
|                     Burkina Faso |     1 037 |          0 |      53 |           0 |       873 |              0 |       111 |        0 |          0 |                  0 |    20 918 698 |
|                          Burundi |       269 |          0 |       1 |           0 |       207 |              0 |        61 |        0 |      6 697 |                563 |    11 899 864 |
|                       Cabo Verde |     1 722 |          0 |      19 |           0 |       772 |              0 |       931 |        0 |     40 475 |             72 770 |       556 201 |
|                         Cambodia |       165 |          0 |       0 |           0 |       133 |              0 |        32 |        1 |     47 702 |              2 852 |    16 726 831 |
|                         Cameroon |    15 173 |          0 |     359 |           0 |    11 928 |              0 |     2 886 |       52 |    120 837 |              4 549 |    26 564 536 |
|                           Canada |   108 486 |          0 |   8 798 |           0 |    72 170 |              0 |    27 518 |    2 170 |  3 302 483 |             87 473 |    37 754 249 |
|            Caribbean Netherlands |         7 |          0 |       0 |           0 |         7 |              0 |         0 |        0 |        424 |             16 163 |        26 232 |
|                   Cayman Islands |       203 |          0 |       1 |           0 |       200 |              0 |         2 |        0 |     26 919 |            409 421 |        65 749 |
|         Central African Republic |     4 356 |          0 |      53 |           0 |     1 229 |              0 |     3 074 |        2 |     27 561 |              5 703 |     4 832 469 |
|                             Chad |       884 |          0 |      75 |           0 |       798 |              0 |        11 |        0 |          0 |                  0 |    16 438 226 |
|                  Channel Islands |       581 |          0 |      47 |           0 |       512 |              0 |        22 |        0 |     21 410 |            123 102 |       173 921 |
|                            Chile |   319 493 |          0 |   7 069 |           0 |   289 220 |              0 |    23 204 |    1 915 |  1 322 503 |             69 161 |    19 122 213 |
|                            China |    83 611 |          6 |   4 634 |           0 |    78 693 |             19 |       284 |        3 | 90 410 000 |             62 814 | 1 439 323 776 |
|                         Colombia |   159 898 |          0 |   5 625 |           0 |    68 806 |              0 |    85 467 |      875 |  1 082 415 |             21 265 |    50 902 201 |
|                          Comoros |       321 |          0 |       7 |           0 |       302 |              0 |        12 |        0 |          0 |                  0 |       870 160 |
|                            Congo |     2 222 |        194 |      47 |           0 |       589 |              0 |     1 586 |        0 |          0 |                  0 |     5 521 945 |
|                       Costa Rica |     8 482 |          0 |      37 |           1 |     2 441 |              0 |     6 004 |       30 |     61 216 |             12 013 |     5 095 810 |
|                          Croatia |     3 827 |          0 |     120 |           0 |     2 558 |              0 |     1 149 |        5 |     95 920 |             23 371 |     4 104 159 |
|                             Cuba |     2 432 |          0 |      87 |           0 |     2 275 |              0 |        70 |        2 |    211 427 |             18 667 |    11 326 332 |
|                          Curaçao |        26 |          1 |       1 |           0 |        24 |              0 |         1 |        0 |      1 080 |              6 581 |       164 119 |
|                           Cyprus |     1 023 |          0 |      19 |           0 |       839 |              0 |       165 |        0 |    167 394 |            138 607 |     1 207 687 |
|                          Czechia |    13 341 |          0 |     355 |           0 |     8 441 |              0 |     4 545 |       21 |    602 670 |             56 273 |    10 709 775 |
|                    Côte d'Ivoire |    13 037 |          0 |      87 |           0 |     6 908 |              0 |     6 042 |        0 |     78 066 |              2 957 |    26 396 778 |
|                              DRC |     8 135 |          0 |     190 |           0 |     3 948 |              0 |     3 997 |        0 |          0 |                  0 |    89 630 305 |
|                          Denmark |    13 061 |          0 |     610 |           0 |    12 160 |              0 |       291 |        3 |  1 257 157 |            217 013 |     5 793 000 |
|                 Diamond Princess |       712 |          0 |      13 |           0 |       651 |              0 |        48 |        4 |          0 |                  0 |             0 |
|                         Djibouti |     4 979 |          0 |      56 |           0 |     4 743 |              0 |       180 |        0 |     51 843 |             52 447 |       988 483 |
|                         Dominica |        18 |          0 |       0 |           0 |        18 |              0 |         0 |        0 |        623 |              8 654 |        71 993 |
|               Dominican Republic |    46 305 |          0 |     910 |           0 |    23 134 |              0 |    22 261 |      226 |    189 391 |             17 452 |    10 851 818 |
|                          Ecuador |    69 570 |          0 |   5 130 |           0 |    30 484 |              0 |    33 956 |      313 |    186 879 |             10 587 |    17 651 979 |
|                            Egypt |    83 930 |          0 |   4 008 |           0 |    25 544 |              0 |    54 378 |       41 |    135 000 |              1 318 |   102 395 050 |
|                      El Salvador |    10 303 |          0 |     278 |           0 |     5 919 |              0 |     4 106 |      357 |    197 151 |             30 390 |     6 487 461 |
|                Equatorial Guinea |     3 071 |          0 |      51 |           0 |       842 |              0 |     2 178 |        0 |     16 000 |             11 395 |     1 404 090 |
|                          Eritrea |       232 |          0 |       0 |           0 |       107 |              0 |       125 |        0 |          0 |                  0 |     3 548 090 |
|                          Estonia |     2 015 |          0 |      69 |           0 |     1 897 |              0 |        49 |        1 |    112 594 |             84 876 |     1 326 571 |
|                         Ethiopia |     7 969 |          0 |     139 |           0 |     2 430 |              0 |     5 400 |       35 |    250 604 |              2 178 |   115 044 244 |
|      Falkland Islands (Malvinas) |        13 |          0 |       0 |           0 |        13 |              0 |         0 |        0 |      1 393 |            399 943 |         3 483 |
|                    Faroe Islands |       188 |          0 |       0 |           0 |       188 |              0 |         0 |        0 |     24 704 |            505 504 |        48 870 |
|                             Fiji |        26 |          0 |       0 |           0 |        18 |              0 |         8 |        0 |      4 000 |              4 461 |       896 687 |
|                          Finland |     7 301 |          0 |     329 |           0 |     6 800 |              0 |       172 |        1 |    278 800 |             50 315 |     5 541 065 |
|                           France |   172 377 |          0 |  30 029 |           0 |    78 597 |              0 |    63 751 |      492 |  2 489 269 |             38 133 |    65 279 255 |
|                    French Guiana |     6 229 |          0 |      31 |           0 |     3 472 |              0 |     2 726 |       25 |     10 919 |             36 531 |       298 897 |
|                 French Polynesia |        62 |          0 |       0 |           0 |        60 |              0 |         2 |        0 |      4 649 |             16 546 |       280 970 |
|                            Gabon |     6 026 |          0 |      46 |           0 |     3 475 |              0 |     2 505 |       11 |     49 853 |             22 383 |     2 227 254 |
|                           Gambia |        64 |          0 |       3 |           0 |        34 |              0 |        27 |        0 |      3 573 |              1 477 |     2 418 471 |
|                          Georgia |       999 |          0 |      15 |           0 |       870 |              0 |       114 |        5 |    148 188 |             37 151 |     3 988 847 |
|                          Germany |   200 766 |          0 |   9 144 |           0 |   185 500 |              0 |     6 122 |      264 |  6 376 054 |             76 092 |    83 794 469 |
|                            Ghana |    24 988 |          0 |     139 |           0 |    21 067 |              0 |     3 782 |        8 |    331 366 |             10 657 |    31 092 641 |
|                        Gibraltar |       180 |          0 |       0 |           0 |       179 |              0 |         1 |        0 |     16 532 |            490 695 |        33 691 |
|                           Greece |     3 883 |          0 |     193 |           0 |     1 374 |              0 |     2 316 |       13 |    386 307 |             37 071 |    10 420 856 |
|                        Greenland |        13 |          0 |       0 |           0 |        13 |              0 |         0 |        0 |      4 789 |             84 352 |        56 774 |
|                          Grenada |        23 |          0 |       0 |           0 |        23 |              0 |         0 |        0 |      5 465 |             48 559 |       112 543 |
|                       Guadeloupe |       190 |          0 |      14 |           0 |       157 |              0 |        19 |        4 |     11 538 |             28 836 |       400 127 |
|                        Guatemala |    30 872 |          0 |   1 302 |           0 |     4 453 |              0 |    25 117 |        5 |     64 590 |              3 603 |    17 926 043 |
|                           Guinea |     6 200 |          0 |      38 |           0 |     4 951 |              0 |     1 211 |       24 |     14 407 |              1 096 |    13 142 438 |
|                    Guinea-Bissau |     1 842 |          0 |      26 |           0 |       773 |              0 |     1 043 |        5 |      1 500 |                762 |     1 969 346 |
|                           Guyana |       308 |          0 |      17 |           0 |       156 |              0 |       135 |        5 |      3 379 |              4 295 |       786 698 |
|                            Haiti |     6 727 |          0 |     141 |           0 |     3 022 |              0 |     3 564 |        0 |     14 544 |              1 275 |    11 407 370 |
|    Holy See (Vatican City State) |        12 |          0 |       0 |           0 |        12 |              0 |         0 |        0 |          0 |                  0 |           801 |
|                         Honduras |    29 106 |        527 |     807 |          18 |     3 123 |              0 |    25 176 |       58 |     49 308 |              4 976 |     9 909 797 |
|                        Hong Kong |     1 570 |          0 |       8 |           0 |     1 229 |              0 |       333 |        6 |    376 645 |             50 225 |     7 499 224 |
|                          Hungary |     4 258 |          0 |     595 |           0 |     3 106 |              0 |       557 |        5 |    296 358 |             30 681 |     9 659 319 |
|                          Iceland |     1 905 |          0 |      10 |           0 |     1 882 |              0 |        13 |        0 |    104 713 |            306 783 |       341 326 |
|                            India |   937 487 |          0 |  24 315 |           0 |   593 080 |              0 |   320 092 |    8 944 | 12 412 664 |              8 991 | 1 380 493 070 |
|                        Indonesia |    78 572 |          0 |   3 710 |           0 |    37 636 |              0 |    37 226 |        0 |  1 097 468 |              4 011 |   273 626 716 |
|                             Iran |   262 173 |          0 |  13 211 |           0 |   225 270 |              0 |    23 692 |    3 389 |  2 023 079 |             24 076 |    84 030 066 |
|                             Iraq |    81 757 |          0 |   3 345 |           0 |    50 782 |              0 |    27 630 |      412 |    698 012 |             17 342 |    40 249 168 |
|                          Ireland |    25 670 |          0 |   1 746 |           0 |    23 364 |              0 |       560 |        9 |    523 277 |            105 932 |     4 939 736 |
|                      Isle of Man |       336 |          0 |      24 |           0 |       312 |              0 |         0 |        0 |      7 301 |             85 844 |        85 050 |
|                           Israel |    42 360 |          0 |     371 |           0 |    19 665 |              0 |    22 324 |      183 |  1 317 362 |            143 229 |     9 197 590 |
|                            Italy |   243 344 |          0 |  34 984 |           0 |   195 441 |              0 |    12 919 |       60 |  6 004 611 |             99 319 |    60 458 132 |
|                          Jamaica |       762 |          3 |      10 |           0 |       643 |             15 |       109 |        0 |     28 603 |              9 658 |     2 961 667 |
|                            Japan |    22 220 |          0 |     982 |           0 |    18 282 |              0 |     2 956 |       40 |    574 432 |              4 542 |   126 460 083 |
|                           Jordan |     1 198 |          0 |      10 |           0 |     1 013 |              0 |       175 |        3 |    477 448 |             46 778 |    10 206 777 |
|                       Kazakhstan |    63 514 |      1 759 |     375 |           0 |    38 008 |          2 097 |    25 131 |      221 |  1 737 546 |             92 499 |    18 784 556 |
|                            Kenya |    10 791 |          0 |     202 |           0 |     3 017 |              0 |     7 572 |       44 |    221 234 |              4 112 |    53 806 557 |
|                           Kuwait |    56 174 |          0 |     396 |           0 |    46 161 |              0 |     9 617 |      156 |    441 143 |            103 247 |     4 272 688 |
|                       Kyrgyzstan |    11 977 |        533 |     160 |          11 |     3 660 |            122 |     8 157 |       24 |    259 793 |             39 799 |     6 527 708 |
| Lao People's Democratic Republic |        19 |          0 |       0 |           0 |        19 |              0 |         0 |        0 |     20 769 |              2 853 |     7 279 113 |
|                           Latvia |     1 174 |          0 |      31 |           0 |     1 022 |              0 |       121 |        1 |    172 078 |             91 277 |     1 885 238 |
|                          Lebanon |     2 451 |          0 |      37 |           0 |     1 452 |              0 |       962 |       20 |    184 425 |             27 025 |     6 824 132 |
|                          Lesotho |       256 |          0 |       3 |           0 |        48 |              0 |       205 |        0 |      6 033 |              2 815 |     2 142 877 |
|                          Liberia |     1 024 |          0 |      51 |           0 |       439 |              0 |       534 |        0 |          0 |                  0 |     5 061 128 |
|           Libyan Arab Jamahiriya |     1 563 |          0 |      42 |           0 |       370 |              0 |     1 151 |        0 |     36 524 |              5 313 |     6 874 480 |
|                    Liechtenstein |        84 |          0 |       1 |           0 |        81 |              0 |         2 |        0 |        900 |             23 602 |        38 132 |
|                        Lithuania |     1 875 |          0 |      79 |           0 |     1 571 |              0 |       225 |       15 |    465 396 |            171 071 |     2 720 490 |
|                       Luxembourg |     5 056 |          0 |     111 |           0 |     4 195 |              0 |       750 |        3 |    292 711 |            467 357 |       626 312 |
|                       MS Zaandam |         9 |          0 |       2 |           0 |         0 |              0 |         7 |        0 |          0 |                  0 |             0 |
|                            Macao |        46 |          0 |       0 |           0 |        45 |              0 |         1 |        0 |      4 071 |              6 267 |       649 637 |
|                        Macedonia |     8 332 |          0 |     389 |           0 |     4 468 |              0 |     3 475 |       55 |     79 392 |             38 107 |     2 083 371 |
|                       Madagascar |     5 343 |          0 |      39 |           0 |     2 646 |              0 |     2 658 |       45 |     30 100 |              1 086 |    27 710 827 |
|                           Malawi |     2 497 |          0 |      40 |           0 |       795 |              0 |     1 662 |        4 |     21 532 |              1 125 |    19 143 672 |
|                         Malaysia |     8 729 |          0 |     122 |           0 |     8 524 |              0 |        83 |        6 |    850 423 |             26 264 |    32 380 313 |
|                         Maldives |     2 801 |          0 |      14 |           0 |     2 302 |              0 |       485 |       12 |     63 559 |            117 517 |       540 849 |
|                             Mali |     2 423 |          0 |     121 |           0 |     1 748 |              0 |       554 |        0 |     16 317 |                805 |    20 266 097 |
|                            Malta |       674 |          0 |       9 |           0 |       660 |              0 |         5 |        0 |    108 553 |            245 823 |       441 590 |
|                       Martinique |       255 |          0 |      15 |           0 |        98 |              0 |       142 |        5 |          0 |                  0 |       375 253 |
|                       Mauritania |     5 518 |          0 |     147 |           0 |     2 664 |              0 |     2 707 |        5 |     13 842 |              2 975 |     4 653 021 |
|                        Mauritius |       342 |          0 |      10 |           0 |       330 |              0 |         2 |        0 |    193 561 |            152 188 |     1 271 853 |
|                          Mayotte |     2 724 |          0 |      37 |           0 |     2 480 |              0 |       207 |        3 |     13 000 |             47 618 |       273 004 |
|                           Mexico |   311 486 |      7 051 |  36 327 |         836 |   193 976 |          4 913 |    81 183 |      378 |    756 137 |              5 862 |   128 981 086 |
|                          Moldova |    19 708 |          0 |     655 |           0 |    13 033 |              0 |     6 020 |      358 |    101 180 |             25 084 |     4 033 570 |
|                           Monaco |       109 |          0 |       4 |           0 |        97 |              0 |         8 |        0 |     16 200 |            412 718 |        39 252 |
|                         Mongolia |       261 |         18 |       0 |           0 |       207 |              3 |        54 |        3 |     28 313 |              8 632 |     3 280 024 |
|                       Montenegro |     1 287 |          0 |      24 |           0 |       330 |              0 |       933 |        7 |     24 972 |             39 760 |       628 069 |
|                       Montserrat |        12 |          0 |       1 |           0 |        10 |              0 |         1 |        0 |         61 |             12 220 |         4 992 |
|                          Morocco |    16 097 |          0 |     257 |           0 |    13 442 |              0 |     2 398 |       31 |    915 140 |             24 783 |    36 925 874 |
|                       Mozambique |     1 268 |          0 |       9 |           0 |       373 |              0 |       886 |        0 |     40 861 |              1 306 |    31 278 721 |
|                          Myanmar |       337 |          0 |       6 |           0 |       261 |              0 |        70 |        0 |     94 168 |              1 730 |    54 423 505 |
|                          Namibia |       864 |          0 |       2 |           0 |        29 |              0 |       833 |        1 |     15 439 |              6 073 |     2 542 369 |
|                            Nepal |    17 061 |          0 |      38 |           0 |    10 328 |              0 |     6 695 |        0 |    606 141 |             20 791 |    29 153 511 |
|                      Netherlands |    51 146 |          0 |   6 135 |           0 |         0 |              0 |    45 011 |       20 |    764 079 |             44 588 |    17 136 380 |
|                    New Caledonia |        21 |          0 |       0 |           0 |        21 |              0 |         0 |        0 |      9 218 |             32 276 |       285 597 |
|                      New Zealand |     1 547 |          2 |      22 |           0 |     1 498 |              0 |        27 |        0 |    433 324 |             86 628 |     5 002 100 |
|                        Nicaragua |     3 147 |          0 |      99 |           0 |     2 282 |              0 |       766 |        0 |          0 |                  0 |     6 627 311 |
|                            Niger |     1 099 |          0 |      68 |           0 |       992 |              0 |        39 |        0 |      6 658 |                275 |    24 226 032 |
|                          Nigeria |    33 616 |          0 |     754 |           0 |    13 792 |              0 |    19 070 |        7 |    186 309 |                903 |   206 284 260 |
|                           Norway |     9 001 |          0 |     253 |           0 |     8 138 |              0 |       610 |        1 |    383 149 |             70 655 |     5 422 810 |
|                             Oman |    59 568 |          0 |     273 |           0 |    37 987 |              0 |    21 308 |      149 |    244 831 |             47 910 |     5 110 259 |
|                         Pakistan |   255 769 |      2 165 |   5 386 |          66 |   172 810 |          2 154 |    77 573 |    2 078 |  1 627 939 |              7 365 |   221 025 870 |
|                        Palestine |     6 764 |          0 |      44 |           0 |     1 084 |              0 |     5 636 |        0 |    141 444 |             27 708 |     5 104 868 |
|                           Panama |    48 096 |          0 |     960 |           0 |    24 667 |              4 |    22 469 |      157 |    171 116 |             39 638 |     4 317 010 |
|                 Papua New Guinea |        11 |          0 |       0 |           0 |         8 |              0 |         3 |        0 |      7 147 |                798 |     8 952 342 |
|                         Paraguay |     3 074 |          0 |      25 |           0 |     1 308 |              0 |     1 741 |       10 |     94 328 |             13 219 |     7 135 586 |
|                             Peru |   333 867 |          0 |  12 229 |           0 |   223 261 |              0 |    98 377 |    1 325 |  1 963 921 |             59 535 |    32 987 448 |
|                      Philippines |    57 545 |          0 |   1 603 |           0 |    20 459 |              0 |    35 483 |      333 |  1 017 723 |              9 283 |   109 631 056 |
|                           Poland |    38 457 |          0 |   1 588 |           0 |    27 756 |              0 |     9 113 |       74 |  1 813 365 |             47 916 |    37 844 896 |
|                         Portugal |    47 051 |          0 |   1 668 |           0 |    31 550 |              0 |    13 833 |       69 |  1 366 864 |            134 066 |    10 195 453 |
|                            Qatar |   104 533 |          0 |     150 |           0 |   101 160 |              0 |     3 223 |      137 |    420 649 |            149 814 |     2 807 805 |
|                          Romania |    33 585 |          0 |   1 931 |           0 |    21 803 |              0 |     9 851 |      234 |    868 478 |             45 158 |    19 232 044 |
|                           Russia |   739 947 |          0 |  11 614 |           0 |   512 825 |              0 |   215 508 |    2 300 | 23 495 752 |            160 999 |   145 937 005 |
|                           Rwanda |     1 416 |          0 |       4 |           0 |       737 |              0 |       675 |        0 |    192 379 |             14 843 |    12 961 309 |
|                          Réunion |       599 |          0 |       3 |           0 |       472 |              0 |       124 |        3 |     35 419 |             39 550 |       895 551 |
|                         S. Korea |    13 551 |         39 |     289 |           0 |    12 348 |             66 |       914 |       15 |  1 431 316 |             27 917 |    51 270 969 |
|            Saint Kitts and Nevis |        17 |          0 |       0 |           0 |        15 |              0 |         2 |        0 |        671 |             12 610 |        53 213 |
|                      Saint Lucia |        22 |          0 |       0 |           0 |        19 |              0 |         3 |        0 |      2 048 |             11 151 |       183 659 |
|                     Saint Martin |        43 |          0 |       3 |           0 |        37 |              0 |         3 |        1 |        851 |             21 997 |        38 687 |
|            Saint Pierre Miquelon |         2 |          0 |       0 |           0 |         1 |              0 |         1 |        0 |          0 |                  0 |         5 793 |
| Saint Vincent and the Grenadines |        35 |          0 |       0 |           0 |        29 |              0 |         6 |        0 |      1 213 |             10 932 |       110 954 |
|                       San Marino |       699 |          0 |      42 |           0 |       656 |              0 |         1 |        0 |      5 729 |            168 828 |        33 934 |
|            Sao Tome and Principe |       732 |          0 |      14 |           0 |       286 |              0 |       432 |        0 |      1 973 |              8 997 |       219 287 |
|                     Saudi Arabia |   237 803 |          0 |   2 283 |           0 |   177 560 |              0 |    57 960 |    2 235 |  2 336 874 |             67 090 |    34 831 824 |
|                          Senegal |     8 243 |          0 |     150 |           0 |     5 580 |              0 |     2 513 |       36 |     92 101 |              5 497 |    16 756 053 |
|                           Serbia |    18 983 |          0 |     418 |           0 |    13 991 |              0 |     4 574 |      170 |    507 002 |             58 037 |     8 735 866 |
|                       Seychelles |       100 |          0 |       0 |           0 |        11 |              0 |        89 |        0 |          0 |                  0 |        98 370 |
|                     Sierra Leone |     1 651 |          0 |      64 |           0 |     1 190 |              0 |       397 |        0 |          0 |                  0 |     7 981 956 |
|                        Singapore |    46 630 |          0 |      27 |           0 |    42 737 |              0 |     3 866 |        0 |  1 009 532 |            172 509 |     5 852 044 |
|                     Sint Maarten |        78 |          0 |      15 |           0 |        63 |              0 |         0 |        0 |        523 |             12 193 |        42 893 |
|                         Slovakia |     1 908 |          0 |      28 |           0 |     1 493 |              0 |       387 |        3 |    231 231 |             42 352 |     5 459 749 |
|                         Slovenia |     1 859 |          0 |     111 |           0 |     1 488 |              0 |       260 |        1 |    117 241 |             56 394 |     2 078 950 |
|                          Somalia |     3 076 |          0 |      93 |           0 |     1 380 |              0 |     1 603 |        2 |          0 |                  0 |    15 905 041 |
|                     South Africa |   298 292 |          0 |   4 346 |           0 |   146 279 |              0 |   147 667 |      539 |  2 232 738 |             37 630 |    59 334 579 |
|                      South Sudan |     2 148 |          0 |      41 |           0 |       333 |              0 |     1 774 |        0 |     10 824 |                967 |    11 198 327 |
|                            Spain |   303 699 |          0 |  28 409 |           0 |         0 |              0 |   275 290 |      617 |  6 026 446 |            128 893 |    46 755 514 |
|                        Sri Lanka |     2 665 |          0 |      11 |           0 |     1 988 |              0 |       666 |        1 |    127 920 |              5 973 |    21 416 733 |
|                        St. Barth |         6 |          0 |       0 |           0 |         6 |              0 |         0 |        0 |        507 |             51 326 |         9 878 |
|                            Sudan |    10 417 |          0 |     659 |           0 |     5 579 |              0 |     4 179 |        0 |        401 |                  9 |    43 879 028 |
|                         Suriname |       801 |          0 |      18 |           0 |       543 |              0 |       240 |        6 |      1 244 |              2 120 |       586 824 |
|                        Swaziland |     1 434 |          0 |      20 |           0 |       695 |              0 |       719 |        5 |     17 559 |             15 129 |     1 160 594 |
|                           Sweden |    76 001 |          0 |   5 545 |           0 |         0 |              0 |    70 456 |       81 |    681 820 |             67 496 |    10 101 646 |
|                      Switzerland |    33 016 |          0 |   1 968 |           0 |    29 800 |              0 |     1 248 |       19 |    690 701 |             79 785 |     8 656 981 |
|             Syrian Arab Republic |       439 |          0 |      21 |           0 |       138 |              0 |       280 |        0 |          0 |                  0 |    17 512 807 |
|                           Taiwan |       451 |          0 |       7 |           0 |       440 |              0 |         4 |        0 |     78 897 |              3 312 |    23 818 498 |
|                       Tajikistan |     6 643 |          0 |      56 |           0 |     5 332 |              0 |     1 255 |        0 |          0 |                  0 |     9 543 974 |
|                         Tanzania |       509 |          0 |      21 |           0 |       183 |              0 |       305 |        7 |          0 |                  0 |    59 779 035 |
|                         Thailand |     3 232 |          5 |      58 |           0 |     3 092 |              1 |        82 |        1 |    603 657 |              8 648 |    69 806 919 |
|                      Timor-Leste |        24 |          0 |       0 |           0 |        24 |              0 |         0 |        0 |      1 568 |              1 189 |     1 319 232 |
|                             Togo |       731 |          0 |      15 |           0 |       528 |              0 |       188 |        2 |     36 277 |              4 379 |     8 284 356 |
|              Trinidad and Tobago |       133 |          0 |       8 |           0 |       124 |              0 |         1 |        0 |      5 847 |              4 177 |     1 399 666 |
|                          Tunisia |     1 306 |          0 |      50 |           0 |     1 087 |              0 |       169 |        0 |     79 144 |              6 694 |    11 823 034 |
|                           Turkey |   214 993 |          0 |   5 402 |           0 |   196 720 |              0 |    12 871 |    1 204 |  4 065 178 |             48 182 |    84 371 332 |
|         Turks and Caicos Islands |        72 |          0 |       2 |           0 |        12 |              0 |        58 |        4 |        946 |             24 422 |        38 735 |
|                              UAE |    55 573 |          0 |     335 |           0 |    46 025 |              0 |     9 213 |        1 |  4 000 000 |            404 262 |     9 894 571 |
|                               UK |   291 373 |          0 |  44 968 |           0 |         0 |              0 |   246 405 |      162 | 12 270 317 |            180 712 |    67 899 665 |
|                              USA | 3 545 077 |          0 | 139 143 |           0 | 1 600 195 |              0 | 1 805 739 |   16 337 | 44 030 877 |            132 993 |   331 076 384 |
|                           Uganda |     1 040 |          0 |       0 |           0 |       984 |              0 |        56 |        0 |    230 680 |              5 039 |    45 776 636 |
|                          Ukraine |    54 771 |          0 |   1 412 |           0 |    27 154 |              0 |    26 205 |      104 |    813 396 |             18 604 |    43 722 282 |
|                          Uruguay |       997 |          0 |      31 |           0 |       905 |              0 |        61 |        0 |     81 446 |             23 443 |     3 474 201 |
|                       Uzbekistan |    14 293 |        208 |      68 |           1 |     8 327 |              0 |     5 898 |       43 |  1 377 915 |             41 150 |    33 485 533 |
|                        Venezuela |    10 010 |          0 |      96 |           0 |     2 671 |              0 |     7 243 |       25 |  1 386 563 |             48 767 |    28 432 540 |
|                          Vietnam |       373 |          0 |       0 |           0 |       352 |              0 |        21 |        1 |    275 000 |              2 824 |    97 370 489 |
|                   Western Sahara |        10 |          0 |       1 |           0 |         8 |              0 |         1 |        0 |          0 |                  0 |       597 756 |
|                            Yemen |     1 516 |          0 |     429 |           0 |       685 |              0 |       402 |        0 |        120 |                  4 |    29 845 521 |
|                           Zambia |     1 895 |          0 |      42 |           0 |     1 412 |              0 |       441 |        1 |     56 825 |              3 089 |    18 397 649 |
|                         Zimbabwe |     1 064 |          0 |      20 |           0 |       343 |              0 |       701 |        0 |     93 248 |              6 271 |    14 870 201 |
+----------------------------------+-----------+------------+---------+-------------+-----------+----------------+-----------+----------+------------+--------------------+---------------+
```

---

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake spec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Used Gems

* [bundler](https://rubygems.org/gems/bundler)
* [httparty](https://rubygems.org/gems/httparty)
* [rake](https://rubygems.org/gems/rake)
* [rspec](https://rubygems.org/gems/rspec)
* [text-table](https://rubygems.org/gems/text-table)
* [thor](https://rubygems.org/gems/thor)
* [tty-pie](https://github.com/piotrmurach/tty-pie)

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/TecnoSigma/covid19-cli. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](http://contributor-covenant.org) code of conduct.

## License

The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).

## Code of Conduct

Everyone interacting in the Covid19::Cli project’s codebases, issue trackers, chat rooms and mailing lists is expected to follow the [code of conduct](https://github.com/TecnoSigma/covid19-cli/blob/master/CODE_OF_CONDUCT.md).
